@@ -7,12 +7,13 @@ except ImportError:
     from .install import install
     from .deploy import deploy
     from .run import run
+import logging
 
 def main():
     def exit():
-        print('Usage:\n  lazyllm install [full|standard|package_name]\n'
-              '  lazyllm deploy modelname\n  lazyllm run graph.json\n'
-              '  lazyllm run chatbot\n  lazyllm run rag\n')
+        logging.error('Usage:\n  lazyllm install <extra1> <extra2> <pkg1> ...\n'
+                      '  lazyllm deploy modelname\n  lazyllm deploy mcp_server <command> [args ...] [options]\n'
+                      '  lazyllm run graph.json\n  lazyllm run chatbot\n  lazyllm run rag\n')
         sys.exit(1)
 
     if len(sys.argv) <= 1: exit()
