@@ -31,13 +31,13 @@ Examples:
     <lazyllm.llm.finetune type=AlpacaloraFinetune>
     """
     def __new__(cls, base_model, target_path, source=lazyllm.config['model_source'], merge_path=None, ctx_len=1024,
-                batch_size=32, lora_r=8, launcher=launchers.remote(ngpus=1), **kw):
+                batch_size=32, lora_r=8, launcher=launchers.remote(ngpus=1), **kw):  # noqa B008
         base_model = ModelManager(source).download(base_model) or ''
         model_name = get_model_name(base_model)
         model_type = ModelManager.get_model_type(model_name)
         if model_type in ['embed', 'tts', 'vlm', 'stt', 'sd']:
             raise RuntimeError(f'Fine-tuning of the {model_type} model is not currently supported.')
-        map_name = model_map(model_name)
+        map_name, _ = model_map(model_name)
         base_name = model_name.split('-')[0].split('_')[0].lower()
         candidates = get_configer().query_finetune(lazyllm.config['gpu_type'], launcher.ngpus,
                                                    map_name, ctx_len, batch_size, lora_r)
