@@ -37,8 +37,9 @@ Examples:
         'input': 'who are you ?',
     }
     default_headers = {'Content-Type': 'application/json'}
+    target_name = 'embeddings'
 
-    def __init__(self, launcher=launchers.remote(ngpus=1), model_type='embed', log_path=None, **kw):
+    def __init__(self, launcher=launchers.remote(ngpus=1), model_type='embed', log_path=None, **kw):  # noqa B008
         super().__init__(launcher=launcher)
         self.kw = ArgsDict({
             'host': '0.0.0.0',
@@ -46,26 +47,11 @@ Examples:
             'batch-size': 256,
         })
         self._model_type = model_type
+        kw.pop('stream', '')
         self.kw.check_and_update(kw)
         self.random_port = False if 'port' in kw and kw['port'] else True
-        if self._model_type == "reranker":
-            self._update_reranker_message()
         self.temp_folder = make_log_dir(log_path, 'lmdeploy') if log_path else None
 
-    def _update_reranker_message(self):
-        self.keys_name_handle = {
-            'inputs': 'query',
-        }
-        self.message_format = {
-            'query': 'who are you ?',
-            'documents': ['string'],
-            'return_documents': False,
-            'raw_scores': False,
-            'top_n': 1,
-            'model': 'default/not-specified',
-        }
-        self.default_headers = {'Content-Type': 'application/json'}
-
     def cmd(self, finetuned_model=None, base_model=None):
         if not os.path.exists(finetuned_model) or \
             not any(filename.endswith('.bin') or filename.endswith('.safetensors')
@@ -79,6 +65,17 @@ Examples:
             if self.random_port:
                 self.kw['port'] = random.randint(30000, 40000)
             cmd = f'infinity_emb v2 --model-id {finetuned_model} '
+            if isinstance(self._launcher, launchers.EmptyLauncher) and self._launcher.ngpus:
+                available_gpus = self._launcher._get_idle_gpus()
+                required_count = self._launcher.ngpus
+                if required_count <= len(available_gpus):
+                    gpu_ids = ','.join(map(str, available_gpus[:required_count]))
+                    cmd += f'--device-id={gpu_ids} '
+                else:
+                    raise RuntimeError(
+                        f"Insufficient GPUs available (required: {required_count}, "
+                        f"available: {len(available_gpus)})"
+                    )
             cmd += self.kw.parse_kwargs()
             if self.temp_folder: cmd += f' 2>&1 | tee {get_log_path(self.temp_folder)}'
             return cmd
@@ -88,14 +85,10 @@ Examples:
     def geturl(self, job=None):
         if job is None:
             job = self.job
-        if self._model_type == "reranker":
-            target_name = 'rerank'
-        else:
-            target_name = 'embeddings'
         if lazyllm.config['mode'] == lazyllm.Mode.Display:
-            return f'http://<ip>:<port>/{target_name}'
+            return f'http://<ip>:<port>/{self.target_name}'
         else:
-            return f'http://{job.get_jobip()}:{self.kw["port"]}/{target_name}'
+            return f'http://{job.get_jobip()}:{self.kw["port"]}/{self.target_name}'
 
     @staticmethod
     def extract_result(x, inputs):
@@ -115,3 +108,10 @@ Examples:
             return json.dumps(res_list)
         elif object_type == 'rerank':
             return [(x['index'], x['relevance_score']) for x in res_object['results']]
+
+class InfinityRerank(Infinity):
+    keys_name_handle = {'inputs': 'query'}
+    message_format = {'query': 'who are you ?', 'documents': ['string'], 'return_documents': False,
+                      'raw_scores': False, 'top_n': 1, 'model': 'default/not-specified'}
+    default_headers = {'Content-Type': 'application/json'}
+    target_name = 'rerank'
