@@ -28,6 +28,10 @@ Keyword Args:
     nccl_port (int): NCCL port, default is ``None``, in which case LazyLLM will automatically generate a random port number.
     tokenizer_mode (str): Tokenizer loading mode, default is ``auto``.
     running_max_req_size (int): Maximum number of parallel requests for the inference engine, default is ``256``.
+    data_type (str): Data type for model weights, default is ``float16``.
+    max_req_total_len (int): Maximum total length for requests, default is ``64000``.
+    max_req_input_len (int): Maximum input length, default is ``4096``.
+    long_truncation_mode (str): Truncation mode for long texts, default is ``head``.
 
 
 
@@ -51,13 +55,15 @@ Examples:
             "top_p": 1,
             "top_k": -1,  # -1 is for all
             "ignore_eos": False,
-            'max_new_tokens': 4096,
+            'max_new_tokens': 8192,
             "stop_sequences": None,
         }
     }
-    auto_map = {'tp': 'tp'}
+    auto_map = {}
+    stream_url_suffix = '_stream'
+    stream_parse_parameters = {"delimiter": b"\n\n"}
 
-    def __init__(self, trust_remote_code=True, launcher=launchers.remote(ngpus=1), stream=False, log_path=None, **kw):
+    def __init__(self, trust_remote_code=True, launcher=launchers.remote(ngpus=1), log_path=None, **kw):  # noqa B008
         super().__init__(launcher=launcher)
         self.kw = ArgsDict({
             'tp': 1,
@@ -70,6 +76,8 @@ Examples:
             "running_max_req_size": 256,
             "data_type": 'float16',
             "max_req_total_len": 64000,
+            "max_req_input_len": 4096,
+            "long_truncation_mode": "head",
         })
         self.trust_remote_code = trust_remote_code
         self.kw.check_and_update(kw)
@@ -78,6 +86,15 @@ Examples:
         self.temp_folder = make_log_dir(log_path, 'lightllm') if log_path else None
 
     def cmd(self, finetuned_model=None, base_model=None):
+        """This method generates the command to start the LightLLM service.
+
+Args:
+    finetuned_model (str): Path to the fine-tuned model.
+    base_model (str): Path to the base model, used when finetuned_model is invalid.
+
+Returns:
+    LazyLLMCMD: A LazyLLMCMD object containing the startup command.
+"""
         if not os.path.exists(finetuned_model) or \
             not any(filename.endswith('.bin') or filename.endswith('.safetensors')
                     for filename in os.listdir(finetuned_model)):
@@ -101,6 +118,14 @@ Examples:
         return LazyLLMCMD(cmd=impl, return_value=self.geturl, checkf=verify_fastapi_func)
 
     def geturl(self, job=None):
+        """Get the URL address of the LightLLM service.
+
+Args:
+    job (optional): Job object, defaults to None, in which case self.job is used.
+
+Returns:
+    str: The service URL address in the format "http://{ip}:{port}/generate".
+"""
         if job is None:
             job = self.job
         if lazyllm.config['mode'] == lazyllm.Mode.Display:
@@ -116,11 +141,3 @@ Examples:
         except Exception as e:
             LOG.warning(f'JSONDecodeError on load {x}')
             raise e
-
-    @staticmethod
-    def stream_parse_parameters():
-        return {"delimiter": b"\n\n"}
-
-    @staticmethod
-    def stream_url_suffix():
-        return "_stream"
