@@ -1,27 +1,34 @@
 import os
 import json
 import random
+import importlib.util
 
 import lazyllm
-from lazyllm import launchers, LazyLLMCMD, ArgsDict, LOG
+from lazyllm import launchers, LazyLLMCMD, ArgsDict, LOG, config
 from .base import LazyLLMDeployBase, verify_fastapi_func
 from ..utils import ModelManager
 from .utils import get_log_path, make_log_dir
 
 
+config.add('lmdeploy_eager_mode', bool, False, 'LMDEPLOY_EAGER_MODE')
+
 class LMDeploy(LazyLLMDeployBase):
-    """    This class is a subclass of ``LazyLLMDeployBase``, leveraging the inference capabilities provided by the [LMDeploy](https://github.com/InternLM/lmdeploy) framework for inference on large language models.
+    """This class is a subclass of ``LazyLLMDeployBase``, leveraging the inference capabilities provided by the [LMDeploy](https://github.com/InternLM/lmdeploy) framework for inference on large language models.
 
 Args:
     launcher (lazyllm.launcher): The launcher for fine-tuning, defaults to ``launchers.remote(ngpus=1)``.
     stream (bool): Whether to enable streaming response, defaults to ``False``.
+    trust_remote_code (bool): Whether to trust remote code, defaults to ``True``.
+    log_path (str): Path for log file, defaults to ``None``.
     kw: Keyword arguments for updating default training parameters. Note that no additional keyword arguments beyond those listed below can be passed.
 
 Keyword Args: 
     tp (int): Tensor parallelism parameter, defaults to ``1``.
-    server_name (str): The IP address of the service, defaults to ``0.0.0.0``.
-    server_port (int): The port number of the service, defaults to ``None``. In this case, LazyLLM will automatically generate a random port number.
-    max_batch_size (int): Maximum batch size, defaults to ``128``.
+    server-name (str): The IP address of the service, defaults to ``0.0.0.0``.
+    server-port (int): The port number of the service, defaults to ``None``. In this case, LazyLLM will automatically generate a random port number.
+    max-batch-size (int): Maximum batch size, defaults to ``128``.
+    chat-template (str): Path to chat template file, defaults to ``None``. If the model is not a vision-language model and no template is specified, a default template will be used.
+    eager-mode (bool): Whether to enable eager mode, controlled by environment variable ``LMDEPLOY_EAGER_MODE``, defaults to ``False``.
 
 
 
@@ -62,9 +69,15 @@ Examples:
         "cancel": False,
         "adapter_name": None
     }
-    auto_map = {}
+    auto_map = {
+        'port': 'server-port',
+        'host': 'server-name',
+        'max_batch_size': 'max-batch-size',
+        'chat_template': 'chat-template',
+    }
+    stream_parse_parameters = {"delimiter": b"\n"}
 
-    def __init__(self, launcher=launchers.remote(ngpus=1), stream=False, log_path=None, **kw):
+    def __init__(self, launcher=launchers.remote(ngpus=1), trust_remote_code=True, log_path=None, **kw):  # noqa B008
         super().__init__(launcher=launcher)
         self.kw = ArgsDict({
             'server-name': '0.0.0.0',
@@ -74,10 +87,20 @@ Examples:
             "chat-template": None,
         })
         self.kw.check_and_update(kw)
+        self._trust_remote_code = trust_remote_code
         self.random_port = False if 'server-port' in kw and kw['server-port'] else True
         self.temp_folder = make_log_dir(log_path, 'lmdeploy') if log_path else None
 
     def cmd(self, finetuned_model=None, base_model=None):
+        """This method generates the command to start the LMDeploy service.
+
+Args:
+    finetuned_model (str): Path to the fine-tuned model.
+    base_model (str): Path to the base model, used when finetuned_model is invalid.
+
+Returns:
+    LazyLLMCMD: A LazyLLMCMD object containing the startup command.
+"""
         if not os.path.exists(finetuned_model) or \
             not any(filename.endswith('.bin') or filename.endswith('.safetensors')
                     for filename in os.listdir(finetuned_model)):
@@ -86,7 +109,7 @@ Examples:
                             f"base_model({base_model}) will be used")
             finetuned_model = base_model
 
-        model_type = ModelManager.get_model_type(finetuned_model)
+        model_type = ModelManager.get_model_type(base_model or finetuned_model)
         if model_type == 'vlm':
             self.kw.pop("chat-template")
         else:
@@ -101,10 +124,8 @@ Examples:
                 self.kw['server-port'] = random.randint(30000, 40000)
             cmd = f"lmdeploy serve api_server {finetuned_model} "
 
-            import importlib.util
-            if importlib.util.find_spec("torch_npu") is not None:
-                cmd += "--device ascend --eager-mode "
-
+            if importlib.util.find_spec("torch_npu") is not None: cmd += '--device ascend '
+            if config['lmdeploy_eager_mode']: cmd += '--eager-mode '
             cmd += self.kw.parse_kwargs()
             if self.temp_folder: cmd += f' 2>&1 | tee {get_log_path(self.temp_folder)}'
             return cmd
@@ -112,6 +133,14 @@ Examples:
         return LazyLLMCMD(cmd=impl, return_value=self.geturl, checkf=verify_fastapi_func)
 
     def geturl(self, job=None):
+        """Get the URL address of the LMDeploy service.
+
+Args:
+    job (optional): Job object, defaults to None, in which case self.job is used.
+
+Returns:
+    str: The service URL address in the format "http://{ip}:{port}/v1/chat/interactive".
+"""
         if job is None:
             job = self.job
         if lazyllm.config['mode'] == lazyllm.Mode.Display:
@@ -122,11 +151,3 @@ Examples:
     @staticmethod
     def extract_result(x, inputs):
         return json.loads(x)['text']
-
-    @staticmethod
-    def stream_parse_parameters():
-        return {"delimiter": b"\n"}
-
-    @staticmethod
-    def stream_url_suffix():
-        return ''
