@@ -2,45 +2,31 @@ import os
 import sys
 import json
 import random
+import importlib
+from packaging.version import parse
+
 import lazyllm
-from lazyllm import launchers, LazyLLMCMD, ArgsDict, LOG
+from lazyllm import launchers, LazyLLMCMD, ArgsDict, LOG, LazyLLMLaunchersBase
 from .base import LazyLLMDeployBase, verify_fastapi_func
+from ...common import LazyLLMRegisterMetaClass
 from .utils import get_log_path, make_log_dir
+from .ray import reallocate_launcher, Distributed, sleep_moment
 
 
-class Vllm(LazyLLMDeployBase):
-    """This class is a subclass of ``LazyLLMDeployBase``, based on the inference capabilities provided by the [VLLM](https://github.com/vllm-project/vllm) framework, used for inference with large language models.
-
-Args:
-    trust_remote_code (bool): Whether to allow loading of model code from remote servers, default is ``True``.
-    launcher (lazyllm.launcher): The launcher for fine-tuning, default is ``launchers.remote(ngpus=1)``.
-    stream (bool): Whether the response is streaming, default is ``False``.
-    kw: Keyword arguments used to update default training parameters. Note that not any additional keyword arguments can be specified here.
-
-The keyword arguments and their default values for this class are as follows:
-
-Keyword Args: 
-    tensor-parallel-size (int): Tensor parallelism parameter, default is ``1``.
-    dtype (str): Data type for model weights and activations, default is ``auto``. Other options include: ``half``, ``float16``, ``bfloat16``, ``float``, ``float32``.
-    kv-cache-dtype (str): Data type for the key-value cache storage, default is ``auto``. Other options include: ``fp8``, ``fp8_e5m2``, ``fp8_e4m3``.
-    device (str): Backend hardware type supported by VLLM, default is ``auto``. Other options include: ``cuda``, ``neuron``, ``cpu``.
-    block-size (int): Sets the size of the token block, default is ``16``.
-    port (int): Service port number, default is ``auto``.
-    host (str): Service IP address, default is ``0.0.0.0``.
-    seed (int): Random number seed, default is ``0``.
-    tokenizer_mode (str): Tokenizer loading mode, default is ``auto``.
-    max-num-seqs (int): Maximum number of parallel requests for the inference engine, default is ``256``.
+class _VllmStreamParseParametersMeta(LazyLLMRegisterMetaClass):
+    def __getattribute__(cls, name):
+        if name == 'stream_parse_parameters':
+            if not hasattr(cls, '_stream_parse_parameters'):
+                vllm_version = parse(importlib.import_module('vllm').__version__)
+                cls._stream_parse_parameters = {"decode_unicode": False}
+                if vllm_version <= parse("0.5.0"): cls._stream_parse_parameters.update({"delimiter": b"\0"})
+            return cls._stream_parse_parameters
+        return super().__getattribute__(name)
 
 
-
-Examples:
-    >>> from lazyllm import deploy
-    >>> infer = deploy.vllm()
-    """
-    keys_name_handle = {
-        'inputs': 'prompt',
-        'stop': 'stop'
-    }
+class Vllm(LazyLLMDeployBase, metaclass=_VllmStreamParseParametersMeta):
+    # keys_name_handle/default_headers/message_format will lose efficacy when openai_api is True
+    keys_name_handle = {'inputs': 'prompt', 'stop': 'stop'}
     default_headers = {'Content-Type': 'application/json'}
     message_format = {
         'prompt': 'Who are you ?',
@@ -52,8 +38,13 @@ Examples:
         'max_tokens': 4096
     }
     auto_map = {'tp': 'tensor-parallel-size'}
+    optional_keys = set(["max-model-len"])
 
-    def __init__(self, trust_remote_code=True, launcher=launchers.remote(ngpus=1), stream=False, log_path=None, **kw):
+    # TODO(wangzhihong): change default value for `openai_api` argument to True
+    def __init__(self, trust_remote_code: bool = True,
+                 launcher: LazyLLMLaunchersBase = launchers.remote(ngpus=1),  # noqa B008
+                 log_path: str = None, openai_api: bool = False, **kw):
+        self.launcher_list, launcher = reallocate_launcher(launcher)
         super().__init__(launcher=launcher)
         self.kw = ArgsDict({
             'dtype': 'auto',
@@ -66,13 +57,22 @@ Examples:
             'port': 'auto',
             'host': '0.0.0.0',
             'max-num-seqs': 256,
+            'pipeline-parallel-size': 1,
+            'max-num-batched-tokens': 64000,
         })
+        self._vllm_cmd = 'vllm.entrypoints.openai.api_server' if openai_api else 'vllm.entrypoints.api_server'
         self.trust_remote_code = trust_remote_code
+        self.kw.update(**{key: kw[key] for key in self.optional_keys if key in kw})
         self.kw.check_and_update(kw)
         self.random_port = False if 'port' in kw and kw['port'] and kw['port'] != 'auto' else True
         self.temp_folder = make_log_dir(log_path, 'vllm') if log_path else None
+        if self.launcher_list:
+            ray_launcher = [Distributed(launcher=launcher) for launcher in self.launcher_list]
+            parall_launcher = [lazyllm.pipeline(sleep_moment, launcher) for launcher in ray_launcher[1:]]
+            self._prepare_deploy = lazyllm.pipeline(
+                ray_launcher[0], post_action=(lazyllm.parallel(*parall_launcher) if len(parall_launcher) else None))
 
-    def cmd(self, finetuned_model=None, base_model=None):
+    def cmd(self, finetuned_model=None, base_model=None, master_ip=None):
         if not os.path.exists(finetuned_model) or \
             not any(filename.endswith('.bin') or filename.endswith('.safetensors')
                     for filename in os.listdir(finetuned_model)):
@@ -85,7 +85,10 @@ Examples:
             if self.random_port:
                 self.kw['port'] = random.randint(30000, 40000)
 
-            cmd = f'{sys.executable} -m vllm.entrypoints.api_server --model {finetuned_model} '
+            cmd = ''
+            if self.launcher_list:
+                cmd += f"ray start --address='{master_ip}' && "
+            cmd += f'{sys.executable} -m {self._vllm_cmd} --model {finetuned_model} '
             cmd += self.kw.parse_kwargs()
             if self.trust_remote_code:
                 cmd += ' --trust-remote-code '
@@ -105,11 +108,3 @@ Examples:
     @staticmethod
     def extract_result(x, inputs):
         return json.loads(x)['text'][0]
-
-    @staticmethod
-    def stream_parse_parameters():
-        return {"decode_unicode": False, "delimiter": b"\0"}
-
-    @staticmethod
-    def stream_url_suffix():
-        return ''
