@@ -2,10 +2,12 @@ from .base import LazyLLMFinetuneBase
 from .alpacalora import AlpacaloraFinetune
 from .collie import CollieFinetune
 from .llamafactory import LlamafactoryFinetune
+from .flagembedding import FlagembeddingFinetune
 
 __all__ = [
     'LazyLLMFinetuneBase',
     'AlpacaloraFinetune',
     'CollieFinetune',
     'LlamafactoryFinetune',
+    'FlagembeddingFinetune',
 ]
