@@ -1,5 +1,4 @@
 import os
-import re
 import yaml
 import json
 import uuid
@@ -8,20 +7,31 @@ import random
 from datetime import datetime
 
 import lazyllm
-from lazyllm import launchers, ArgsDict, thirdparty, CaseInsensitiveDict
+from lazyllm import launchers, ArgsDict, thirdparty
 from .base import LazyLLMFinetuneBase
+from .llama_factory.model_mapping import match_longest_prefix, llamafactory_mapping_dict
+
 
 class LlamafactoryFinetune(LazyLLMFinetuneBase):
     """This class is a subclass of ``LazyLLMFinetuneBase``, based on the training capabilities provided by the [LLaMA-Factory](https://github.com/hiyouga/LLaMA-Factory) framework, used for training large language models(or visual language models).
 
 Args:
-    base_model (str): The base model used for training. It is required to be the path of the base model.
-    target_path (str): The path where the trained model weights are saved.
-    merge_path (str): The path where the model is merged with LoRA weights, default is None. If not specified, "lazyllm_lora" and "lazyllm_merge" directories will be created under ``target_path``, to be used as ``target_path`` and ``merge_path`` respectively.
-    config_path (str): The LLaMA-Factory training configuration file (yaml format is required), default is None. If not specified, a ``.temp`` folder will be created in the current working directory, and a configuration file starting with ``train_`` and ending with ``.yaml`` will be generated inside it.
-    export_config_path (str): The LLaMA-Factory Lora weight merging configuration file (yaml format is required), default is None. If not specified, a configuration file starting with ``merge_`` and ending with ``.yaml`` will be generated inside the ``.temp`` folder in the current working directory.
-    launcher (lazyllm.launcher): The launcher for fine-tuning, default is ``launchers.remote(ngpus=1, sync=True)``.
-    kw: Keyword arguments used to update the default training parameters.
+    base_model (str): Path to the base model used for training. Supports local paths; if the path does not exist, it will attempt to locate it from the configured model directory.
+    target_path (str): Target directory to save model weights after training is completed.
+    merge_path (str, optional): Path to save the model after merging LoRA weights. Defaults to None.
+        If not specified, two directories will be automatically created under ``target_path``:
+        - "lazyllm_lora" (for storing LoRA fine-tuned weights)
+        - "lazyllm_merge" (for storing the merged model weights)
+    config_path (str, optional): Path to the YAML file containing training configuration. Defaults to None.
+        If not specified, the default config file ``llama_factory/sft.yaml`` will be used.
+        This file can override default training parameters.
+    export_config_path (str, optional): Path to the YAML file for LoRA weight export/merging configuration. Defaults to None.
+        If not specified, the default config file ``llama_factory/lora_export.yaml`` will be used.
+    lora_r (int, optional): Rank of the LoRA adaptation. If provided, overrides the ``lora_rank`` value in the configuration.
+    modules_to_save (str, optional): List of additional module names to be saved. Should be provided as a string in Python list format, e.g., "[module1, module2]".
+    lora_target_modules (str, optional): List of module names to apply LoRA fine-tuning to. Format is the same as above.
+    launcher (lazyllm.launcher, optional): Launcher for the fine-tuning task. Defaults to a single-GPU, synchronous remote launcher: ``launchers.remote(ngpus=1, sync=True)``.
+    **kw: Additional keyword arguments used to dynamically override default parameters in the training configuration.
 
 Keyword Args:
     stage (typing.Literal['pt', 'sft', 'rm', 'ppo', 'dpo', 'kto']): Default is: ``sft``. Which stage will be performed in training.
@@ -73,7 +83,7 @@ Examples:
                  lora_r=None,
                  modules_to_save=None,
                  lora_target_modules=None,
-                 launcher=launchers.remote(ngpus=1, sync=True),
+                 launcher=launchers.remote(ngpus=1, sync=True),  # noqa B008
                  **kw
                  ):
         if not os.path.exists(base_model):
@@ -96,11 +106,11 @@ Examples:
         self.export_config_path = export_config_path
         self.config_folder_path = os.path.dirname(os.path.abspath(__file__))
 
-        default_config_path = os.path.join(self.config_folder_path, 'llamafactory', 'sft.yaml')
-        self.template_dict = ArgsDict(self.load_yaml(default_config_path))
+        default_config_path = os.path.join(self.config_folder_path, 'llama_factory', 'sft.yaml')
+        self.template_dict = ArgsDict(self._load_yaml(default_config_path))
 
         if self.config_path:
-            self.template_dict.update(self.load_yaml(self.config_path))
+            self.template_dict.update(self._load_yaml(self.config_path))
 
         if lora_r:
             self.template_dict['lora_rank'] = lora_r
@@ -110,14 +120,14 @@ Examples:
             self.template_dict['lora_target'] = lora_target_modules.strip('[]')
         self.template_dict['model_name_or_path'] = base_model
         self.template_dict['output_dir'] = target_path
-        self.template_dict['template'] = self.get_template_name(base_model)
+        self.template_dict['template'] = self._get_template_name(base_model)
         self.template_dict.check_and_update(kw)
 
-        default_export_config_path = os.path.join(self.config_folder_path, 'llamafactory', 'lora_export.yaml')
-        self.export_dict = ArgsDict(self.load_yaml(default_export_config_path))
+        default_export_config_path = os.path.join(self.config_folder_path, 'llama_factory', 'lora_export.yaml')
+        self.export_dict = ArgsDict(self._load_yaml(default_export_config_path))
 
         if self.export_config_path:
-            self.export_dict.update(self.load_yaml(self.export_config_path))
+            self.export_dict.update(self._load_yaml(self.export_config_path))
 
         self.export_dict['model_name_or_path'] = base_model
         self.export_dict['adapter_name_or_path'] = target_path
@@ -129,37 +139,27 @@ Examples:
             os.makedirs(self.temp_folder)
         self.log_file_path = None
 
-    def get_template_name(self, base_model):
-        try:
-            from llamafactory.extras.constants import DEFAULT_TEMPLATE
-        except Exception:
-            # llamfactory need a gpu, 1st import raise error, so import 2nd.
-            from llamafactory.extras.constants import DEFAULT_TEMPLATE
-        teplate_dict = CaseInsensitiveDict(DEFAULT_TEMPLATE)
+    def _get_template_name(self, base_model):
         base_name = os.path.basename(base_model).lower()
-        pattern = r'^llama-(\d+)-\d+'
-        if re.match(pattern, base_name):
-            key = 'llama-' + re.match(pattern, base_name).group(1)
+        key_value = match_longest_prefix(base_name)
+        if key_value:
+            return key_value
         else:
-            key = re.split('[_-]', base_name)[0]
-        if key in teplate_dict:
-            return teplate_dict[key]
-        else:
-            raise RuntimeError(f'Cannot find prfix({key}) of base_model({base_model}) '
-                               f'in DEFAULT_TEMPLATE of LLaMA_Factory: {DEFAULT_TEMPLATE}')
+            raise RuntimeError(f'Cannot find prfix of base_model({base_model}) '
+                               f'in DEFAULT_TEMPLATE of LLaMA_Factory: {llamafactory_mapping_dict}')
 
-    def load_yaml(self, config_path):
+    def _load_yaml(self, config_path):
         with open(config_path, 'r') as file:
             config_dict = yaml.safe_load(file)
         return config_dict
 
-    def build_temp_yaml(self, updated_template_str, prefix='train_'):
+    def _build_temp_yaml(self, updated_template_str, prefix='train_'):
         fd, temp_yaml_file = tempfile.mkstemp(prefix=prefix, suffix='.yaml', dir=self.temp_folder)
         with os.fdopen(fd, 'w') as temp_file:
             temp_file.write(updated_template_str)
         return temp_yaml_file
 
-    def build_temp_dataset_info(self, datapaths):
+    def _build_temp_dataset_info(self, datapaths):
         if isinstance(datapaths, str):
             datapaths = [datapaths]
         elif isinstance(datapaths, list) and all(isinstance(item, str) for item in datapaths):
@@ -172,22 +172,65 @@ Examples:
             assert os.path.isfile(datapath)
             file_name, _ = os.path.splitext(os.path.basename(datapath))
             temp_dataset_dict[file_name] = {'file_name': datapath}
+            formatting = 'alpaca'
+            try:
+                with open(datapath, 'r', encoding='utf-8') as file:
+                    data = json.load(file)
+                if 'messages' in data[0]:
+                    formatting = 'sharegpt'
+                media_types = []
+                for media in ['images', 'videos', 'audios']:
+                    if media in data[0]:
+                        media_types.append(media)
+                if media_types:
+                    columns = {item: item for item in media_types}
+                    columns.update({"messages": "messages"})
+                    temp_dataset_dict[file_name].update({
+                        "tags": {
+                            "role_tag": "role",
+                            "content_tag": "content",
+                            "user_tag": "user",
+                            "assistant_tag": "assistant"
+                        },
+                        "columns": columns
+                    })
+            except Exception:
+                pass
+            temp_dataset_dict[file_name].update({'formatting': formatting})
         self.temp_dataset_info_path = os.path.join(self.temp_folder, 'dataset_info.json')
         with open(self.temp_dataset_info_path, 'w') as json_file:
             json.dump(temp_dataset_dict, json_file, indent=4)
         return self.temp_dataset_info_path, ','.join(temp_dataset_dict.keys())
 
-    def rm_temp_yaml(self):
+    def _rm_temp_yaml(self):
         if self.temp_yaml_file:
             if os.path.exists(self.temp_yaml_file):
                 os.remove(self.temp_yaml_file)
             self.temp_yaml_file = None
 
     def cmd(self, trainset, valset=None) -> str:
+        """Generate LLaMA-Factory fine-tuning command sequence, including training and model merge commands.
+
+Args:
+    trainset (str): Training dataset path (supports relative path to lazyllm.config['data_path'])
+    valset (str, optional): Validation dataset path (not directly used in current implementation)
+
+Returns:
+    str: Complete shell command string containing:
+         - Training command (with auto-configured parameters)
+         - Log redirection (saved to target path)
+         - Optional model merge command (when LoRA is configured)
+
+Notes:
+    - Automatically generates timestamped training log files
+    - Temporary files are automatically cleaned up after use
+    - Supports multiple data formats (alpaca/sharegpt etc.)
+    - Multimodal data (images/videos/audios) is automatically detected and handled
+"""
         thirdparty.check_packages(['datasets', 'deepspeed', 'numpy', 'peft', 'torch', 'transformers', 'trl'])
         # train config update
         if 'dataset_dir' in self.template_dict and self.template_dict['dataset_dir'] == 'lazyllm_temp_dir':
-            _, datasets = self.build_temp_dataset_info(trainset)
+            _, datasets = self._build_temp_dataset_info(trainset)
             self.template_dict['dataset_dir'] = self.temp_folder
         else:
             datasets = trainset
@@ -196,16 +239,16 @@ Examples:
         # save config update
         if self.template_dict['finetuning_type'] == 'lora':
             updated_export_str = yaml.dump(dict(self.export_dict), default_flow_style=False)
-            self.temp_export_yaml_file = self.build_temp_yaml(updated_export_str, prefix='merge_')
+            self.temp_export_yaml_file = self._build_temp_yaml(updated_export_str, prefix='merge_')
 
         updated_template_str = yaml.dump(dict(self.template_dict), default_flow_style=False)
-        self.temp_yaml_file = self.build_temp_yaml(updated_template_str)
+        self.temp_yaml_file = self._build_temp_yaml(updated_template_str)
 
         formatted_date = datetime.now().strftime("%Y-%m-%d_%H-%M-%S")
         random_value = random.randint(1000, 9999)
         self.log_file_path = f'{self.target_path}/train_log_{formatted_date}_{random_value}.log'
 
-        cmds = f'llamafactory-cli train {self.temp_yaml_file}'
+        cmds = f'export DISABLE_VERSION_CHECK=1 && llamafactory-cli train {self.temp_yaml_file}'
         cmds += f' 2>&1 | tee {self.log_file_path}'
         if self.temp_export_yaml_file:
             cmds += f' && llamafactory-cli export {self.temp_export_yaml_file}'
