@@ -1,9 +1,12 @@
 import json
-from typing import Optional, List, Union, Any
+import uuid
+from typing import Callable, Optional, List, Union, Any
 
-from ...common import LazyLLMRegisterMetaClass, package
+from lazyllm.flow.flow import Pipeline
 
-def is_number(s: str):
+from ...common import LazyLLMRegisterMetaClass, package, Finalizer
+
+def _is_number(s: str):
     try:
         int(s)
         return True
@@ -68,8 +71,53 @@ Examples:
     def __call__(self, *msg):
         return self.format(msg[0] if len(msg) == 1 else package(msg))
 
+    def __or__(self, other):
+        if not isinstance(other, LazyLLMFormatterBase):
+            return NotImplemented
+        return PipelineFormatter(other.__ror__(self))
+
+    def __ror__(self, f: Callable) -> Pipeline:
+        if isinstance(f, Pipeline):
+            if not f._capture:
+                _ = Finalizer(lambda: setattr(f, '_capture', True), lambda: setattr(f, '_capture', False))
+            f._add(str(uuid.uuid4().hex) if len(f._item_names) else None, self)
+            return f
+        return Pipeline(f, self)
+
+
+class PipelineFormatter(LazyLLMFormatterBase):
+    def __init__(self, formatter: Pipeline):
+        self._formatter = formatter
+
+    def _parse_py_data_by_formatter(self, py_data):
+        return self._formatter(py_data)
+
+    def __or__(self, other):
+        if isinstance(other, LazyLLMFormatterBase):
+            if isinstance(other, PipelineFormatter): other = other._formatter
+            return PipelineFormatter(self._formatter | other)
+        return NotImplemented
+
 
 class JsonLikeFormatter(LazyLLMFormatterBase):
+    """This class is used to extract subfields from nested structures (like dicts, lists, tuples) using a JSON-like indexing syntax.
+
+The behavior is driven by a formatter string similar to Python-style slicing and dictionary access:
+
+- `[0]` fetches the first item
+- `[0][{key}]` accesses the `key` field in the first item
+- `[0,1][{a,b}]` fetches the `a` and `b` fields from the first and second items
+- `[::2]` does slicing with a step of 2
+- `*[0][{x}]` means return a wrapped/structured result
+
+Args:
+    formatter (str, optional): A format string that controls how to slice and extract the structure. If None, the input will be returned directly.
+
+
+Examples:
+    >>> from lazyllm.components.formatter.formatterbase import JsonLikeFormatter
+    >>> formatter = JsonLikeFormatter("[{a,b}]")
+    """
     class _ListIdxes(tuple): pass
     class _DictKeys(tuple): pass
 
@@ -101,9 +149,9 @@ class JsonLikeFormatter(LazyLLMFormatterBase):
             elif ":" in dim:
                 assert ',' not in dim, '[a, b:c] is not supported'
                 parts = dim.split(":")
-                start = int(parts[0]) if is_number(parts[0]) else None
-                end = int(parts[1]) if len(parts) > 1 and is_number(parts[1]) else None
-                step = int(parts[2]) if len(parts) > 2 and is_number(parts[2]) else None
+                start = int(parts[0]) if _is_number(parts[0]) else None
+                end = int(parts[1]) if len(parts) > 1 and _is_number(parts[1]) else None
+                step = int(parts[2]) if len(parts) > 2 and _is_number(parts[2]) else None
                 slices.append(slice(start, end, step))
             elif ',' in dim:
                 slices.append(__class__._ListIdxes(d.strip() for d in dim.split(',') if d.strip()))
@@ -145,7 +193,12 @@ class JsonLikeFormatter(LazyLLMFormatterBase):
         else: return self._parse_py_data_by_formatter(_impl(data, curr_slice), slices=slices[1:])
 
 
-class PythonFormatter(JsonLikeFormatter): pass
+class PythonFormatter(JsonLikeFormatter):
+    """Reserved formatter class for supporting Python-style data extraction syntax. To be developed.
+
+Currently inherits from JsonLikeFormatter with no additional behavior.
+"""
+    pass
 
 
 class EmptyFormatter(LazyLLMFormatterBase):
@@ -301,17 +354,64 @@ Examples:
 LAZYLLM_QUERY_PREFIX = '<lazyllm-query>'
 
 def encode_query_with_filepaths(query: str = None, files: Union[str, List[str]] = None) -> str:
+    """Encodes a query string together with associated file paths into a structured string format with context.
+
+If file paths are provided, the query and file list will be wrapped into a JSON object prefixed with ``__lazyllm_docs__``. Otherwise, it returns the original query string.
+
+Args:
+    query (str): The user query string. Defaults to an empty string.
+    files (str or List[str]): File path(s) associated with the query. Can be a single string or a list of strings.
+
+Returns:
+    str: A structured encoded query string or the raw query.
+
+Raises:
+    AssertionError: If `files` is not a string or list of strings.
+
+
+Examples:
+    >>> from lazyllm.components.formatter import encode_query_with_filepaths
+    
+    >>> # Encode a query along with associated documentation files
+    >>> encode_query_with_filepaths("Generate questions based on the document", files=["a.md"])
+    '<lazyllm-query>{"query": "Generate questions based on the document", "files": ["a.md"]}'
+    """
     query = query if query else ''
-    query_with_docs = {'query': query, 'files': files}
     if files:
         if isinstance(files, str): files = [files]
         assert isinstance(files, list), "files must be a list."
         assert all(isinstance(item, str) for item in files), "All items in files must be strings"
-        return LAZYLLM_QUERY_PREFIX + json.dumps(query_with_docs)
+        return LAZYLLM_QUERY_PREFIX + json.dumps({'query': query, 'files': files})
     else:
         return query
 
 def decode_query_with_filepaths(query_files: str) -> Union[dict, str]:
+    """Decodes a structured query string into a dictionary containing the original query and file paths.
+
+If the input string starts with the special prefix ``__lazyllm_docs__``, it attempts to parse the JSON content; otherwise, it returns the raw query string as-is.
+
+Args:
+    query_files (str): The encoded query string that may include both query and file paths.
+
+Returns:
+    Union[dict, str]: A dictionary containing 'query' and 'files' if structured, otherwise the original query string.
+
+Raises:
+    AssertionError: If the input is not a string.
+    ValueError: If the string is prefixed but JSON decoding fails.
+
+
+Examples:
+    >>> from lazyllm.components.formatter import decode_query_with_filepaths
+    
+    >>> # Decode a structured query with files
+    >>> decode_query_with_filepaths('<lazyllm-query>{"query": "Summarize the content", "files": ["doc.md"]}')
+    {'query': 'Summarize the content', 'files': ['doc.md']}
+    
+    >>> # Decode a plain string without files
+    >>> decode_query_with_filepaths("This is just a simple question")
+    'This is just a simple question'
+    """
     assert isinstance(query_files, str), "query_files must be a str."
     query_files = query_files.strip()
     if query_files.startswith(LAZYLLM_QUERY_PREFIX):
@@ -324,6 +424,30 @@ def decode_query_with_filepaths(query_files: str) -> Union[dict, str]:
         return query_files
 
 def lazyllm_merge_query(*args: str) -> str:
+    """Merges multiple query strings (potentially with associated file paths) into a single structured query string.
+
+Each argument can be a plain query string or a structured query created by ``encode_query_with_filepaths``. The function decodes each input, concatenates all query texts, and merges the associated file paths. The final result is re-encoded into a single query string with unified context.
+
+Args:
+    *args (str): Multiple query strings. Each can be either plain text or an encoded structured query with files.
+
+Returns:
+    str: A single structured query string containing the merged query and file paths.
+
+
+Examples:
+    >>> from lazyllm.components.formatter import encode_query_with_filepaths, lazyllm_merge_query
+    
+    >>> # Merge two structured queries with English content and associated files
+    >>> q1 = encode_query_with_filepaths("Please summarize document one", files=["doc1.md"])
+    >>> q2 = encode_query_with_filepaths("Add details from document two", files=["doc2.md"])
+    >>> lazyllm_merge_query(q1, q2)
+    '<lazyllm-query>{"query": "Please summarize document oneAdd details from document two", "files": ["doc1.md", "doc2.md"]}'
+    
+    >>> # Merge plain English text queries without documents
+    >>> lazyllm_merge_query("What is AI?", "Explain deep learning.")
+    'What is AI?Explain deep learning.'
+    """
     if len(args) == 1:
         return args[0]
     for item in args:
@@ -354,6 +478,23 @@ def _lazyllm_get_file_list(files: Any) -> list:
         raise TypeError(f'Not supported type: {type(files)}.')
 
 class FileFormatter(LazyLLMFormatterBase):
+    """A formatter that transforms query strings with document context between structured formats.
+
+Supports three modes:
+- "decode": Decodes structured query strings into dictionaries with `query` and `files`.
+- "encode": Encodes a dictionary with `query` and `files` into a structured query string.
+- "merge": Merges multiple structured query strings into one.
+
+Args:
+    formatter (str): The operation mode. Must be one of "decode", "encode", or "merge". Defaults to "decode".
+
+
+Examples:
+    >>> from lazyllm.components.formatter import FileFormatter
+    
+    >>> # Decode mode
+    >>> fmt = FileFormatter('decode')
+    """
 
     def __init__(self, formatter: str = 'decode'):
         self._mode = formatter.strip().lower()
