@@ -9,16 +9,16 @@ import re
 class LazyLLMPrompterBase(metaclass=LazyLLMRegisterMetaClass):
     """The base class of Prompter. A custom Prompter needs to inherit from this base class and set the Prompt template and the Instruction template using the `_init_prompt` function provided by the base class, as well as the string used to capture results. Refer to  [prompt](/Best%20Practice/prompt) for further understanding of the design philosophy and usage of Prompts.
 
-Both the Prompt template and the Instruction template use ``{}`` to indicate the fields to be filled in. The fields that can be included in the Prompt are `system`, `history`, `tools`, `user` etc., while the fields that can be included in the instruction_template are `instruction` and `extro_keys`. If the ``instruction`` field is a string, it is considered as a system instruction; if it is a dictionary, it can only contain the keys ``user`` and ``system``. ``user`` represents the user input instruction, which is placed before the user input in the prompt, and ``system`` represents the system instruction, which is placed after the system prompt in the prompt.
+Both the Prompt template and the Instruction template use ``{}`` to indicate the fields to be filled in. The fields that can be included in the Prompt are `system`, `history`, `tools`, `user` etc., while the fields that can be included in the instruction_template are `instruction` and `extra_keys`. If the ``instruction`` field is a string, it is considered as a system instruction; if it is a dictionary, it can only contain the keys ``user`` and ``system``. ``user`` represents the user input instruction, which is placed before the user input in the prompt, and ``system`` represents the system instruction, which is placed after the system prompt in the prompt.
 ``instruction`` is passed in by the application developer, and the ``instruction`` can also contain ``{}`` to define fillable fields, making it convenient for users to input additional information.
 
 
 Examples:
     >>> from lazyllm.components.prompter import PrompterBase
     >>> class MyPrompter(PrompterBase):
-    ...     def __init__(self, instruction = None, extro_keys = None, show = False):
+    ...     def __init__(self, instruction = None, extra_keys = None, show = False):
     ...         super(__class__, self).__init__(show)
-    ...         instruction_template = f'{instruction}\\n{{extro_keys}}\\n'.replace('{extro_keys}', PrompterBase._get_extro_key_template(extro_keys))
+    ...         instruction_template = f'{instruction}\\n{{extra_keys}}\\n'.replace('{extra_keys}', PrompterBase._get_extro_key_template(extra_keys))
     ...         self._init_prompt("<system>{system}</system>\\n</instruction>{instruction}</instruction>{history}\\n{input}\\n, ## Response::", instruction_template, '## Response::')
     ... 
     >>> p = MyPrompter('ins {instruction}')
@@ -46,11 +46,11 @@ Examples:
             self._split = split
 
     @staticmethod
-    def _get_extro_key_template(extro_keys, prefix='Here are some extra messages you can referred to:\n\n'):
-        if extro_keys:
-            if isinstance(extro_keys, str): extro_keys = [extro_keys]
-            assert isinstance(extro_keys, (tuple, list)), 'Only str, tuple[str], list[str] are supported'
-            return prefix + ''.join([f"### {k}:\n{{{k}}}\n\n" for k in extro_keys])
+    def _get_extro_key_template(extra_keys, prefix='Here are some extra messages you can referred to:\n\n'):
+        if extra_keys:
+            if isinstance(extra_keys, str): extra_keys = [extra_keys]
+            assert isinstance(extra_keys, (tuple, list)), 'Only str, tuple[str], list[str] are supported'
+            return prefix + ''.join([f"### {k}:\n{{{k}}}\n\n" for k in extra_keys])
         return ''
 
     def _handle_tool_call_instruction(self):
@@ -190,6 +190,15 @@ Examples:
         return dict(messages=history, tools=tools) if tools else dict(messages=history)
 
     def pre_hook(self, func: Optional[Callable] = None):
+        """Sets a pre-processing hook function, allowing external custom processing of input data before prompt generation.
+
+Args:
+    func (Optional[Callable]): A callable object to be used as the pre-processing hook function, which receives and processes input data.
+
+**Returns:**
+
+- LazyLLMPrompterBase: Returns the instance itself to support method chaining.
+"""
         self._pre_hook = func
         return self
 
@@ -246,7 +255,38 @@ Args:
         return output if getattr(self, "_split", None) is None else output.split(self._split)[-1]
 
 class EmptyPrompter(LazyLLMPrompterBase):
+    """An empty prompt generator that inherits from `LazyLLMPrompterBase`, and directly returns the original input.
+
+This class performs no formatting and is useful for debugging, testing, or as a placeholder.
+
+
+Examples:
+    >>> from lazyllm.components.prompter import EmptyPrompter
+    
+    >>> prompter = EmptyPrompter()
+    
+    >>> prompter.generate_prompt("Hello LazyLLM")
+    'Hello LazyLLM'
+    
+    >>> prompter.generate_prompt({"query": "Tell me a joke"})
+    {'query': 'Tell me a joke'}
+    
+    >>> # Even with additional parameters, the input is returned unchanged
+    >>> prompter.generate_prompt("No-op", history=[["Hi", "Hello"]], tools=[{"name": "search"}], label="debug")
+    'No-op'
+    """
 
     def generate_prompt(self, input, history=None, tools=None, label=None, show=False):
+        """A prompt passthrough implementation that inherits from `LazyLLMPrompterBase`.
+
+This method directly returns the input without any formatting. Useful for debugging, testing, or placeholder use.
+
+Args:
+    input (Any): The input to be returned directly as the prompt.
+    history (Option[List[List | Dict]]): Dialogue history, ignored. Defaults to None.
+    tools (Option[List[Dict]]): Tool definitions, ignored. Defaults to None.
+    label (Option[str]): Label, ignored. Defaults to None.
+    show (bool): Whether to print the returned prompt. Defaults to False.
+"""
         if self._show or show: LOG.info(input)
         return input
