@@ -7,7 +7,6 @@ from abc import ABC, abstractmethod
 
 import lazyllm
 from .model_mapping import model_name_mapping, model_provider, model_groups
-from lazyllm.common.common import EnvVarContextManager
 
 lazyllm.config.add('model_source', str, 'modelscope', 'MODEL_SOURCE')
 lazyllm.config.add('model_cache_dir', str, os.path.join(os.path.expanduser('~'), '.lazyllm', 'model'),
@@ -62,25 +61,25 @@ Examples:
     >>> downloader = ModelManager(model_source='modelscope')
     >>> downloader.download('chatglm3-6b')
     """
-    def __init__(self, model_source=lazyllm.config['model_source'],
-                 token=lazyllm.config['model_source_token'],
-                 cache_dir=lazyllm.config['model_cache_dir'],
-                 model_path=lazyllm.config['model_path']):
-        self.model_source = model_source
+    def __init__(self, model_source, token=lazyllm.config['model_source_token'],
+                 cache_dir=lazyllm.config['model_cache_dir'], model_path=lazyllm.config['model_path']):
+        self.model_source = model_source or lazyllm.config['model_source']
         self.token = token or None
         self.cache_dir = cache_dir
         self.model_paths = model_path.split(":") if len(model_path) > 0 else []
         if self.model_source == 'huggingface':
-            self.hub_downloader = HuggingfaceDownloader(token=self.token)
+            self.hub_downloader = _HuggingfaceDownloader(token=self.token)
         else:
-            self.hub_downloader = ModelscopeDownloader(token=self.token)
+            self.hub_downloader = _ModelscopeDownloader(token=self.token)
             if self.model_source != 'modelscope':
-                lazyllm.LOG.warning("Only support Huggingface and Modelscope currently. "
-                                    f"Unsupported model source: {self.model_source}. Forcing use of Modelscope.")
+                lazyllm.LOG.error("Only support Huggingface and Modelscope currently. "
+                                  f"Unsupported model source: {self.model_source}. Forcing use of Modelscope.")
 
-    @classmethod
-    def get_model_type(cls, model) -> str:
-        assert isinstance(model, str) and len(model) > 0, "model name should be a non-empty string"
+    @staticmethod
+    @functools.lru_cache
+    def get_model_type(model) -> str:
+        assert isinstance(model, str) and len(model) > 0, f'model name should be a non-empty string, get {model}'
+        __class__._try_add_mapping(model)
         for name, info in model_name_mapping.items():
             if 'type' not in info: continue
 
@@ -92,27 +91,30 @@ Examples:
                 return info['type']
         return 'llm'
 
-    @classmethod
-    def get_model_name(cls, model) -> str:
+    @staticmethod
+    @functools.lru_cache
+    def _get_model_name(model) -> str:
         search_string = os.path.basename(model)
+        __class__._try_add_mapping(search_string)
         for model_name, sources in model_name_mapping.items():
             if model_name.lower() == search_string.lower() or any(
-                os.path.basename(source_file).lower() == search_string.lower()
-                for source_file in sources["source"].values()
-            ):
+                    os.path.basename(source_file).lower() == search_string.lower()
+                    for source_file in sources["source"].values()):
                 return model_name
         return ""
 
-    @classmethod
-    def get_model_prompt_keys(cls, model) -> dict:
-        model_name = cls.get_model_name(model)
+    @staticmethod
+    @functools.lru_cache
+    def get_model_prompt_keys(model) -> dict:
+        model_name = __class__._get_model_name(model)
+        __class__._try_add_mapping(model_name)
         if model_name and "prompt_keys" in model_name_mapping[model_name.lower()]:
             return model_name_mapping[model_name.lower()]["prompt_keys"]
         else:
             return dict()
 
-    @classmethod
-    def validate_model_path(cls, model_path):
+    @staticmethod
+    def validate_model_path(model_path):
         extensions = {'.pt', '.bin', '.safetensors'}
         for _, _, files in os.walk(model_path):
             for file in files:
@@ -120,13 +122,14 @@ Examples:
                     return True
         return False
 
-    def _try_add_mapping(self, model):
+    @staticmethod
+    def _try_add_mapping(model):
         model_base = os.path.basename(model)
         model = model_base.lower()
         if model in model_name_mapping.keys():
             return
         matched_model_prefix = next((key for key in model_provider if model.startswith(key)), None)
-        if matched_model_prefix and self.model_source in model_provider[matched_model_prefix]:
+        if matched_model_prefix:
             matching_keys = [key for key in model_groups.keys() if key in model]
             if matching_keys:
                 matched_groups = max(matching_keys, key=len)
@@ -137,17 +140,15 @@ Examples:
 
     def download(self, model='', call_back=None):
         assert isinstance(model, str), "model name should be a string."
-        self._try_add_mapping(model)
-        # Dummy or local model.
         if len(model) == 0 or model[0] in (os.sep, '.', '~') or os.path.isabs(model): return model
-
-        model_at_path = self._model_exists_at_path(model)
-        if model_at_path: return model_at_path
-
+        if (model_at_path := self._model_exists_at_path(model)): return model_at_path
         if self.model_source == '' or self.model_source not in ('huggingface', 'modelscope'):
-            print("[WARNING] model automatic downloads only support Huggingface and Modelscope currently.")
+            lazyllm.LOG.error("model automatic downloads only support Huggingface and Modelscope currently.")
             return model
 
+        self._try_add_mapping(model)
+        if model_name_mapping.get(model.lower(), {}).get('download_by_other'): return model
+
         if model.lower() in model_name_mapping.keys() and \
                 self.model_source in model_name_mapping[model.lower()]['source'].keys():
             full_model_dir = os.path.join(self.cache_dir, model)
@@ -175,11 +176,11 @@ Examples:
             model_save_dir = self._do_download(model_name_for_download, call_back)
             return model_save_dir
 
-    def validate_token(self):
+    def _validate_token(self):
         return self.hub_downloader.verify_hub_token()
 
-    def validate_model_id(self, model_id):
-        return self.hub_downloader.verify_model_id(model_id)
+    def _validate_model_id(self, model_id):
+        return self.hub_downloader._verify_model_id(model_id)
 
     def _model_exists_at_path(self, model_name):
         if len(self.model_paths) == 0:
@@ -196,7 +197,7 @@ Examples:
         for model_path in self.model_paths:
             if len(model_path) == 0: continue
             if model_path[0] != os.sep:
-                print(f"[WARNING] skipping path {model_path} as only absolute paths is accepted.")
+                lazyllm.LOG.warning(f"skipping path {model_path} as only absolute paths is accepted.")
                 continue
             for model_dir in model_dirs:
                 full_model_dir = os.path.join(model_path, model_dir)
@@ -216,9 +217,9 @@ Examples:
         try:
             return self.hub_downloader.download(model, full_model_dir, call_back)
         # Use `BaseException` to capture `KeyboardInterrupt` and normal `Exceptioin`.
-        except BaseException as e:
+        except BaseException as e:  # noqa B036
             lazyllm.LOG.warning(f"Download encountered an error: {e}")
-            if not self.token:
+            if not self.token and 'Permission denied' not in str(e):
                 lazyllm.LOG.warning('Token is empty, which may prevent private models from being downloaded, '
                                     'as indicated by "the model does not exist." Please set the token with the '
                                     'environment variable LAZYLLM_MODEL_SOURCE_TOKEN to download private models.')
@@ -227,7 +228,7 @@ Examples:
                 lazyllm.LOG.warning(f"{full_model_dir} removed due to exceptions.")
         return False
 
-class HubDownloader(ABC):
+class _HubDownloader(ABC):
 
     def __init__(self, token=None):
         self._token = token if self._verify_hub_token(token) else None
@@ -242,7 +243,7 @@ class HubDownloader(ABC):
         pass
 
     @abstractmethod
-    def verify_model_id(self, model_id):
+    def _verify_model_id(self, model_id):
         pass
 
     @abstractmethod
@@ -261,7 +262,7 @@ class HubDownloader(ABC):
                 try:
                     call_back(n, total)
                 except Exception as e:
-                    print(f"Error in callback: {e}")
+                    lazyllm.LOG.error(f"Error in callback: {e}")
             time.sleep(1)
 
     def _get_current_files_size(self, model_dir):
@@ -296,29 +297,12 @@ class HubDownloader(ABC):
     def verify_hub_token(self):
         return True if self._token else False
 
-class HuggingfaceDownloader(HubDownloader):
-
-    def _envs_manager(func):
-
-        @functools.wraps(func)
-        def wrapper(self, *args, **kwargs):
-            env_vars = {'https_proxy': lazyllm.config['https_proxy'] or os.environ.get("https_proxy", None),
-                        'http_proxy': lazyllm.config['http_proxy'] or os.environ.get("http_proxy", None)}
-            with EnvVarContextManager(env_vars):
-                if not os.environ.get("https_proxy", None):
-                    lazyllm.LOG.warning('If there is no download response or if downloads repeatedly fail over an '
-                                        'extended period, please set the `LAZYLLM_HTTPS_PROXY` environment variable '
-                                        'to configure a proxy. Do not directly set the `https_proxy` and `http_proxy` '
-                                        'environment variables in your environment, as doing so may disrupt model '
-                                        'deployment and result in deployment failures.')
-                return func(self, *args, **kwargs)
-        return wrapper
+class _HuggingfaceDownloader(_HubDownloader):
 
     def _build_hub_api(self, token):
         from huggingface_hub import HfApi
         return HfApi(token=token)
 
-    @_envs_manager
     def _verify_hub_token(self, token):
         from huggingface_hub import HfApi
         api = HfApi()
@@ -329,8 +313,7 @@ class HuggingfaceDownloader(HubDownloader):
             if token: lazyllm.LOG.warning(f'Huggingface token {token} verified failed')
             return False
 
-    @_envs_manager
-    def verify_model_id(self, model_id):
+    def _verify_model_id(self, model_id):
         try:
             self._api.model_info(model_id)
             return True
@@ -338,18 +321,16 @@ class HuggingfaceDownloader(HubDownloader):
             lazyllm.LOG.warning('Verify failed: ', e)
             return False
 
-    @_envs_manager
     def _do_download(self, model_id, model_dir):
         from huggingface_hub import snapshot_download
         # refer to https://huggingface.co/docs/huggingface_hub/v0.23.1/en/package_reference/file_download
-        if not self.verify_model_id(model_id):
+        if not self._verify_model_id(model_id):
             lazyllm.LOG.warning(f"Invalid model id:{model_id}")
             return False
         downloaded_path = snapshot_download(repo_id=model_id, local_dir=model_dir, token=self._token)
         lazyllm.LOG.info(f"model downloaded at {downloaded_path}")
         return downloaded_path
 
-    @_envs_manager
     def _get_repo_files(self, model_id):
         assert self._api
         orgin_info = self._api.list_repo_tree(model_id, expand=True, recursive=True)
@@ -363,7 +344,7 @@ class HuggingfaceDownloader(HubDownloader):
                 })
         return hub_model_info
 
-class ModelscopeDownloader(HubDownloader):
+class _ModelscopeDownloader(_HubDownloader):
 
     def _build_hub_api(self, token):
         from modelscope.hub.api import HubApi
@@ -382,7 +363,7 @@ class ModelscopeDownloader(HubDownloader):
             if token: lazyllm.LOG.warning(f'Modelscope token {token} verified failed')
             return False
 
-    def verify_model_id(self, model_id):
+    def _verify_model_id(self, model_id):
         try:
             self._api.get_model(model_id)
             return True
@@ -393,7 +374,7 @@ class ModelscopeDownloader(HubDownloader):
     def _do_download(self, model_id, model_dir):
         from modelscope.hub.snapshot_download import snapshot_download
         # refer to https://www.modelscope.cn/docs/models/download
-        if not self.verify_model_id(model_id):
+        if not self._verify_model_id(model_id):
             lazyllm.LOG.warning(f"Invalid model id:{model_id}")
             return False
         downloaded_path = snapshot_download(model_id=model_id, local_dir=model_dir)
