@@ -17,6 +17,24 @@ model_groups = {
             'system': "You are a helpful assistant."
             },
     },
+    "deepseek-r1-distill-qwen": {
+        "prompt_keys": {
+            'sos': '<|im_start|>system\n', 'soh': '<|im_start|>user\n', 'soa': '<|im_start|>assistant\n\n<think>', 'soe': '<|im_start|>environment\n', 'eos': '<|im_end|>\n', 'eoh': '<|im_end|>\n', 'eoa': '<|im_end|>', 'eoe': '<|im_end|>\n', 'separator': '\n', 'stop_words': ['<|im_end|>'], 'tool_start_token': '<|action_start|><|function|>', 'tool_end_token': '<|action_end|>', 'tool_args_token': "<|args|>",
+            'system': "You are a helpful assistant."
+            },
+    },
+    "deepseek-r1-distill-llama": {
+        "prompt_keys": {
+            'sos': '<|start_header_id|>system<|end_header_id|>\n\n', 'soh': '<|start_header_id|>user<|end_header_id|>\n\n', 'soa': '<|start_header_id|>assistant<|end_header_id|>\n\n<think>', 'eos': '<|eot_id|>', 'eoh': '<|eot_id|>', 'eoa': '<|eot_id|>', 'stop_words': ['<|eot_id|>', '<|end_of_text|>', '<|eom_id|>'],
+            'system': "You are a helpful assistant.",
+            },
+    },
+    "deepseek": {
+        "prompt_keys": {
+            'sos': '<｜begin▁of▁sentence｜>', 'soh': '<｜User｜>', 'soa': '<｜Assistant｜>', 'eos': '', 'eoh': '', 'eoa': '<｜end▁of▁sentence｜>', 'stop_words': ['<｜end▁of▁sentence｜>'],
+            'system': "",
+            },
+    },    
     "internlm": {
         "prompt_keys": {
             'sos': '<|System|>:', 'soh': '<|User|>:', 'soa': '<|Bot|>:', 'eos': '\n', 'eoh': '\n', 'eoa': '<eoa>', 'separator': '\n', 'stop_words': ['<eoa>'],
@@ -102,6 +120,10 @@ model_provider = {
     "qwen": {
         "huggingface": "Qwen",
         "modelscope": "qwen"
+    },
+    "deepseek":{
+        "huggingface": "deepseek-ai",
+        "modelscope": "deepseek-ai"
     }
 }
 
@@ -153,6 +175,20 @@ model_name_mapping = {
         },
         "type": "reranker"
     },
+    "bge-reranker-v2-m3": {
+        "source": {
+            "huggingface": "BAAI/bge-reranker-v2-m3",
+            "modelscope": "BAAI/bge-reranker-v2-m3"
+        },
+        "type": "reranker"
+    },
+    "bge-vl-v1.5-mmeb": {
+        "source": {
+            "huggingface": "BAAI/BGE-VL-v1.5-mmeb",
+            "modelscope": "BAAI/BGE-VL-v1.5-mmeb"
+        },
+        "type": "cross_modal_embed" # image - text
+    },
     "chattts": {
         "source": {
             "huggingface": "2Noise/ChatTTS",
@@ -160,6 +196,13 @@ model_name_mapping = {
         },
         "type": "tts"
     },
+    "chattts-new": {
+        "source": {
+            "huggingface": "2Noise/ChatTTS",
+            "modelscope": "AI-ModelScope/ChatTTS"
+        },
+        "type": "tts"
+    },
     "internvl-chat-v1-5": {
         "source": {
             "huggingface": "OpenGVLab/InternVL-Chat-V1-5",
@@ -202,6 +245,20 @@ model_name_mapping = {
         },
         "type": "vlm"
     },
+    "qwen2.5-vl-3b-instruct": {
+        "source": {
+            "huggingface": "Qwen/Qwen2.5-VL-3B-Instruct",
+            "modelscope": "Qwen/Qwen2.5-VL-3B-Instruct"
+        },
+        "type": "vlm"
+    },
+    "qwen2.5-vl-32b-instruct": {
+        "source": {
+            "huggingface": "Qwen/Qwen2.5-VL-32B-Instruct",
+            "modelscope": "Qwen/Qwen2.5-VL-32B-Instruct"
+        },
+        "type": "vlm"
+    },
     "musicgen-medium": {
         "source": {
             "huggingface": "facebook/musicgen-medium",
@@ -229,5 +286,53 @@ model_name_mapping = {
             "modelscope": "AI-ModelScope/stable-diffusion-3-medium-diffusers"
         },
         "type": "sd"
+    },
+    "stable-diffusion-3_5-large": {
+        "source": {
+            "huggingface": "stabilityai/stable-diffusion-3.5-large",
+            "modelscope": "AI-ModelScope/stable-diffusion-3.5-large"
+        },
+        "type": "sd"
+    },
+    "flux.1-dev": {
+        "source": {
+            "huggingface": "black-forest-labs/FLUX.1-dev",
+            "modelscope": "MusePublic/489_ckpt_FLUX_1"
+        },
+        "type": "sd"
+    },
+    "cogview4-6b": {
+        "source": {
+            "huggingface": "THUDM/CogView4-6B",
+            "modelscope": "ZhipuAI/CogView4-6B"
+        },
+        "type": "sd"
+    },
+    "wan2_1-t2v-1_3b-diffusers": {
+        "source": {
+            "huggingface": "Wan-AI/Wan2.1-T2V-1.3B-Diffusers",
+            "modelscope": "Wan-AI/Wan2.1-T2V-1.3B-Diffusers"
+        },
+        "type": "sd"
+    },
+    "pp-ocrv4_server": {
+        "source": {},
+        "download_by_other":True,
+        "type": "ocr"
+    },
+    "pp-ocrv4_mobile": {
+        "source": {},
+        "download_by_other":True,
+        "type": "ocr"
+    },
+    "pp-ocrv5_server": {
+        "source": {},
+        "download_by_other":True,
+        "type": "ocr"
+    },
+    "pp-ocrv5_mobile": {
+        "source": {},
+        "download_by_other":True,
+        "type": "ocr"
     }
 }
