@@ -1,8 +1,9 @@
 import os
 from enum import Enum
 import json
-from typing import List, Union
+from typing import List, Union, Optional
 from contextlib import contextmanager
+import logging
 
 
 class Mode(Enum):
@@ -17,7 +18,7 @@ class Config(object):
 environment variables, or specify them explicitly. it can export all configuration items as well.
 The Config module automatically generates an object named 'config' containing all configurations.
 """
-    def __init__(self, prefix='LAZYLLM', home=os.path.join(os.path.expanduser('~'), '.lazyllm')):
+    def __init__(self, prefix='LAZYLLM', home=os.path.join(os.path.expanduser('~'), '.lazyllm')):  # noqa B008
         self._config_params = dict()
         self._env_map_name = dict()
         self.prefix = prefix
@@ -62,7 +63,7 @@ Args:
 
 Args:
     None.
-    
+
 
 
 Examples:
@@ -77,12 +78,19 @@ Examples:
 
     @contextmanager
     def temp(self, name, value):
+        """
+Temporarily override a configuration item within a context manager scope, restoring the original value upon exit.
+
+Args:
+    name (str): The name of the configuration item to temporarily change.
+    value (Any): The temporary value to set.
+"""
         old_value = self[name]
         self.impl[name] = value
         yield
         self.impl[name] = old_value
 
-    def add(self, name, type, default=None, env=None):
+    def add(self, name: str, type: type, default: Optional[Union[int, str, bool]] = None, env: Union[str, dict] = None):
         """Loads value into LazyLLM configuration item. The function first attempts to find the value with the given name from the
 dict loaded from config.json. If found, it removes the key from the dict and saves the value to the config.
 If 'env' is a string, the function calls getenv to look for the corresponding LazyLLM environment variable, and if
@@ -100,8 +108,8 @@ Args:
         update_params = (type, default, env)
         if name not in self._config_params or self._config_params[name] != update_params:
             if name in self._config_params:
-                print(f"Warning: The default configuration parameter {name}({self._config_params[name]}) "
-                      f"has been added, but a new {name}({update_params}) has been added repeatedly.")
+                logging.warning(f"The default configuration parameter {name}({self._config_params[name]}) "
+                                f"has been added, but a new {name}({update_params}) has been added repeatedly.")
             self._config_params.update({name: update_params})
             if isinstance(env, str):
                 self._env_map_name[('lazyllm_' + env).upper()] = name
@@ -111,7 +119,8 @@ Args:
         self._update_impl(name, type, default, env)
         return self
 
-    def _update_impl(self, name, type, default=None, env=None):
+    def _update_impl(self, name: str, type: type, default: Optional[Union[int, str, bool]] = None,
+                     env: Union[str, dict] = None):
         self.impl[name] = self.cfgs.pop(name) if name in self.cfgs else default
         if isinstance(env, dict):
             for k, v in env.items():
@@ -125,15 +134,26 @@ Args:
 
     def __getitem__(self, name):
         try:
+            if isinstance(name, bytes): name = name.decode('utf-8')
             return self.impl[name]
         except KeyError:
-            raise RuntimeError(f'Key {name} is not in lazyllm global config')
+            raise RuntimeError(f'Key `{name}` is not in lazyllm global config')
 
     def __str__(self):
         return str(self.impl)
 
-    def refresh(self, targets: Union[str, List[str]] = None) -> None:
+    def refresh(self, targets: Union[bytes, str, List[str]] = None) -> None:
+        """
+Refresh configuration items based on the latest environment variable values.  
+If `targets` is a string, updates the single corresponding configuration item;  
+if it's a list, updates multiple;  
+if None, scans all environment-variable-mapped configuration items and updates them.
+
+Args:
+    targets (str | list[str] | None): Name of the config key or list of keys to refresh, or None to refresh all environment-backed keys.
+"""
         names = targets
+        if isinstance(targets, bytes): targets = targets.decode('utf-8')
         if isinstance(targets, str):
             names = targets.lower()
             if names.startswith('lazyllm_'):
@@ -144,7 +164,7 @@ Args:
             names = list(set([self._env_map_name[key] for key in curr_envs if key in self._env_map_name]))
         assert isinstance(names, list)
         for name in names:
-            self._update_impl(name, *self._config_params[name])
+            if name in self.impl: self._update_impl(name, *self._config_params[name])
 
 config = Config().add('mode', Mode, Mode.Normal, dict(DISPLAY=Mode.Display, DEBUG=Mode.Debug)
                 ).add('repr_ml', bool, False, 'REPR_USE_ML'
@@ -154,4 +174,5 @@ config = Config().add('mode', Mode, Mode.Normal, dict(DISPLAY=Mode.Display, DEBU
                 ).add('train_target_root', str, os.path.join(os.getcwd(), 'save_ckpt'), 'TRAIN_TARGET_ROOT'
                 ).add('infer_log_root', str, os.path.join(os.getcwd(), 'infer_log'), 'INFER_LOG_ROOT'
                 ).add('temp_dir', str, os.path.join(os.getcwd(), '.temp'), 'TEMP_DIR'
+                ).add('thread_pool_worker_num', int, 16, 'THREAD_POOL_WORKER_NUM'
                 )
