@@ -209,6 +209,7 @@ add_chinese_doc('ActionModule', '''\
 
 Args:
     action (Callable|list[Callable]): 被包装的对象，是一个或一组可执行的对象。
+    return_trace (bool): 是否开启 trace 模式，用于记录调用栈，默认为 ``False``。
 ''')
 
 add_english_doc('ActionModule', '''\
@@ -216,6 +217,7 @@ Used to wrap a Module around functions, modules, flows, Module, and other callab
 
 Args:
     action (Callable|list[Callable]): The object to be wrapped, which is one or a set of callable objects.
+    return_trace (bool): Whether to enable trace mode to record the execution stack. Defaults to ``False``.
 
 **Examples:**\n
 ```python
@@ -281,6 +283,42 @@ INFO: (lazyllm.launcher) PID: dummy finetune!, and init-args is {}
 
 ''')
 
+add_chinese_doc('ActionModule.forward', '''\
+执行被包装的 action，对输入参数进行前向计算。等效于调用该模块本身。
+
+Args:
+    args (list of callables or single callable): 传递给被包装 action 的位置参数。
+    kwargs (dict of callables): 传递给被包装 action 的关键字参数。
+
+**Returns:**\n
+- 任意类型：被包装 action 的执行结果。
+''')
+
+add_english_doc('ActionModule.forward', '''\
+Executes the wrapped action with the provided input arguments. Equivalent to directly calling the module.
+
+Args:
+    args (list of callables or single callable): Positional arguments to be passed to the wrapped action.
+    kwargs (dict of callables): Keyword arguments to be passed to the wrapped action.
+
+**Returns:**\n
+- Any: The result of executing the wrapped action.
+''')
+
+add_chinese_doc('ActionModule.submodules', '''\
+返回被包装 action 中所有属于 ModuleBase 类型的子模块。该属性会自动展开 Pipeline 中嵌套的模块。
+
+**Returns:**\n
+- list[ModuleBase]: 子模块列表
+''')
+
+add_english_doc('ActionModule.submodules', '''\
+Returns all submodules of type ModuleBase contained in the wrapped action. This automatically traverses any nested modules inside a Pipeline.
+
+**Returns:**\n
+- list[ModuleBase]: List of submodules
+''')
+
 # add_example('ActionModule', '''\
 # >>> import lazyllm
 # >>> def myfunc(input): return input + 1
@@ -308,14 +346,244 @@ INFO: (lazyllm.launcher) PID: dummy finetune!, and init-args is {}
 # ['get 16', 'get 24', 'get 32']
 # ''')
 
-add_chinese_doc('TrainableModule', '''\
-可训练的模块，所有的模型(包括llm、Embedding等)均通过TrainableModule提供服务
+add_chinese_doc('servermodule.LLMBase', '''\
+大语言模型模块的基类，继承自 ModuleBase。  
+负责管理流式输出、Prompt 和格式化器的初始化与切换，处理输入中的文件信息，支持实例共享。
 
 Args:
-    base_model (str): 基模型的名称或者路径，如果本地没有模型，且微调或部署的方法为finetune.auto/deploy.auto, 则会自动尝试下载
-    target_path (str): 微调任务的保存路径，如只推理，则可以不填
-    stream (bool): 是否流式输出。如果使用的推理引擎不支持流式，则此参数会被忽略
-    return_trace (bool): 是否将结果记录在trace中
+    stream (bool 或 dict): 是否启用流式输出或流式配置，默认为 False。
+    return_trace (bool): 是否返回执行过程的 trace，默认为 False。
+    init_prompt (bool): 是否在初始化时自动创建默认 Prompt，默认为 True。
+''')
+
+add_english_doc('servermodule.LLMBase', '''\
+Base class for large language model modules, inheriting from ModuleBase.  
+Manages initialization and switching of streaming output, prompts, and formatters; processes file information in inputs; supports instance sharing.
+
+Args:
+    stream (bool or dict): Whether to enable streaming output or streaming configuration, default is False.
+    return_trace (bool): Whether to return execution trace, default is False.
+    init_prompt (bool): Whether to automatically create a default prompt at initialization, default is True.
+''')
+
+add_chinese_doc('servermodule.LLMBase.prompt', '''\
+设置或切换 Prompt。支持 None、PrompterBase 子类或字符串/字典类型创建 ChatPrompter。
+
+Args:
+    prompt (str/dict/PrompterBase/None): 要设置的 Prompt。
+    history (list): 对话历史，仅当 prompt 为字符串或字典时有效。
+
+**Returns**\n
+- self: 便于链式调用。
+''')
+
+add_english_doc('servermodule.LLMBase.prompt', '''\
+Set or switch the prompt. Supports None, PrompterBase subclass, or string/dict to create ChatPrompter.
+
+Args:
+    prompt (str/dict/PrompterBase/None): The prompt to set.
+    history (list): Conversation history, only valid when prompt is str or dict.
+
+**Returns**\n
+- self: For chaining calls.
+''')
+
+add_chinese_doc('servermodule.LLMBase.formatter', '''\
+设置或切换输出格式化器。支持 None、FormatterBase 子类或可调用对象。
+
+Args:
+    format (FormatterBase/Callable/None): 格式化器对象或函数，默认为 None。
+
+**Returns**\n
+- self: 便于链式调用。
+''')
+
+add_english_doc('servermodule.LLMBase.formatter', '''\
+Set or switch the output formatter. Supports None, FormatterBase subclass or callable.
+
+Args:
+    format (FormatterBase/Callable/None): Formatter object or function, default is None.
+
+**Returns**\n
+- self: For chaining calls.
+''')
+
+add_chinese_doc('servermodule.LLMBase.share', '''\
+创建当前实例的浅拷贝，并可重新设置 prompt、formatter、stream 等属性。  
+适用于多会话或多 Agent 共享基础配置但个性化部分参数的场景。
+
+Args:
+    prompt (str/dict/PrompterBase/None): 新的 Prompt，可选。
+    format (FormatterBase/None): 新的格式化器，可选。
+    stream (bool/dict/None): 新的流式设置，可选。
+    history (list/None): 新的对话历史，仅在设置 Prompt 时有效。
+
+**Returns**\n
+- LLMBase: 新的共享实例。
+''')
+
+add_english_doc('servermodule.LLMBase.share', '''\
+Creates a shallow copy of the current instance, with optional resetting of prompt, formatter, and stream attributes.  
+Useful for scenarios where multiple sessions or agents share a base configuration but customize certain parameters.
+
+Args:
+    prompt (str/dict/PrompterBase/None): New prompt, optional.
+    format (FormatterBase/None): New formatter, optional.
+    stream (bool/dict/None): New streaming settings, optional.
+    history (list/None): New conversation history, effective only when setting prompt.
+
+**Returns**\n
+- LLMBase: The new shared instance.
+''')
+
+add_chinese_doc('TrainableModule', '''\
+可训练模块，所有模型（包括LLM、Embedding等）都通过TrainableModule提供服务
+
+<span style="font-size: 20px;">**`TrainableModule(base_model='', target_path='', *, stream=False, return_trace=False)`**</span>
+
+
+Args:
+    base_model (str): 基础模型的名称或路径。
+    target_path (str): 保存微调任务的路径。
+    source (str): 模型来源，如果未设置，将从环境变量LAZYLLM_MODEL_SOURCE读取。
+    stream (bool): 输出流式结果。     
+    return_trace (bool): 在trace中记录结果。
+
+<span style="font-size: 20px;">**`TrainableModule.trainset(v):`**</span>
+
+设置 TrainableModule 的训练集
+
+Args:
+    v (str): 训练/微调数据集的路径
+
+**示例:**\n
+```python
+>>> import lazyllm
+>>> m = lazyllm.module.TrainableModule().finetune_method(finetune.dummy).trainset('/file/to/path').deploy_method(None).mode('finetune')
+>>> m.update()
+INFO: (lazyllm.launcher) PID: dummy finetune!, and init-args is {}
+```
+
+<span style="font-size: 20px;">**`TrainableModule.train_method(v, **kw):`**</span>
+
+设置 TrainableModule 的训练方法（暂不支持继续预训练，预计下一版本支持）
+
+Args:
+    v (LazyLLMTrainBase): 训练方法，可选值包括 ``train.auto`` 等
+    kw (**dict): 训练方法所需的参数，对应 v 的参数
+
+<span style="font-size: 20px;">**`TrainableModule.finetune_method(v, **kw):`**</span>
+
+设置 TrainableModule 的微调方法及其参数
+
+Args:
+    v (LazyLLMFinetuneBase): 微调方法，可选值包括 ``finetune.auto`` / ``finetune.alpacalora`` / ``finetune.collie`` 等
+    kw (**dict): 微调方法所需的参数，对应 v 的参数
+
+**示例:**\n            
+```python
+>>> import lazyllm
+>>> m = lazyllm.module.TrainableModule().finetune_method(finetune.dummy).deploy_method(None).mode('finetune')
+>>> m.update()
+INFO: (lazyllm.launcher) PID: dummy finetune!, and init-args is {}    
+```
+
+<span style="font-size: 20px;">**`TrainableModule.deploy_method(v, **kw):`**</span>
+
+设置 TrainableModule 的部署方法及其参数
+
+Args:
+    v (LazyLLMDeployBase): 部署方法，可选值包括 ``deploy.auto`` / ``deploy.lightllm`` / ``deploy.vllm`` 等
+    kw (**dict): 部署方法所需的参数，对应 v 的参数
+
+**示例:**\n
+```python
+>>> import lazyllm
+>>> m = lazyllm.module.TrainableModule().deploy_method(deploy.dummy).mode('finetune')
+>>> m.evalset([1, 2, 3])
+>>> m.update()
+INFO: (lazyllm.launcher) PID: dummy finetune!, and init-args is {}
+>>> m.eval_result
+["reply for 1, and parameters is {'do_sample': False, 'temperature': 0.1}", "reply for 2, and parameters is {'do_sample': False, 'temperature': 0.1}", "reply for 3, and parameters is {'do_sample': False, 'temperature': 0.1}"]                                   
+```
+
+<span style="font-size: 20px;">**`TrainableModule.mode(v):`**</span>
+
+设置 TrainableModule 在 update 时执行训练还是微调
+
+Args:
+    v (str): 设置在 update 时执行训练还是微调，可选值为 'finetune' 和 'train'，默认为 'finetune'
+
+**示例:**\n
+```python
+>>> import lazyllm
+>>> m = lazyllm.module.TrainableModule().finetune_method(finetune.dummy).deploy_method(None).mode('finetune')
+>>> m.update()
+INFO: (lazyllm.launcher) PID: dummy finetune!, and init-args is {}            
+```
+<span style="font-size: 20px;">**`eval(*, recursive=True)`**</span>
+评估该模块（及其所有子模块）。此功能需在模块通过evalset设置评估集后生效。
+
+Args:
+    recursive (bool) :是否递归评估所有子模块，默认为True。
+
+<span style="font-size: 20px;">**`evalset(evalset, load_f=None, collect_f=<function ModuleBase.<lambda>>)`**</span>
+
+为模块设置评估集。已设置评估集的模块将在执行``update``或``eval``时进行评估，评估结果将存储在eval_result变量中。
+
+<span style="font-size: 18px;">&ensp;**`evalset(evalset, collect_f=lambda x: ...)→ None `**</span>
+
+
+Args:
+    evalset (list) :评估数据集
+    collect_f (Callable) :评估结果的后处理方法，默认不进行后处理。\n
+
+
+<span style="font-size: 18px;">&ensp;**`evalset(evalset, load_f=None, collect_f=lambda x: ...)→ None`**</span>
+
+
+Args:
+    evalset (str) :评估集路径
+    load_f (Callable) :评估集加载方法，包括文件格式解析和列表转换
+    collect_f (Callable) :评估结果后处理方法，默认不进行后处理
+
+**示例:**\n
+```python
+>>> import lazyllm
+>>> m = lazyllm.module.TrainableModule().deploy_method(deploy.dummy)
+>>> m.evalset([1, 2, 3])
+>>> m.update()
+INFO: (lazyllm.launcher) PID: dummy finetune!, and init-args is {}
+>>> m.eval_result
+["reply for 1, and parameters is {'do_sample': False, 'temperature': 0.1}", "reply for 2, and parameters is {'do_sample': False, 'temperature': 0.1}", "reply for 3, and parameters is {'do_sample': False, 'temperature': 0.1}"]                
+```     
+
+<span style="font-size: 20px;">**`restart() `**</span>
+
+重启模块及其所有子模块
+
+**示例:**\n
+```python
+>>> import lazyllm
+>>> m = lazyllm.module.TrainableModule().deploy_method(deploy.dummy)
+>>> m.restart()
+>>> m(1)
+"reply for 1, and parameters is {'do_sample': False, 'temperature': 0.1}"
+```
+
+<span style="font-size: 20px;">start() </span>
+
+部署模块及其所有子模块
+
+**示例:**\n
+```python
+>>> import lazyllm
+>>> m = lazyllm.module.TrainableModule().deploy_method(deploy.dummy)
+>>> m.start()
+>>> m(1)
+"reply for 1, and parameters is {'do_sample': False, 'temperature': 0.1}"     
+```                
+
 ''')
 
 add_english_doc('TrainableModule', '''\
@@ -325,11 +593,12 @@ Trainable module, all models (including LLM, Embedding, etc.) are served through
 
 
 Args:
-    base_model (str): Name or path of the base model. If the model is not available locally, it will be automatically downloaded from the model source.
-    target_path (str): Path to save the fine-tuning task. Can be left empty if only performing inference.
-    source (str): Model source, optional values are huggingface or. If not set, it will read the value from the environment variable LAZYLLM_MODEL_SOURCE.
-    stream (bool): Whether to output stream. If the inference engine used does not support streaming, this parameter will be ignored.
-    return_trace (bool): Whether to record the results in trace.
+    base_model (str): Name or path of the base model. 
+    target_path (str): Path to save the fine-tuning task. 
+    source (str): Model source. If not set, it will read the value from the environment variable LAZYLLM_MODEL_SOURCE.
+    stream (bool): Whether to output stream. 
+    return_trace (bool): Record the results in trace.
+
 
 <span style="font-size: 20px;">**`TrainableModule.trainset(v):`**</span>
 
@@ -471,6 +740,162 @@ m(1)
 ```                                  
 ''')
 
+add_chinese_doc('TrainableModule.wait', '''\
+等待模型部署任务完成，该方法会阻塞当前线程直到部署完成。
+''')
+
+add_english_doc('TrainableModule.wait', '''\
+Wait for the model deployment task to complete. This method blocks the current thread until the deployment is finished.
+''')
+
+add_example('TrainableModule.wait', '''\
+>>> import lazyllm
+>>> class Mywait(lazyllm.module.llms.TrainableModule):
+...    def forward(self):
+...        self.wait()
+''')
+
+add_chinese_doc('TrainableModule.stop', '''\
+暂停模型特定任务。
+Args:
+    task_name(str): 需要暂停的任务名, 默认为None(默认暂停deploy任务)
+''')
+
+add_english_doc('TrainableModule.stop', '''\
+Pause a specific task of the model.
+Args:
+    task_name (str): The name of the task to pause. Defaults to None (pauses the 'deploy' task by default).
+''')
+
+add_example('TrainableModule.stop', '''\
+>>> import lazyllm
+>>> class Mystop(lazyllm.module.llms.TrainableModule):
+...    def forward(self, task):
+...        self.stop(task)
+''')
+
+add_chinese_doc('TrainableModule.prompt', '''\
+处理输入的prompt生成符合模型需求的格式。
+Args:
+    prompt(str): 输入的prompt, 默认为空。
+    history(**List): 对话历史记忆。
+''')
+
+add_english_doc('TrainableModule.prompt', '''\
+Processes the input prompt and generates a format compatible with the model.
+Args:
+    prompt (str): The input prompt. Defaults to an empty string.
+    history (List): Conversation history.
+''')
+
+add_example('TrainableModule.prompt', '''\
+>>> import lazyllm
+>>> class Myprompt(lazyllm.module.llms.TrainableModule):
+...    def forward(self, prompt, history):
+...        self.prompt(prompt,history)
+''')
+
+add_chinese_doc('TrainableModule.forward', '''\
+自动构建符合模型要求的输入数据结构，适配多模态场景。
+''')
+
+add_english_doc('TrainableModule.forward', '''\
+Supports handling various input formats, automatically builds the input structure required by the model, and adapts to multimodal scenarios.
+''')
+
+add_example('TrainableModule.forward', '''\
+>>> import lazyllm
+>>> from lazyllm.module import TrainableModule
+>>> class MyModule(TrainableModule):
+...     def forward(self, __input, **kw):
+...         return f"processed: {__input}"
+...
+>>> MyModule()("Hello")
+'processed: Hello'
+''')
+
+add_english_doc("TrainableModule.get_all_models", '''\
+get_all_models() -> List[str]
+
+Returns a list of all fine-tuned model paths under the current target path.
+
+Returns:
+- List[str]: A list of fine-tuned model identifiers or directories.
+''')
+
+add_chinese_doc("TrainableModule.get_all_models", '''\
+get_all_models() -> List[str]
+
+返回当前目标路径下所有微调模型的路径列表。
+
+返回值：
+- List[str]：所有微调模型的名称或路径列表。
+''')
+
+add_english_doc("TrainableModule.status", '''\
+status(task_name: Optional[str] = None) -> str
+
+Returns the current status of a specific task in the module.
+
+Args:
+- task_name (Optional[str]): Name of the task (e.g., 'deploy'). Defaults to 'deploy' if not provided.
+
+Returns:
+- str: Status string such as 'running', 'finished', or 'stopped'.
+''')
+
+add_chinese_doc("TrainableModule.status", '''\
+status(task_name: Optional[str] = None) -> str
+
+返回模块中指定任务的当前状态。
+
+参数：
+- task_name (Optional[str])：任务名称（如 'deploy'），默认返回 'deploy' 任务的状态。
+
+返回值：
+- str：状态字符串，例如 'running'、'finished' 或 'stopped'。
+''')
+
+add_english_doc("TrainableModule.set_specific_finetuned_model", '''\
+set_specific_finetuned_model(model_path: str) -> None
+
+Sets the model to be used from a specific fine-tuned model path.
+
+Args:
+- model_path (str): The path to the fine-tuned model to use.
+''')
+
+add_chinese_doc("TrainableModule.set_specific_finetuned_model", '''\
+set_specific_finetuned_model(model_path: str) -> None
+
+设置要使用的特定微调模型路径。
+
+参数：
+- model_path (str)：要使用的微调模型的路径。
+''')
+
+add_english_doc("TrainableModule.set_default_parameters", '''\
+set_default_parameters(*, optional_keys: List[str] = [], **kw) -> None
+
+Sets the default parameters to be used during inference or evaluation.
+
+Args:
+- optional_keys (List[str]): A list of optional keys to allow additional parameters without error.
+- **kw: Key-value pairs for default parameters such as temperature, top_k, etc.
+
+''')
+
+add_chinese_doc("TrainableModule.set_default_parameters", '''\
+set_default_parameters(*, optional_keys: List[str] = [], **kw) -> None
+
+设置用于推理或评估的默认参数。
+
+参数：
+- optional_keys (List[str])：允许传入额外参数的可选键列表。
+- **kw：用于设置默认参数的键值对，如 temperature、top_k 等。
+
+''')
+
 # add_example('TrainableModule', '''\
 # >>> import lazyllm
 # >>> m = lazyllm.module.TrainableModule().finetune_method(finetune.dummy).trainset('/file/to/path').deploy_method(None).mode('finetune')
@@ -497,18 +922,20 @@ add_chinese_doc('UrlModule', '''\
 可以将ServerModule部署得到的Url包装成一个Module，调用 ``__call__`` 时会访问该服务。
 
 Args:
-    url (str): 要包装的服务的Url
-    stream (bool): 是否流式请求和输出，默认为非流式
+    url (str): 要包装的服务的Url，默认为空字符串
+    stream (bool|Dict[str, str]): 是否流式请求和输出，默认为非流式
     return_trace (bool): 是否将结果记录在trace中，默认为False
+    init_prompt (bool): 是否初始化prompt，默认为True
 ''')
 
 add_english_doc('UrlModule', '''\
 The URL obtained from deploying the ServerModule can be wrapped into a Module. When calling ``__call__`` , it will access the service.
 
 Args:
-    url (str): The URL of the service to be wrapped.
-    stream (bool): Whether to request and output in streaming mode, default is non-streaming.
+    url (str): The URL of the service to be wrapped, defaults to empty string.
+    stream (bool|Dict[str, str]): Whether to request and output in streaming mode, default is non-streaming.
     return_trace (bool): Whether to record the results in trace, default is False.
+    init_prompt (bool): Whether to initialize prompt, defaults to True.
 ''')
 
 add_example('UrlModule', '''\
@@ -552,7 +979,9 @@ Args:
     stream (bool): 是否流式请求和输出，默认为非流式。
     return_trace (bool): 是否将结果记录在 trace 中，默认为``False``。
     port (int): 指定服务部署后的端口，默认为 ``None`` 会随机生成端口。
-    launcher (LazyLLMLaunchersBase): 用于选择服务执行的计算节点，默认为`` launchers.remote``。
+    pythonpath(str):传递给子进程的 PYTHONPATH 环境变量，默认为 ``None``。
+    launcher (LazyLLMLaunchersBase): 用于选择服务执行的计算节点，默认为是异步远程部署"launchers.remote(sync=False)"。
+    url(str):模块服务的地址，默认为"None",使用Redis获取。
 ''')
 
 add_english_doc('ServerModule', '''\
@@ -565,7 +994,9 @@ Args:
     stream (bool): Whether to request and output in streaming mode, default is non-streaming.
     return_trace (bool): Whether to record the results in trace, default is ``False``.
     port (int): Specifies the port after the service is deployed. The default is ``None``, which will generate a random port.
-    launcher (LazyLLMLaunchersBase): Used to select the compute node for service execution, default is ``launchers.remote`` .
+    pythonpath (str): PYTHONPATH environment variable passed to the subprocess. Defaults to None.
+    launcher (LazyLLMLaunchersBase): Specifies the compute node for running the service. Defaults to asynchronous remote deployment via launchers.remote(sync=False).
+    url (str): The service URL of the module. Defaults to None, in which case the URL is retrieved from Redis.
 
 **Examples:**\n
 ```python
@@ -717,6 +1148,22 @@ dummy finetune!, and init-args is {a: f2}
 [["post2(reply for 1, and parameters is {'do_sample': False, 'temperature': 0.1})", "post2(reply for 2, and parameters is {'do_sample': False, 'temperature': 0.1})", "post2(reply for 3, and parameters is {'do_sample': False, 'temperature': 0.1})"], ["post2(reply for 1, and parameters is {'do_sample': False, 'temperature': 0.1})", "post2(reply for 2, and parameters is {'do_sample': False, 'temperature': 0.1})", "post2(reply for 3, and parameters is {'do_sample': False, 'temperature': 0.1})"]]
 ''')
 
+add_chinese_doc('AutoModel', '''\
+用于部署在线 API 模型或本地模型的模块，支持加载在线推理模块或本地可微调模块。
+Args:
+    model (str): 指定要加载的模型名称，例如 ``internlm2-chat-7b``，可为空。为空时默认加载 ``internlm2-chat-7b``。
+    source (str): 指定要使用的在线模型服务，如需使用在线模型，必须传入此参数。支持 ``qwen`` / ``glm`` / ``openai`` / ``moonshot`` 等。
+    framework (str): 指定本地部署所使用的推理框架，支持 ``lightllm`` / ``vllm`` / ``lmdeploy``。将通过 ``TrainableModule`` 与指定框架组合进行部署。
+''')
+
+add_english_doc('AutoModel', '''\
+A module for deploying either online API-based models or local models, supporting both online inference and locally trainable modules.
+Args:
+    model (str): The name of the model to load, e.g., ``internlm2-chat-7b``. If None, ``internlm2-chat-7b`` will be loaded by default.
+    source (str): Specifies the online model service to use. Required when using online models. Supported values include ``qwen``, ``glm``, ``openai``, ``moonshot``, etc.
+    framework (str): The local inference framework to use for deployment. Supported values are ``lightllm``, ``vllm``, and ``lmdeploy``. The model will be deployed via ``TrainableModule`` using the specified framework.
+''')
+
 add_chinese_doc('OnlineChatModule', '''\
 用来管理创建目前市面上公开的大模型平台访问模块，目前支持openai、sensenova、glm、kimi、qwen、doubao、deekseek(由于该平台暂时不让充值了，暂时不支持访问)。平台的api key获取方法参见 [开始入门](/#platform)
 
@@ -765,6 +1212,48 @@ ret: Hello! How can I assist you today?
 >>> print(vlm(inputs))
 ''')
 
+add_chinese_doc('llms.onlinemodule.supplier.doubao.DoubaoModule', '''\
+豆包（Doubao）在线对话模块。
+该类封装了对字节跳动豆包 API 的调用，用于进行多轮对话。默认使用模型 `doubao-1-5-pro-32k-250115`，支持流式输出和调用链跟踪。
+Args:
+    model (str): 使用的模型名称，默认为 `doubao-1-5-pro-32k-250115`。
+    base_url (str): API 的基础 URL，默认为 "https://ark.cn-beijing.volces.com/api/v3/"。
+    api_key (str): 豆包 API Key。若未提供，则从 lazyllm.config['doubao_api_key'] 读取。
+    stream (bool): 是否启用流式输出，默认为 True。
+    return_trace (bool): 是否返回调用链跟踪信息，默认为 False。
+    **kwargs: 其他传递给基类的参数。
+''')
+
+add_english_doc('llms.onlinemodule.supplier.doubao.DoubaoModule', '''\
+Doubao online chat module.
+This class wraps the Doubao API (from ByteDance) for multi-turn chat. It defaults to model `doubao-1-5-pro-32k-250115` and supports streaming and optional trace return.
+Args:
+    model (str): The name of the model to use. Defaults to `doubao-1-5-pro-32k-250115`.
+    base_url (str): The base URL for the API. Defaults to "https://ark.cn-beijing.volces.com/api/v3/".
+    api_key (str): Doubao API key. If not provided, it will be read from `lazyllm.config['doubao_api_key']`.
+    stream (bool): Whether to use streaming output. Defaults to True.
+    return_trace (bool): Whether to return trace information. Defaults to False.
+    **kwargs: Additional arguments passed to the base class.
+''')
+
+add_chinese_doc('llms.onlinemodule.supplier.openai.OpenAIEmbedding', '''\
+OpenAI 在线嵌入模块。
+该类封装了对 OpenAI 嵌入 API 的调用，默认使用模型 `text-embedding-ada-002`，用于将文本编码为向量表示。
+Args:
+    embed_url (str): OpenAI 嵌入 API 的 URL，默认为 "https://api.openai.com/v1/embeddings"。
+    embed_model_name (str): 使用的嵌入模型名称，默认为 "text-embedding-ada-002"。
+    api_key (str, optional): OpenAI 的 API Key。若未提供，则从 lazyllm.config 中读取。
+''')
+
+add_english_doc('llms.onlinemodule.supplier.openai.OpenAIEmbedding', '''\
+Online embedding module using OpenAI.
+This class wraps the OpenAI Embedding API, defaulting to the `text-embedding-ada-002` model, and converts text into vector representations.
+Args:
+    embed_url (str): The URL endpoint of the OpenAI embedding API. Default is "https://api.openai.com/v1/embeddings".
+    embed_model_name (str): The name of the embedding model to use. Default is "text-embedding-ada-002".
+    api_key (str, optional): The OpenAI API key. If not provided, it will be read from `lazyllm.config`.
+''')
+
 add_chinese_doc('OnlineEmbeddingModule', '''\
 用来管理创建目前市面上的在线Embedding服务模块，目前支持openai、sensenova、glm、qwen、doubao
 
@@ -915,3 +1404,95 @@ add_example('OnlineEmbeddingModuleBase', '''\
 ...         pass
 ...         return embedding
 ''')
+
+add_chinese_doc('llms.onlinemodule.supplier.doubao.DoubaoEmbedding', '''\
+豆包嵌入类，继承自 OnlineEmbeddingModuleBase，封装了调用豆包在线文本嵌入服务的功能。  
+通过指定服务接口 URL、模型名称及 API Key，支持远程获取文本向量表示。
+
+Args:
+    embed_url (Optional[str]): 豆包文本嵌入服务的接口 URL，默认指向北京区域的服务地址。
+    embed_model_name (Optional[str]): 使用的豆包嵌入模型名称，默认为 "doubao-embedding-text-240715"。
+    api_key (Optional[str]): 访问豆包服务的 API Key，若未提供则从 lazyllm 配置中读取。
+''')
+
+add_english_doc('llms.onlinemodule.supplier.doubao.DoubaoEmbedding', '''\
+DoubaoEmbedding class inherits from OnlineEmbeddingModuleBase, encapsulating the functionality to call Doubao's online text embedding service.  
+It supports remote text vector representation retrieval by specifying the service URL, model name, and API key.
+
+Args:
+    embed_url (Optional[str]): URL of the Doubao text embedding service, defaulting to the Beijing region endpoint.
+    embed_model_name (Optional[str]): Name of the Doubao embedding model used, default is "doubao-embedding-text-240715".
+    api_key (Optional[str]): API key for accessing the Doubao service. If not provided, it is read from lazyllm config.
+''')
+
+add_chinese_doc('llms.onlinemodule.fileHandler.FileHandlerBase', '''\
+FileHandlerBase是用于处理微调数据文件的基类，主要用于验证和转换微调数据格式。该类本身不支持直接实例化，需要子类继承该类并实现特定的文件格式转换逻辑。
+
+FileHandlerBase提供以下功能：\n
+1. 验证微调数据文件的格式是否符合标准（.jsonl格式）\n
+2. 检查数据内容是否符合预期的消息格式（包含role和content字段）\n
+3. 验证角色类型是否在允许的范围内（system、knowledge、user、assistant）\n
+4. 确保每个对话示例都包含assistant回复\n
+5. 提供临时文件存储机制用于后续处理\n
+''')
+
+add_english_doc('llms.onlinemodule.fileHandler.FileHandlerBase', '''\
+FileHandlerBase is a base class for handling fine-tuning data files, primarily used for validating and converting fine-tuning data formats. This class itself does not support direct instantiation; it requires subclasses to inherit from this class and implement specific file format conversion logic.
+
+FileHandlerBase provides the following capabilities:\n
+1. Validate that the fine-tuning data file format conforms to standards (.jsonl format)\n
+2. Check if the data content conforms to the expected message format (containing role and content fields)\n
+3. Verify that role types are within the allowed range (system, knowledge, user, assistant)\n
+4. Ensure that each conversation example contains an assistant response\n
+5. Provide temporary file storage mechanism for subsequent processing\n
+''')
+
+add_example('llms.onlinemodule.fileHandler.FileHandlerBase', '''\
+>>> import lazyllm
+>>> from lazyllm.module.llms.onlinemodule.fileHandler import FileHandlerBase
+>>> import tempfile
+>>> import json
+>>> sample_data = [
+...     {"messages": [{"role": "user", "content": "Hello"}, {"role": "assistant", "content": "Hi there!"}]},
+...     {"messages": [{"role": "user", "content": "How are you?"}, {"role": "assistant", "content": "I'm doing well, thank you!"}]}
+... ] 
+>>> with tempfile.NamedTemporaryFile(mode='w', suffix='.jsonl', delete=False) as f:
+...     for item in sample_data:
+...         f.write(json.dumps(item, ensure_ascii=False) + '\n')
+...     temp_file_path = f.name
+>>> class CustomFileHandler(FileHandlerBase):
+...     def _convert_file_format(self, filepath: str) -> str:
+...         with open(filepath, 'r', encoding='utf-8') as f:
+...             data = [json.loads(line) for line in f]
+...         converted_data = []
+...         for item in data:
+...             messages = item.get('messages', [])
+...             conversation = []
+...             for msg in messages:
+...                 conversation.append(f"{msg['role']}: {msg['content']}")
+...             converted_data.append('\n'.join(conversation))
+...         return '\n---\n'.join(converted_data)
+>>> handler = CustomFileHandler()
+>>> try:
+...     result = handler.get_finetune_data(temp_file_path)
+...     print("数据验证和转换成功")
+... except Exception as e:
+...     print(f"错误: {e}")
+... finally:
+...     import os
+...     os.unlink(temp_file_path)
+''')
+
+add_chinese_doc('llms.onlinemodule.fileHandler.FileHandlerBase.get_finetune_data', '''\
+获取并处理微调数据文件，包括验证文件格式和转换为目标平台支持的格式。
+
+Args:
+    filepath (str): 微调数据文件的路径，必须是.jsonl格式
+''')
+
+add_english_doc('llms.onlinemodule.fileHandler.FileHandlerBase.get_finetune_data', '''\
+Get and process fine-tuning data files, including validating file format and converting to the format supported by the target platform.
+
+Args:
+    filepath (str): Path to the fine-tuning data file, must be in .jsonl format
+''')
