@@ -6,10 +6,11 @@ from typing import List, Dict, Optional, Set, Union
 
 import lazyllm
 from lazyllm import once_wrapper
-from .engine import Engine, Node, ServerGraph
+from .engine import Engine, Node, ServerGraph, SharedHttpTool
 from lazyllm.tools.train_service.serve import TrainServer
 from lazyllm.tools.train_service.client import LocalTrainClient, OnlineTrainClient
 from lazyllm.tools.infer_service import InferClient, InferServer
+from lazyllm.components.formatter.formatterbase import LAZYLLM_QUERY_PREFIX
 
 
 @contextmanager
@@ -317,7 +318,8 @@ class LightEngine(Engine):
                     node = resource
                 else:
                     return self._nodes.get(node)
-            node = Node(id=node['id'], kind=node['kind'], name=node['name'], args=node['args'])
+            node = Node(id=node['id'], kind=node['kind'], name=node['name'], args=node['args'],
+                        hyperparameter=node.get('hyperparameter'))
         if node.id not in self._nodes:
             self._nodes[node.id] = super(__class__, self).build_node(node)
         return self._nodes[node.id]
@@ -327,8 +329,9 @@ class LightEngine(Engine):
         for nodeid in node_ids:
             self.stop(nodeid)
             # TODO(wangzhihong): Analyze dependencies and only allow deleting nodes without dependencies
-            [self._nodes.pop(id) for id in self.subnodes(nodeid, recursive=True)]
-            self._nodes.pop(nodeid)
+            [self._nodes.pop(id, None) for id in self.subnodes(nodeid, recursive=True)
+             if id not in ('__start__', '__end__')]
+            if nodeid not in ('__start__', '__end__'): self._nodes.pop(nodeid, None)
 
     def update_node(self, node):
         if not isinstance(node, Node):
@@ -336,7 +339,8 @@ class LightEngine(Engine):
         self._nodes[node.id] = super(__class__, self).build_node(node)
         return self._nodes[node.id]
 
-    def start(self, nodes, edges=[], resources=[], gid=None, name=None, _history_ids=None):
+    def start(self, nodes, edges=None, resources=None, gid=None, name=None, _history_ids=None):
+        edges, resources = edges or [], resources or []
         if isinstance(nodes, str):
             assert not edges and not resources and not gid and not name
             self.build_node(nodes).func.start()
@@ -377,7 +381,8 @@ class LightEngine(Engine):
                 node.func.stop()
 
     def update(self, gid_or_nodes: Union[str, Dict, List[Dict]], nodes: List[Dict],
-               edges: List[Dict] = [], resources: List[Dict] = []) -> str:
+               edges: Optional[List[Dict]] = None, resources: Optional[List[Dict]] = None) -> str:
+        edges, resources = edges or [], resources or []
         if isinstance(gid_or_nodes, str):
             assert (gid := gid_or_nodes) in self._nodes
             name = self._nodes[gid].name
@@ -394,6 +399,8 @@ class LightEngine(Engine):
             args = [lazyllm.formatter.file(formatter='encode')(dict(query=args[0] if args else '', files=files))]
         if _file_resources:
             lazyllm.globals['lazyllm_files'] = _file_resources
+        nodes = [self.build_node(node) for node in self.subnodes(id, recursive=True)]
+        [node.func.valid_key() for node in nodes if isinstance(node.func, SharedHttpTool)]
         f = self.build_node(id).func
         lazyllm.FileSystemQueue().dequeue()
         if history := _lazyllm_history:
@@ -401,7 +408,15 @@ class LightEngine(Engine):
             if not isinstance(history, list) and all([isinstance(h, list) for h in history]):
                 raise RuntimeError('History shoule be [[str, str], ..., [str, str]] (list of list of str)')
             lazyllm.globals['chat_history'] = {Engine().build_node(i).func._module_id: history for i in f._history_ids}
+        for node in nodes:
+            if isinstance(node, Node) and node.hyperparameter is not None and hasattr(node.func, "_module_id"):
+                lazyllm.globals['global_parameters'][node.func._module_id] = node.hyperparameter
         result = self.build_node(id).func(*args, **kw)
         lazyllm.globals['lazyllm_files'] = {}
         lazyllm.globals['chat_history'] = {}
-        return result
+        if isinstance(result, str) and result.startswith(LAZYLLM_QUERY_PREFIX):
+            decoded_result = lazyllm.formatter.file(formatter='decode')(result)
+            if decoded_result["query"] and decoded_result["files"]: return result
+            return decoded_result["query"] or decoded_result["files"][0]
+        else:
+            return result
