@@ -1,8 +1,9 @@
 import lazyllm
 import builtins
-from lazyllm import LazyLLMRegisterMetaClass, package, kwargs, arguments, bind, root, config
-from lazyllm import ReadOnlyWrapper, LOG, globals
-from ..common.bind import _MetaBind
+from lazyllm import config
+from lazyllm.common import LazyLLMRegisterMetaClass, package, kwargs, arguments, bind, root
+from lazyllm.common import ReadOnlyWrapper, LOG, globals
+from lazyllm.common.bind import _MetaBind
 from functools import partial
 from contextlib import contextmanager
 from enum import Enum
@@ -17,7 +18,7 @@ import concurrent.futures
 from collections import deque
 import uuid
 from ..hook import LazyLLMHook
-import asyncio
+from itertools import repeat
 
 
 class _FuncWrap(object):
@@ -43,7 +44,7 @@ def new_ins(obj, cls):
         return True if (cls is _FuncWrap or (_oldins(cls, (tuple, list)) and _FuncWrap in cls)) else _oldins(obj._f, cls)
     return _oldins(obj, cls)
 
-setattr(builtins, 'isinstance', new_ins)
+builtins.isinstance = new_ins
 
 def _is_function(f):
     return isinstance(f, (types.BuiltinFunctionType, types.FunctionType,
@@ -57,9 +58,9 @@ This class provides a way to organize items, which can be instances of ``FlowBas
 Args:
     items (iterable): An iterable of items to be included in the flow. These can be instances of ``FlowBase`` or other objects.
     item_names (list of str, optional): A list of names corresponding to the items. This allows items to be accessed by name. If not provided, items can only be accessed by index.
-
+    auto_capture: If True, variables newly defined within the ``with`` block will be automatically added to the flow. Defaults to ``False``.
 """
-    def __init__(self, *items, item_names=[], auto_capture=False) -> None:
+    def __init__(self, *items, item_names=None, auto_capture=False) -> None:
         self._father = None
         self._items, self._item_names, self._item_ids = [], [], []
         self._auto_capture = auto_capture
@@ -67,7 +68,7 @@ Args:
         self._curr_frame = None
         self._flow_id = str(uuid.uuid4().hex)
 
-        for k, v in zip(item_names if item_names else [None] * len(items), items):
+        for k, v in zip(item_names if item_names else repeat(None), items):
             self._add(k, v)
 
         self._capture = False
@@ -109,10 +110,16 @@ Args:
         self.__post_init__()
         return False
 
+    def __iter__(self):
+        # used to support `with pipeline() as (a.b, b):`
+        return iter([self, self])
+
     def __setattr__(self, name: str, value):
         if '_capture' in self.__dict__ and self._capture and not name.startswith('_'):
             assert name not in self._item_names, f'Duplicated name: {name}'
             self._add(name, value)
+        elif name in getattr(self, '_item_names', ()):
+            raise RuntimeError(f'The setting of {self.__class__} elements must be done within the `with` statement.')
         else:
             super(__class__, self).__setattr__(name, value)
 
@@ -122,6 +129,15 @@ Args:
         raise AttributeError(f'{self.__class__} object has no attribute {name}')
 
     def id(self, module=None):
+        """Get the identifier for a module or the flow itself. If a string is provided, it is returned as-is. If a bound module is provided, returns its associated item_id. If no argument is given, returns the unique id of the entire flow.
+
+Args:
+    module (Optional[Union[str, Any]]): Target module or string identifier.
+
+**Returns:**
+
+- str: Corresponding identifier string.
+"""
         if isinstance(module, str): return module
         return self._item_ids[self._items.index(module)] if module else self._flow_id
 
@@ -210,13 +226,28 @@ def _bind_enter(self):
 def _bind_exit(self, exc_type, exc_val, exc_tb):
     return self._f.__exit__(exc_type, exc_val, exc_tb)
 
-setattr(bind, '__enter__', _bind_enter)
-setattr(bind, '__exit__', _bind_exit)
+bind.__enter__ = _bind_enter
+bind.__exit__ = _bind_exit
 
 
 # TODO(wangzhihong): support workflow launcher.
 # Disable item launchers if launcher is already set in workflow.
 class LazyLLMFlowsBase(FlowBase, metaclass=LazyLLMRegisterMetaClass):
+    """A base class for flow structures with hook support and unified execution logic.
+
+`LazyLLMFlowsBase` is the base class for all LazyLLM flow types. It organizes a sequence of callable modules into a flow and provides support for pre/post hooks, synchronization control, post-processing, and error-safe invocation. It is not intended for direct use but instead serves as a foundational class for concrete flow types like `Pipeline`, `Parallel`, etc.
+
+```text
+input --> [Flow module1 -> Flow module2 -> ... -> Flow moduleN] --> output
+                   ↑             ↓
+               pre_hook       post_hook
+```
+Args:
+    args: A sequence of callables representing the flow modules.
+    post_action: An optional callable applied to the output after main flow execution. Defaults to ``None``。
+    auto_capture: If True, variables newly defined within the ``with`` block will be automatically added to the flow. Defaults to ``False``.
+
+"""
     def __init__(self, *args, post_action=None, auto_capture=False, **kw):
         assert len(args) == 0 or len(kw) == 0, f'Cannot provide args `{args}` and kwargs `{kw}` at the same time'
         if len(args) > 0 and isinstance(args[0], (tuple, list)):
@@ -247,13 +278,25 @@ class LazyLLMFlowsBase(FlowBase, metaclass=LazyLLMRegisterMetaClass):
         return r
 
     def register_hook(self, hook_type: LazyLLMHook):
+        """Register a hook type for additional processing before and after the flow execution.
+
+Args:
+    hook_type (LazyLLMHook): The hook type or instance to register.
+"""
         self._hooks.add(hook_type)
 
     def unregister_hook(self, hook_type: LazyLLMHook):
+        """Unregister a previously registered hook.
+
+Args:
+    hook_type (LazyLLMHook): The hook type or instance to remove.
+"""
         if hook_type in self._hooks:
             self._hooks.remove(hook_type)
 
     def clear_hooks(self):
+        """Clear all registered hooks.
+"""
         self._hooks = set()
 
     def _post_process(self, output):
@@ -267,6 +310,15 @@ class LazyLLMFlowsBase(FlowBase, metaclass=LazyLLMRegisterMetaClass):
         return self(*args, **kw)
 
     def set_sync(self, sync=True):
+        """Set whether the flow executes synchronously.
+
+Args:
+    sync (bool): Whether to execute synchronously. Default is True.
+
+**Returns**
+
+- LazyLLMFlowsBase: The current instance.
+"""
         self._sync = sync
         return self
 
@@ -277,6 +329,12 @@ class LazyLLMFlowsBase(FlowBase, metaclass=LazyLLMRegisterMetaClass):
         return lazyllm.make_repr('Flow', self.__class__.__name__, subs=subs, items=self._item_names)
 
     def wait(self):
+        """Wait for all asynchronous tasks in the flow to complete.
+
+**Returns**
+
+- LazyLLMFlowsBase: The current instance.
+"""
         def filter(x):
             return hasattr(x, 'job') and isinstance(x.job, ReadOnlyWrapper) and not x.job.isNone()
         self.for_each(filter, lambda x: x.job.wait())
@@ -284,6 +342,15 @@ class LazyLLMFlowsBase(FlowBase, metaclass=LazyLLMRegisterMetaClass):
 
     # bind_args: dict(input=input, args=dict(key=value))
     def invoke(self, it, __input, *, bind_args_source=None, **kw):
+        """Invoke a target (function, module, or bind object) with the given input.  
+Supports root/pipeline output replacement for bind objects.
+
+Args:
+    it (Callable | bind): The target to invoke.
+    __input (Any): Input data.
+    bind_args_source (Any, optional): Source of bind arguments.
+    **kw: Additional keyword arguments.
+"""
         if isinstance(it, bind):
             if it._has_root:
                 it._args = [a.get_from(self.ancestor) if isinstance(a, type(root)) else a for a in it._args]
@@ -308,6 +375,16 @@ class LazyLLMFlowsBase(FlowBase, metaclass=LazyLLMRegisterMetaClass):
             raise
 
     def bind(self, *args, **kw):
+        """Bind arguments to the current flow, producing a bind object.
+
+Args:
+    *args: Positional arguments.
+    **kw: Keyword arguments.
+
+**Returns**
+
+- bind: The bound bind object.
+"""
         return bind(self, *args, **kw)
 
 
@@ -322,6 +399,7 @@ The ``Pipeline`` class is a linear sequence of processing stages, where the outp
 Args:
     args (list of callables or single callable): The processing stages of the pipeline. Each element can be a callable function or an instance of ``LazyLLMFlowsBase.FuncWrap``. If a single list or tuple is provided, it is unpacked as the stages of the pipeline.
     post_action (callable, optional): An optional action to perform after the last stage of the pipeline. Defaults to None.
+    auto_capture (bool, optional): If True, variables newly defined within the ``with`` block will be automatically added to the flow. Defaults to ``False``.
     kwargs (dict of callables): Named processing stages of the pipeline. Each key-value pair represents a named stage, where the key is the name and the value is the callable stage.
 
 **Returns:**
@@ -375,7 +453,17 @@ Examples:
     def input(self): return bind.Args(self.id())
     @property
     def kwargs(self): return bind.Args(self.id(), 'kwargs')
-    def output(self, module): return bind.Args(self.id(), self.id(module))
+    def output(self, module, unpack=False):
+        """Get the output result of a specified module in the pipeline.
+
+Args:
+    module: The module to get output from. Can be a module object or module name.
+    unpack (bool): Whether to unpack the output result. Defaults to False.
+
+Returns:
+    bind.Args: A bound argument object for data passing in the pipeline.
+"""
+        return bind.Args(self.id(), self.id(module), unpack=unpack)
 
     def _run(self, __input, **kw):
         output = __input
@@ -402,6 +490,26 @@ config.add('save_flow_result', bool, False, 'SAVE_FLOW_RESULT')
 
 @contextmanager
 def save_pipeline_result(flag: bool = True):
+    """A context manager that temporarily sets whether to save intermediate results during pipeline execution.
+
+When entering the context, `Pipeline.g_save_flow_result` is set to the given value. After exiting, it restores the previous value. Useful for debugging or recording intermediate outputs.
+
+Args:
+    flag (bool): Whether to enable result saving. Defaults to True.
+
+**Returns:**
+
+- ContextManager: A context manager.
+
+
+Examples:
+    >>> import lazyllm
+    >>> pipe = lazyllm.pipeline(lambda x: x + 1, lambda x: x * 2)
+    >>> with lazyllm.save_pipeline_result(True):
+    ...     result = pipe(1)
+    >>> result
+    4
+    """
     old_flag = Pipeline.g_save_flow_result
     Pipeline.g_save_flow_result = flag
     yield
@@ -409,7 +517,9 @@ def save_pipeline_result(flag: bool = True):
 
 
 _barr = threading.local()
-def barrier(args): _barr.impl.wait(); return args
+def barrier(args):
+    if _barr.impl: _barr.impl.wait()
+    return args
 
 
 def _split_input(input: Union[Tuple, List], flag: Optional[Union[int, List]] = None):
@@ -429,6 +539,9 @@ def _split_input(input: Union[Tuple, List], flag: Optional[Union[int, List]] = N
     raise TypeError(f'invalid flag type {type(flag)} given')
 
 
+config.add('parallel_multiprocessing', bool, False, 'PARALLEL_MULTIPROCESSING')
+
+
 #        /> module11 -> ... -> module1N -> out1 \
 #  input -> module21 -> ... -> module2N -> out2 -> (out1, out2, out3)
 #        \> module31 -> ... -> module3N -> out3 /
@@ -453,9 +566,11 @@ The ``Parallel.sequential`` method can be visualized as follows:
 ```
 
 Args:
-    _scatter (bool, optional): If ``True``, the input is split across the items. If ``False``, the same input is passed to all items. Defaults to ``False``.
-    _concurrent (bool, optional): If ``True``, operations will be executed concurrently using threading. If ``False``, operations will be executed sequentially. Defaults to ``True``.
     args: Variable length argument list for the base class.
+    _scatter (bool, optional): If ``True``, the input is split across the items. If ``False``, the same input is passed to all items. Defaults to ``False``.
+    _concurrent (Union[bool, int], optional): If ``True``, operations will be executed concurrently using threading. If an integer, specifies the maximum number of concurrent executions. If ``False``, operations will be executed sequentially. Defaults to ``True``.
+    multiprocessing (bool, optional): If ``True``, multiprocessing will be used instead of multithreading for parallel execution. This can provide true parallelism but adds overhead for inter-process communication. Defaults to ``False``.
+    auto_capture (bool, optional): If True, variables newly defined within the ``with`` block will be automatically added to the flow. Defaults to ``False``.
     kwargs: Arbitrary keyword arguments for the base class.
 
 `asdict property`
@@ -504,6 +619,21 @@ Examples:
     '2\\n4\\n0.5'
     """
 
+    @staticmethod
+    def _worker(func, barrier, global_data, *args, **kw):
+        # When multiple threads or processes use the same pipeline, all threads share the same pipeline ID,
+        # making it impossible to distinguish between them based on the pipeline ID when saving intermediate
+        # results. To address this, we assign a new session ID to each thread to store the intermediate
+        # results of each pipeline. Note that when running in parallel, the execution order of modules is not
+        # guaranteed, so TODO(wangzhihong) streaming output via FileSystemQueue is not possible.
+        lazyllm.globals._init_sid()
+        lazyllm.globals._update(global_data)
+        lazyllm.globals['bind_args'] = lazyllm.globals['bind_args'].copy()
+        _barr.impl = barrier
+        r = func(*args, **kw)
+        lazyllm.globals.clear()
+        return r
+
     class PostProcessType(Enum):
         NONE = 0
         DICT = 1
@@ -513,11 +643,12 @@ Examples:
         JOIN = 5
 
     def __init__(self, *args, _scatter: bool = False, _concurrent: Union[bool, int] = True,
-                 auto_capture: bool = False, **kw):
+                 multiprocessing: bool = False, auto_capture: bool = False, **kw):
         super().__init__(*args, **kw, auto_capture=auto_capture)
         self._post_process_type = Parallel.PostProcessType.NONE
         self._post_process_args = None
-        self._concurrent = _concurrent if not isinstance(_concurrent, bool) else 5 if _concurrent else 0
+        self._multiprocessing = multiprocessing or config['parallel_multiprocessing']
+        self._concurrent = 0 if not _concurrent else 5 if isinstance(_concurrent, bool) else _concurrent
         self._scatter = _scatter
 
     @staticmethod
@@ -533,11 +664,52 @@ Examples:
     sum = property(partial(_set_status, type=PostProcessType.SUM))
 
     def join(self, string=''):
+        """Marks the Parallel instance to join its results with the specified string on each call.
+
+Args:
+    string (str): The string to use for joining results. Defaults to an empty string.
+
+**Returns:**
+
+- Parallel: Returns the current Parallel instance configured to join results with the specified string.
+
+**Example:**
+
+```python
+>>> ppl = lazyllm.parallel(a=test1, b=test2, c=test3).join('\n')
+>>> ppl(1)
+'2\n4\n0.5'
+```
+"""
         assert isinstance(string, str), 'argument of join shoule be str'
         return Parallel._set_status(self, type=Parallel.PostProcessType.JOIN, args=string)
 
     @classmethod
     def sequential(cls, *args, **kw):
+        """Creates a Parallel instance that executes sequentially.
+
+This class method sets ``_concurrent`` to ``False``, causing all operations to be executed in sequence rather than in parallel.
+
+The ``Parallel.sequential`` method can be visualized as follows:
+
+```text
+# input -> module21 -> ... -> module2N -> out2 -> 
+```
+
+Args:
+    args: Variable length argument list passed to the Parallel constructor.
+    kwargs: Keyword arguments passed to the Parallel constructor.
+    _scatter (bool, optional): If ``True``, the input is split across the items. If ``False``, the same input is passed to all items. Defaults to ``False``.
+    _concurrent (bool, optional): If ``True``, operations will be executed concurrently using threading. If ``False``, operations will be executed sequentially. Defaults to ``True``.
+    multiprocessing (bool, optional): If ``True``, multiprocessing will be used instead of multithreading for parallel execution. This can provide true parallelism but adds overhead for inter-process communication. Defaults to ``False``.
+    auto_capture (bool, optional): If True, variables newly defined within the ``with`` block will be automatically added to the flow. Defaults to ``False``.
+    args: Variable length argument list for the base class.
+    kwargs: Arbitrary keyword arguments for the base class.
+
+**Returns:**
+
+- Parallel: A new Parallel instance configured for sequential execution.
+"""
         return cls(*args, _concurrent=False, **kw)
 
     def _run(self, __input, items=None, **kw):
@@ -552,20 +724,27 @@ Examples:
             inputs = __input
 
         if self._concurrent:
-            def impl(func, barrier, global_data, *args, **kw):
-                lazyllm.globals._init_sid()
-                lazyllm.globals._update(global_data)
-                lazyllm.globals['bind_args'] = lazyllm.globals['bind_args'].copy()
-                _barr.impl = barrier
-                r = func(*args, **kw)
-                lazyllm.globals.clear()
-                return r
+            if self._multiprocessing:
+                barrier, executor = None, lazyllm.ProcessPoolExecutor
+            else:
+                barrier, executor = threading.Barrier(len(items)), concurrent.futures.ThreadPoolExecutor
 
-            loop, barrier = asyncio.new_event_loop(), threading.Barrier(len(items))
-            with concurrent.futures.ThreadPoolExecutor(max_workers=self._concurrent) as executor:
-                return package(loop.run_until_complete(asyncio.gather(*[loop.run_in_executor(executor, partial(
-                    impl, self.invoke, barrier, lazyllm.globals._data, it, inp, **kw))
-                    for it, inp in zip(items, inputs)])))
+            with executor(max_workers=self._concurrent) as e:
+                futures = [e.submit(partial(self._worker, self.invoke, barrier, lazyllm.globals._data, it, inp, **kw))
+                           for it, inp in zip(items, inputs)]
+                if (not_done := concurrent.futures.wait(futures).not_done):
+                    error_msgs = []
+                    for future in not_done:
+                        if (exc := future.exception()) is not None:
+                            if (tb := getattr(future, "_traceback", None)):
+                                tb_str = ''.join(traceback.format_exception(type(exc), exc, tb))
+                            else:
+                                tb_str = ''.join(traceback.format_exception(type(exc), exc, exc.__traceback__))
+                            error_msgs.append(f"Future: {future}\n{tb_str}")
+                        else:
+                            error_msgs.append(f"Future: {future} not complete without exception。")
+                    raise RuntimeError('Parallel execute failed!\n' + '\n'.join(error_msgs))
+                return package([future.result() for future in futures])
         else:
             return package(self.invoke(it, inp, **kw) for it, inp in zip(items, inputs))
 
@@ -603,6 +782,7 @@ This class is useful when you have distinct data processing pipelines that can b
 Args:
     args : Variable length argument list representing the modules to be executed in parallel.
     _concurrent (bool, optional): A flag to control whether the modules should be run concurrently. Defaults to ``True``. You can use ``Diverter.sequential`` instead of ``Diverter`` to set this variable.
+    auto_capture (bool, optional): If True, variables newly defined within the ``with`` block will be automatically added to the flow. Defaults to ``False``.
     kwargs : Arbitrary keyword arguments representing additional modules, where the key is the name of the module.
 
 
@@ -640,6 +820,9 @@ The Warp class is designed to apply the same processing module to a set of input
 
 Args:
     args: Variable length argument list representing the single module to be applied to all inputs.
+    _scatter (bool): Whether to scatter inputs into parts before processing. Defaults to False.
+    _concurrent (bool | int): Whether to execute in parallel. Can be a boolean or a max concurrency limit. Defaults to True.
+    auto_capture (bool): If True, variables newly defined within the ``with`` block will be automatically added to the flow. Defaults to ``False``.
     kwargs: Arbitrary keyword arguments for future extensions.
 
 Note:
@@ -655,6 +838,11 @@ Examples:
     >>> warp = lazyllm.warp(lazyllm.pipeline(lambda x: x * 2, lambda x: f'get {x}'))
     >>> warp(1, 2, 3, 4)
     ('get 2', 'get 4', 'get 6', 'get 8')
+    
+    >>> from lazyllm import package
+    >>> warp1 = lazyllm.warp(lambda x, y: x * 2 + y)
+    >>> print(warp1([package(1,2), package(10, 20)]))
+    (4, 40)
     """
     def __init__(self, *args, _scatter: bool = False, _concurrent: Union[bool, int] = True,
                  auto_capture: bool = False, **kw):
@@ -691,9 +879,9 @@ The ``Switch`` class provides a way to choose between different flows depending
 
 Args:
     args: A variable length argument list, alternating between conditions and corresponding flows or functions. Conditions are either callables returning a boolean or values to be compared with the input expression.
+    conversion (callable, optional): A function used to transform or preprocess the evaluation expression ``exp`` before performing condition matching. Defaults to ``None``.
     post_action (callable, optional): A function to be called on the output after the selected flow is executed. Defaults to ``None``.
     judge_on_full_input(bool): If set to ``True``, the conditional judgment will be performed through the input of ``switch``, otherwise the input will be split into two parts: the judgment condition and the actual input, and only the judgment condition will be judged.
-    kwargs: Arbitrary keyword arguments representing named conditions and corresponding flows or functions.
 
 Raises:
     TypeError: If an odd number of arguments are provided, or if the first argument is not a dictionary and the conditions are not provided in pairs.
@@ -846,6 +1034,7 @@ Args:
     stop_condition (callable, optional): A function that takes the output of the last item in the loop as input and returns a boolean. If it returns ``True``, the loop will stop. If ``None``, the loop will continue until ``count`` is reached. Defaults to ``None``.
     count (int, optional): The maximum number of iterations to run the loop for. If ``None``, the loop will continue indefinitely or until ``stop_condition`` returns ``True``. Defaults to ``None``.
     post_action (callable, optional): A function to be called with the final output after the loop ends. Defaults to ``None``.
+    auto_capture (bool, optional): If True, variables newly defined within the ``with`` block will be automatically added to the flow. Defaults to ``False``.
     judge_on_full_input(bool): If set to ``True``, the conditional judgment will be performed through the input of ``stop_condition``, otherwise the input will be split into two parts: the judgment condition and the actual input, and only the judgment condition will be judged.
 
 Raises:
@@ -877,6 +1066,21 @@ Examples:
 
 
 class Graph(LazyLLMFlowsBase):
+    """A complex flow control structure based on Directed Acyclic Graph (DAG).
+
+The Graph class allows you to create complex processing graphs where nodes represent processing functions and edges represent data flow. It supports topological sorting to ensure correct execution order and can handle complex dependencies with multiple inputs and outputs.
+
+The Graph class is particularly suitable for scenarios requiring complex data flow and dependency management, such as machine learning pipelines, data processing workflows, etc.
+
+Args:
+    post_action (callable, optional): A function to be called after the graph execution is complete. Defaults to ``None``.
+    auto_capture (bool, optional): Whether to automatically capture variables from context. Defaults to ``False``.
+    kwargs: Arbitrary keyword arguments representing named nodes and corresponding functions.
+
+**Returns:**
+
+- The final output result of the graph.
+"""
 
     start_node_name, end_node_name = '__start__', '__end__'
 
@@ -900,16 +1104,94 @@ class Graph(LazyLLMFlowsBase):
         self._constants = []
 
     def set_node_arg_name(self, arg_names):
+        """Set the argument names for nodes.
+
+This method is used to set the names of function arguments for nodes in the graph, which is important for correct invocation of multi-parameter functions.
+
+Args:
+    arg_names (list): List of argument names, corresponding to the order when nodes were created.
+
+
+Examples:
+    >>> import lazyllm
+    >>> with lazyllm.graph() as g:
+    ...     g.add = lambda a, b: a + b
+    ...     g.multiply = lambda x, y: x * y
+    >>> g.set_node_arg_name([['x', 'y'], ['a', 'b']])
+    >>> g._nodes['add'].arg_names
+    ['x', 'y']
+    >>> g._nodes['multiply'].arg_names
+    ['a', 'b']
+    """
         for node_name, name in zip(self._item_names, arg_names):
             self._nodes[node_name].arg_names = name
 
     @property
-    def start_node(self): return self._nodes[Graph.start_node_name]
+    def start_node(self):
+        """Get the start node of the graph.
+
+**Returns:**
+
+- Node: The start node (__start__) object of the graph.
+
+
+Examples:
+    >>> import lazyllm
+    >>> with lazyllm.graph() as g:
+    ...     g.process = lambda x: x * 2
+    >>> start = g.start_node
+    >>> start.name
+    '__start__'
+    """
+        return self._nodes[Graph.start_node_name]
 
     @property
-    def end_node(self): return self._nodes[Graph.end_node_name]
+    def end_node(self):
+        """Get the end node of the graph.
+
+**Returns:**
+
+- Node: The end node (__end__) object of the graph.
+
+
+Examples:
+    >>> import lazyllm
+    >>> with lazyllm.graph() as g:
+    ...     g.process = lambda x: x * 2
+    >>> end = g.end_node
+    >>> end.name
+    '__end__'
+    """
+        return self._nodes[Graph.end_node_name]
 
     def add_edge(self, from_node, to_node, formatter=None):
+        """Add an edge to the graph, defining data flow between nodes.
+
+This method is used to define connection relationships between nodes in the graph, specifying how data flows from one node to another.
+
+Args:
+    from_node (str or Node): The name or Node object of the source node.
+    to_node (str or Node): The name or Node object of the target node.
+    formatter (callable, optional): Optional formatting function for data transformation during transfer. Defaults to ``None``.
+
+
+Examples:
+    >>> import lazyllm
+    >>> with lazyllm.graph() as g:
+    ...     g.node1 = lambda x: x * 2
+    ...     g.node2 = lambda x: x + 1
+    ...     g.node3 = lambda x, y: x + y
+    >>> g.add_edge('__start__', 'node1')
+    >>> g.add_edge('node1', 'node2')
+    >>> g.add_edge('node3', '__end__')
+    >>> g._nodes['node1'].outputs
+    [<Flow type=Node name=node2>]
+    >>> def double_input(data):
+    ...     return data * 2
+    >>> g.add_edge('node1', 'node3', formatter=double_input)
+    >>> g._nodes['node3'].inputs
+    {'node1': <function double_input at ...>}
+    """
         if isinstance(from_node, (tuple, list)):
             return [self.add_edge(f, to_node, formatter) for f in from_node]
         if isinstance(to_node, (tuple, list)):
@@ -924,6 +1206,23 @@ class Graph(LazyLLMFlowsBase):
         self._out_degree[from_node] += 1
 
     def add_const_edge(self, constant, to_node):
+        """Add a constant edge that passes a fixed value to a specified node.
+
+This method is used to pass constant values as input to nodes in the graph without needing to get data from other nodes.
+
+Args:
+    constant: The constant value to pass.
+    to_node (str or Node): The name or Node object of the target node.
+
+
+Examples:
+    >>> import lazyllm
+    >>> with lazyllm.graph() as g:
+    ...     g.add = lambda x, y: x + y
+    >>> g.add_const_edge(10, 'add')
+    >>> g._constants
+    [10]
+    """
         if isinstance(to_node, (tuple, list)):
             return [self.add_const_edge(constant, t) for t in to_node]
         if isinstance(to_node, str): to_node = self._nodes[to_node]
@@ -931,6 +1230,40 @@ class Graph(LazyLLMFlowsBase):
         self._constants.append(constant)
 
     def topological_sort(self):
+        """Perform topological sorting to return the correct node execution order.
+
+This method uses Kahn's algorithm to perform topological sorting on the directed acyclic graph, ensuring all dependencies are satisfied.
+
+**Returns:**
+
+- List[Node]: List of nodes arranged in topological order.
+
+**Raises:**
+
+- ValueError: If there are circular dependencies in the graph.
+
+
+Examples:
+    >>> import lazyllm
+    >>> with lazyllm.graph() as g:
+    ...     g.node1 = lambda x: x * 2
+    ...     g.node2 = lambda x: x + 1
+    ...     g.node3 = lambda x, y: x + y
+    >>> g.add_edge('__start__', 'node1')
+    >>> g.add_edge('node1', 'node2')
+    >>> g.add_edge('node1', 'node3')
+    >>> g.add_edge('node2', 'node3')
+    >>> g.add_edge('node3', '__end__')
+    >>> sorted_nodes = g.topological_sort()
+    >>> [node.name for node in sorted_nodes]
+    ['__start__', 'node1', 'node2', 'node3', '__end__']
+    >>> g.add_edge('node3', 'node1')
+    >>> try:
+    ...     g.topological_sort()
+    ... except ValueError as e:
+    ...     print("检测到循环依赖")
+    检测到循环依赖
+    """
         in_degree = self._in_degree.copy()
         queue = deque([node for node in self._nodes.values() if in_degree[node] == 0])
         sorted_nodes: List[Graph.Node] = []
@@ -949,11 +1282,39 @@ class Graph(LazyLLMFlowsBase):
         return [n for n in sorted_nodes if (self._in_degree[n] > 0 or self._out_degree[n] > 0)]
 
     def compute_node(self, sid, node, intermediate_results, futures):
+        """Compute the output result of a single node.
+
+This is an internal method of the graph, used to execute the computation of a single node, including getting input data, applying formatter functions, calling node functions, etc.
+
+Args:
+    sid: Session ID.
+    node (Node): The node to compute.
+    intermediate_results (dict): Intermediate result storage.
+    futures (dict): Async task dictionary.
+
+**Returns:**
+
+- The computation result of the node.
+
+
+Examples:
+    >>> import lazyllm
+    >>> with lazyllm.graph() as g:
+    ...     g.add = lambda x, y: x + y
+    ...     g.multiply = lambda x: x * 2
+    >>> g.add_edge('__start__', 'add')
+    >>> g.add_const_edge(5, 'add')
+    >>> g.add_edge('add', 'multiply')
+    >>> g.add_edge('multiply', '__end__')
+    >>> result = g(3)  # x=3, y=5 (常量)
+    >>> result
+    16
+    """
         globals._init_sid(sid)
 
         def get_input(name):
             if name.startswith('_lazyllm_constant_'):
-                return self._constants[int(name.strip('_lazyllm_constant_'))]
+                return self._constants[int(name.removeprefix('_lazyllm_constant_'))]
             if name not in intermediate_results['values']:
                 r = futures[name].result()
                 with intermediate_results['lock']:
@@ -996,7 +1357,8 @@ class Graph(LazyLLMFlowsBase):
 
             for node in self._sorted_nodes:
                 if node.name == '__start__':
-                    intermediate_results['values'][node.name] = arguments(__input, kw)
+                    intermediate_results['values'][node.name] = (
+                        arguments(__input, kw) if (__input and kw) else (kw or __input))
                 else:
                     future = executor.submit(self.compute_node, globals._sid, node, intermediate_results, futures)
                     futures[node.name] = future
