@@ -6,6 +6,7 @@ import random
 import atexit
 import threading
 import subprocess
+import multiprocessing
 from enum import Enum
 from queue import Queue
 from datetime import datetime
@@ -24,7 +25,6 @@ import yaml
 from typing import Literal
 
 class Status(Enum):
-    """An enumeration."""
     TBSubmitted = 0,
     InQueue = 1
     Running = 2,
@@ -91,7 +91,7 @@ class Job(object):
         assert isinstance(cmd, LazyLLMCMD)
         self._origin_cmd = cmd
         self.sync = sync
-        self.launcher = launcher
+        self._launcher = launcher
         self.queue, self.jobid, self.ip, self.ps = Queue(), None, None, None
         self.output_hooks = []
 
@@ -133,13 +133,13 @@ class Job(object):
         if self.sync:
             self.ps.wait()
         else:
-            self.launcher.all_processes[self.launcher._id].append((self.jobid, self))
+            self._launcher.all_processes[self._launcher._id].append((self.jobid, self))
             n = 0
             while self.status in (Status.TBSubmitted, Status.InQueue, Status.Pending):
                 time.sleep(2)
                 n += 1
                 if n > 1800:  # 3600s
-                    self.launcher.all_processes[self.launcher._id].pop()
+                    self._launcher.all_processes[self._launcher._id].pop()
                     LOG.error('Launch failed: No computing resources are available.')
                     break
 
@@ -169,10 +169,14 @@ class Job(object):
                 try:
                     line = line.decode('utf-8')
                 except Exception:
-                    pass
-                queue.put(line)
-                if hooks:
-                    hooks(line) if callable(hooks) else [hook(line) for hook in hooks]
+                    try:
+                        line = line.decode('gb2312')
+                    except Exception:
+                        pass
+                if isinstance(line, str):
+                    queue.put(line)
+                    if hooks:
+                        hooks(line) if callable(hooks) else [hook(line) for hook in hooks]
                 LOG.info(f'{self.jobid}: {line.rstrip()}', )
                 if self.output_thread_event.is_set():
                     break
@@ -310,7 +314,7 @@ class K8sLauncher(LazyLLMLaunchersBase):
                 raise
 
         def _delete_deployment(self, wait_for_completion=True, timeout=60, check_interval=5):
-            k8s.config.load_kube_config(self.launcher.kube_config_path)
+            k8s.config.load_kube_config(self._launcher.kube_config_path)
             api_instance = k8s.client.AppsV1Api()
             try:
                 api_instance.delete_namespaced_deployment(
@@ -369,7 +373,7 @@ class K8sLauncher(LazyLLMLaunchersBase):
                 raise
 
         def _delete_service(self, wait_for_completion=True, timeout=60, check_interval=5):
-            k8s.config.load_kube_config(self.launcher.kube_config_path)
+            k8s.config.load_kube_config(self._launcher.kube_config_path)
             svc_instance = k8s.client.CoreV1Api()
             service_name = f"service-{self.deployment_name}"
             try:
@@ -470,7 +474,7 @@ class K8sLauncher(LazyLLMLaunchersBase):
                     raise
 
         def _delete_or_update_gateway(self, wait_for_completion=True, timeout=60, check_interval=5):
-            k8s.config.load_kube_config(self.launcher.kube_config_path)
+            k8s.config.load_kube_config(self._launcher.kube_config_path)
             gateway_instance = k8s.client.CustomObjectsApi()
             try:
                 gateway = gateway_instance.get_namespaced_custom_object(
@@ -610,7 +614,7 @@ class K8sLauncher(LazyLLMLaunchersBase):
                 raise
 
         def _delete_httproute(self, wait_for_deletion=True, timeout=60, check_interval=5):
-            k8s.config.load_kube_config(self.launcher.kube_config_path)
+            k8s.config.load_kube_config(self._launcher.kube_config_path)
             httproute_instance = k8s.client.CustomObjectsApi()
             httproute_name = f"httproute-{self.deployment_name}"
             try:
@@ -658,7 +662,7 @@ class K8sLauncher(LazyLLMLaunchersBase):
             self._create_or_update_gateway()
             self._create_httproute()
             self.jobid = self._get_jobid()
-            self.launcher.all_processes[self.launcher._id].append((self.jobid, self))
+            self._launcher.all_processes[self._launcher._id].append((self.jobid, self))
             ret = self.wait()
             LOG.info(ret)
 
@@ -857,7 +861,7 @@ class K8sLauncher(LazyLLMLaunchersBase):
 
         def _is_gateway_ready(self, timeout):
             url = f"http://{self.get_jobip()}:{self.deployment_port}{self.path}"
-            for i in range(self.gateway_retry):
+            for _ in range(self.gateway_retry):
                 try:
                     response = requests.get(url, timeout=timeout)
                     if response.status_code != 503:
@@ -1046,18 +1050,6 @@ class K8sLauncher(LazyLLMLaunchersBase):
 
 @final
 class EmptyLauncher(LazyLLMLaunchersBase):
-    """This class is a subclass of ``LazyLLMLaunchersBase`` and serves as a local launcher.
-
-Args:
-    subprocess (bool): Whether to use a subprocess to launch. Default is ``False``.
-    sync (bool): Whether to execute jobs synchronously. Default is ``True``, otherwise it executes asynchronously.
-
-
-
-Examples:
-    >>> import lazyllm
-    >>> launcher = lazyllm.launchers.empty()
-    """
     all_processes = defaultdict(list)
 
     @final
@@ -1066,17 +1058,17 @@ Examples:
             super(__class__, self).__init__(cmd, launcher, sync=sync)
 
         def _wrap_cmd(self, cmd):
-            if self.launcher.ngpus == 0:
+            if self._launcher.ngpus == 0:
                 return cmd
-            gpus = self.launcher._get_idle_gpus()
+            gpus = self._launcher._get_idle_gpus()
             if gpus and lazyllm.config['cuda_visible']:
-                if self.launcher.ngpus is None:
+                if self._launcher.ngpus is None:
                     empty_cmd = f'CUDA_VISIBLE_DEVICES={gpus[0]} '
-                elif self.launcher.ngpus <= len(gpus):
+                elif self._launcher.ngpus <= len(gpus):
                     empty_cmd = 'CUDA_VISIBLE_DEVICES=' + \
-                                ','.join([str(n) for n in gpus[:self.launcher.ngpus]]) + ' '
+                                ','.join([str(n) for n in gpus[:self._launcher.ngpus]]) + ' '
                 else:
-                    error_info = (f'Not enough GPUs available. Requested {self.launcher.ngpus} GPUs, '
+                    error_info = (f'Not enough GPUs available. Requested {self._launcher.ngpus} GPUs, '
                                   f'but only {len(gpus)} are available.')
                     LOG.error(error_info)
                     raise error_info
@@ -1134,7 +1126,6 @@ Examples:
                 return f(*args, **kw)
             else:
                 LOG.info("Async execution of callable object is not supported currently.")
-                import multiprocessing
                 p = multiprocessing.Process(target=f, args=args, kwargs=kw)
                 p.start()
                 p.join()
@@ -1167,24 +1158,6 @@ Examples:
 
 @final
 class SlurmLauncher(LazyLLMLaunchersBase):
-    """This class is a subclass of ``LazyLLMLaunchersBase`` and acts as a Slurm launcher.
-
-Specifically, it provides methods to start and configure Slurm jobs, including specifying parameters such as the partition, number of nodes, number of processes, number of GPUs, and timeout settings.
-
-Args:
-    partition (str): The Slurm partition to use. Defaults to ``None``, in which case the default partition in ``lazyllm.config['partition']`` will be used. This configuration can be enabled by setting environment variables, such as ``export LAZYLLM_SLURM_PART=a100``.
-    nnode  (int): The number of nodes to use. Defaults to ``1``.
-    nproc (int): The number of processes per node. Defaults to ``1``.
-    ngpus (int): The number of GPUs per node. Defaults to ``None``, meaning no GPUs will be used.
-    timeout (int): The timeout for the job in seconds. Defaults to ``None``, in which case no timeout will be set.
-    sync (bool): Whether to execute the job synchronously. Defaults to ``True``, otherwise it will be executed asynchronously.
-
-
-
-Examples:
-    >>> import lazyllm
-    >>> launcher = lazyllm.launchers.slurm(partition='partition_name', nnode=1, nproc=1, ngpus=1, sync=False)
-    """
     # In order to obtain the jobid to monitor and terminate the job more
     # conveniently, only one srun command is allowed in one Job
     all_processes = defaultdict(list)
@@ -1198,13 +1171,13 @@ Examples:
 
         def _wrap_cmd(self, cmd):
             # Assemble the order
-            slurm_cmd = f'srun -p {self.launcher.partition} -N {self.launcher.nnode} --job-name={self.name}'
-            if self.launcher.nproc:
-                slurm_cmd += f' -n{self.launcher.nproc}'
-            if self.launcher.timeout:
-                slurm_cmd += f' -t {self.launcher.timeout}'
-            if self.launcher.ngpus:
-                slurm_cmd += f' --gres=gpu:{self.launcher.ngpus}'
+            slurm_cmd = f'srun -p {self._launcher.partition} -N {self._launcher.nnode} --job-name={self.name}'
+            if self._launcher.nproc:
+                slurm_cmd += f' -n{self._launcher.nproc}'
+            if self._launcher.timeout:
+                slurm_cmd += f' -t {self._launcher.timeout}'
+            if self._launcher.ngpus:
+                slurm_cmd += f' --gres=gpu:{self._launcher.ngpus}'
             return f'{slurm_cmd} bash -c \'{cmd}\''
 
         def _get_jobid(self):
@@ -1293,10 +1266,10 @@ Examples:
         return result
 
     def get_idle_nodes(self, partion=None):
-        """
+        '''
         Obtain the current number of available nodes based on the available number of GPUs.
         Return a dictionary with node IP as the key and the number of available GPUs as the value.
-        """
+        '''
         if not partion:
             partion = self.partition
         num_can_use_nodes = self.num_can_use_nodes
@@ -1356,26 +1329,6 @@ Examples:
 
 @final
 class ScoLauncher(LazyLLMLaunchersBase):
-    """This class is a subclass of ``LazyLLMLaunchersBase`` and acts as a SCO launcher.
-
-Specifically, it provides methods to start and configure SCO jobs, including specifying parameters such as the partition, workspace name, framework type, number of nodes, number of processes, number of GPUs, and whether to use torchrun or not.
-
-Args:
-    partition (str): The Slurm partition to use. Defaults to ``None``, in which case the default partition in ``lazyllm.config['partition']`` will be used. This configuration can be enabled by setting environment variables, such as ``export LAZYLLM_SLURM_PART=a100``.
-    workspace_name (str): The workspace name on SCO. Defaults to the configuration in ``lazyllm.config['sco.workspace']``. This configuration can be enabled by setting environment variables, such as ``export LAZYLLM_SCO_WORKSPACE=myspace``.
-    framework (str): The framework type to use, for example, ``pt`` for PyTorch. Defaults to ``pt``.
-    nnode  (int): The number of nodes to use. Defaults to ``1``.
-    nproc (int): The number of processes per node. Defaults to ``1``.
-    ngpus (int): The number of GPUs per node. Defaults to ``1``, using 1 GPU.
-    torchrun (bool): Whether to start the job with ``torchrun``. Defaults to ``False``.
-    sync (bool): Whether to execute the job synchronously. Defaults to ``True``, otherwise it will be executed asynchronously.
-
-
-
-Examples:
-    >>> import lazyllm
-    >>> launcher = lazyllm.launchers.sco(partition='partition_name', nnode=1, nproc=1, ngpus=1, sync=False)
-    """
     all_processes = defaultdict(list)
 
     @final
@@ -1393,7 +1346,7 @@ Examples:
                 self.ip = line.split()[-1]
 
         def _wrap_cmd(self, cmd):
-            launcher = self.launcher
+            launcher = self._launcher
             # Assemble the cmd
             sco_cmd = f'srun -p {launcher.partition} --workspace-id {self.workspace_name} ' \
                       f'--job-name={self.name} -f {launcher.framework} ' \
@@ -1529,8 +1482,8 @@ Examples:
                         return Status.Cancelled
                     elif job_state == 'succeeded':
                         return Status.Done
-                except Exception:
-                    pass
+                except Exception as e:
+                    lazyllm.LOG.error(f'Failed to get job status, reason is {str(e)}')
             return Status.Failed
 
     def __init__(self, partition=None, workspace_name=lazyllm.config['sco.workspace'],
@@ -1563,23 +1516,6 @@ Examples:
 
 
 class RemoteLauncher(LazyLLMLaunchersBase):
-    """This class is a subclass of ``LazyLLMLaunchersBase`` and acts as a proxy for a remote launcher. It dynamically creates and returns an instance of the corresponding launcher based on the ``lazyllm.config['launcher']`` entry in the configuration file (for example: ``SlurmLauncher`` or ``ScoLauncher``).
-
-Args:
-    *args: Positional arguments that will be passed to the constructor of the dynamically created launcher.
-    sync (bool): Whether to execute the job synchronously. Defaults to ``False``.
-    **kwargs: Keyword arguments that will be passed to the constructor of the dynamically created launcher.
-
-Notes: 
-    - ``RemoteLauncher`` is not a direct launcher but dynamically creates a launcher based on the configuration. 
-    - The ``lazyllm.config['launcher']`` in the configuration file specifies a launcher class name present in the ``lazyllm.launchers`` module. This configuration can be set by setting the environment variable ``LAZYLLM_DEAULT_LAUNCHER``. For example: ``export LAZYLLM_DEAULT_LAUNCHER=sco``, ``export LAZYLLM_DEAULT_LAUNCHER=slurm``.
-
-
-
-Examples:
-    >>> import lazyllm
-    >>> launcher = lazyllm.launchers.remote(ngpus=1)
-    """
     def __new__(cls, *args, sync=False, ngpus=1, **kwargs):
         return getattr(lazyllm.launchers, lazyllm.config['launcher'])(*args, sync=sync, ngpus=ngpus, **kwargs)
 
