@@ -7,10 +7,11 @@ package_name_map = {
     'huggingface_hub': 'huggingface-hub',
     'jwt': 'PyJWT',
     'rank_bm25': 'rank-bm25',
-    'collie': 'collie-lm',
     'faiss': 'faiss-cpu',
     'flash_attn': 'flash-attn',
-    'sklearn': 'scikit-learn'
+    'sklearn': 'scikit-learn',
+    'volcenginesdkarkruntime': 'volcengine-python-sdk[ark]',
+    'opensearchpy': 'opensearch-py',
 }
 
 requirements = {}
@@ -69,7 +70,7 @@ class PackageWrapper(object):
         try:
             return getattr(importlib.import_module(
                 self._Wrapper__key, package=self._Wrapper__package), __name)
-        except (ImportError, ModuleNotFoundError):
+        except ImportError:
             pip_cmd = get_pip_install_cmd([self._Wrapper__key])
             if pip_cmd:
                 err_msg = f'Cannot import module {self._Wrapper__key}, please install it by {pip_cmd}'
@@ -77,9 +78,18 @@ class PackageWrapper(object):
                 err_msg = f'Cannot import module {self._Wrapper__key}'
             raise ImportError(err_msg)
 
+    def __setattr__(self, __name, __value):
+        if __name in ('_Wrapper__key', '_Wrapper__package'):
+            return super(__class__, self).__setattr__(__name, __value)
+        setattr(importlib.import_module(
+            self._Wrapper__key, package=self._Wrapper__package), __name, __value)
+
 modules = ['redis', 'huggingface_hub', 'jieba', 'modelscope', 'pandas', 'jwt', 'rank_bm25', 'redisvl', 'datasets',
-           'deepspeed', 'fire', 'numpy', 'peft', 'torch', 'transformers', 'collie', 'faiss', 'flash_attn', 'google',
+           'deepspeed', 'fire', 'numpy', 'peft', 'torch', 'transformers', 'faiss', 'flash_attn', 'google',
            'lightllm', 'vllm', 'ChatTTS', 'wandb', 'funasr', 'sklearn', 'torchvision', 'scipy', 'pymilvus',
-           'sentence_transformers', 'gradio', 'chromadb', 'nltk', 'PIL', 'httpx', 'bm25s', 'kubernetes', 'pymongo']
+           'sentence_transformers', 'gradio', 'chromadb', 'nltk', 'PIL', 'httpx', 'bm25s', 'kubernetes', 'pymongo',
+           'rapidfuzz', 'FlagEmbedding', 'mcp', 'diffusers', 'pypdf', 'pptx', 'html2text', 'ebooklib', 'docx2txt',
+           'zlib', 'struct', 'olefile', 'spacy', 'tarfile', 'boto3', 'botocore', 'paddleocr', 'volcenginesdkarkruntime',
+           'zhipuai', 'dashscope', 'opensearchpy']
 for m in modules:
     vars()[m] = PackageWrapper(m)
