@@ -1,15 +1,17 @@
-from .functionCall import FunctionCall, FunctionCallAgent
+from .functionCall import FunctionCall, FunctionCallAgent, FunctionCallFormatter
 from .toolsManager import register, ToolManager
 from .reactAgent import ReactAgent
 from .planAndSolveAgent import PlanAndSolveAgent
 from .rewooAgent import ReWOOAgent
-
+from .toolsManager import ModuleTool
 __all__ = [
     "ToolManager",
     "FunctionCall",
     "FunctionCallAgent",
+    "FunctionCallFormatter",
     "register",
     "ReactAgent",
     "PlanAndSolveAgent",
-    "ReWOOAgent"
+    "ReWOOAgent",
+    "ModuleTool"
 ]
