@@ -51,6 +51,38 @@ def _check_return_type_is_the_same(doc_type_hints, func_type_hints) -> None:
 # ---------------------------------------------------------------------------- #
 
 class ModuleTool(ModuleBase, metaclass=LazyLLMRegisterMetaClass):
+    """Base class for defining tools using callable Python functions.
+
+This class automatically parses function signatures and docstrings to build a parameter schema using `pydantic`. It also performs input validation and handles standardized tool execution.
+
+`__init__(self, verbose=False, return_trace=True)`
+Initializes a tool wrapper module.
+
+Args:
+    verbose (bool): Whether to print verbose logs during execution.
+    return_trace (bool): Whether to keep intermediate execution trace in the result.
+
+
+Examples:
+    
+    >>> from lazyllm.components import ModuleTool
+    >>> class AddTool(ModuleTool):
+    ...     def apply(self, a: int, b: int) -> int:
+    ...         '''Add two integers.
+    ...         
+    ...         Args:
+    ...             a (int): First number.
+    ...             b (int): Second number.
+    ...         
+    ...         Returns:
+    ...             int: The sum of a and b.
+    ...         '''
+    ...         return a + b
+    >>> tool = AddTool()
+    >>> result = tool({'a': 3, 'b': 5})
+    >>> print(result)
+    8
+    """
     def __init__(self, verbose: bool = False, return_trace: bool = True):
         super().__init__(return_trace=return_trace)
         self._verbose = verbose
@@ -78,7 +110,7 @@ class ModuleTool(ModuleBase, metaclass=LazyLLMRegisterMetaClass):
 
         signature = inspect.signature(func)
         has_var_args = False
-        for name, param in signature.parameters.items():
+        for _, param in signature.parameters.items():
             if param.kind == inspect.Parameter.VAR_POSITIONAL or\
                param.kind == inspect.Parameter.VAR_KEYWORD:
                 has_var_args = True
@@ -123,9 +155,17 @@ class ModuleTool(ModuleBase, metaclass=LazyLLMRegisterMetaClass):
 
     @property
     def required_args(self) -> Set[str]:
-        return set(self._params_schema.model_json_schema()["required"])
+        return set(self._params_schema.model_json_schema().get("required", []))
 
     def apply(self, *args: Any, **kwargs: Any) -> Any:
+        """
+Abstract method to be implemented in subclasses.
+
+This method should perform a specific task based on the provided arguments.
+
+Raises:
+    NotImplementedError: If the method is not overridden in a subclass.
+"""
         raise NotImplementedError("Implement apply function in subclass")
 
     def _validate_input(self, tool_input: Dict[str, Any]) -> Dict[str, Any]:
@@ -152,6 +192,17 @@ class ModuleTool(ModuleBase, metaclass=LazyLLMRegisterMetaClass):
             raise TypeError(f"tool_input {tool_input} only supports dict and str.")
 
     def validate_parameters(self, arguments: Dict[str, Any]) -> bool:
+        """
+Validate whether the provided arguments meet the required criteria.
+
+This method checks if all required keys are present in the input dictionary and attempts format validation.
+
+Args:
+    arguments (Dict[str, Any]): Dictionary of input arguments.
+
+Returns:
+    bool: True if valid and complete; False otherwise.
+"""
         if len(self.required_args.difference(set(arguments.keys()))) == 0:
             # contains all required parameters
             try:
@@ -172,10 +223,11 @@ class ModuleTool(ModuleBase, metaclass=LazyLLMRegisterMetaClass):
 
         return ret
 
-register = lazyllm.Register(ModuleTool, ["apply"])
+register = lazyllm.Register(ModuleTool, ["apply"], default_group='tool')
 if "tool" not in LazyLLMRegisterMetaClass.all_clses:
     register.new_group("tool")
 
+
 class ToolManager(ModuleBase):
     """ToolManager is a tool management class used to provide tool information and tool calls to function call.
 
@@ -183,6 +235,8 @@ When constructing this management class, you need to pass in a list of tool name
 
 Args:
     tools (List[str]): A list of tool name strings.
+    return_trace (bool): If True, return intermediate steps and tool calls.
+    stream (bool): Whether to stream the planning and solving process.
 
 
 Examples:
