@@ -1,7 +1,8 @@
-from .serve import InferServer
+from .serve import InferServer, JobDescription
 from .client import InferClient
 
 __all__ = [
     'InferServer',
     'InferClient',
+    "JobDescription"
 ]
