@@ -1,23 +1,23 @@
 from .document import Document
-from .retriever import Retriever
+from .retriever import Retriever, TempDocRetriever
 from .rerank import Reranker, register_reranker
 from .transform import SentenceSplitter, LLMParser, NodeTransform, TransformArgs, AdaptiveTransform
 from .similarity import register_similarity
 from .doc_node import DocNode
 from .readers import (PDFReader, DocxReader, HWPReader, PPTXReader, ImageReader, IPYNBReader, EpubReader,
                       MarkdownReader, MboxReader, PandasCSVReader, PandasExcelReader, VideoAudioReader)
-from .dataReader import SimpleDirectoryReader
+from .dataReader import SimpleDirectoryReader, FileReader
 from .doc_manager import DocManager, DocListManager
 from .global_metadata import GlobalMetadataDesc as DocField
 from .data_type import DataType
 from .index_base import IndexBase
-from .store_base import StoreBase
-
+from .store import LazyLLMStoreBase
 
 __all__ = [
     "Document",
     "Reranker",
     "Retriever",
+    "TempDocRetriever",
     "NodeTransform",
     "AdaptiveTransform",
     "TransformArgs",
@@ -44,5 +44,6 @@ __all__ = [
     'DocField',
     'DataType',
     'IndexBase',
-    'StoreBase',
+    'LazyLLMStoreBase',
+    "FileReader",
 ]
