@@ -13,12 +13,13 @@ from itertools import repeat
 from typing import Dict, Optional, List, Callable, Type
 from pathlib import Path, PurePosixPath, PurePath
 from fsspec import AbstractFileSystem
-from lazyllm import ModuleBase, LOG
+from lazyllm import ModuleBase, LOG, config
+from lazyllm.components.formatter.formatterbase import _lazyllm_get_file_list
 from .doc_node import DocNode
 from .readers import (ReaderBase, PDFReader, DocxReader, HWPReader, PPTXReader, ImageReader, IPYNBReader,
                       EpubReader, MarkdownReader, MboxReader, PandasCSVReader, PandasExcelReader, VideoAudioReader,
                       get_default_fs, is_default_fs)
-from .global_metadata import (RAG_DOC_FILE_NAME, RAG_DOC_FILE_TYPE, RAG_DOC_FILE_SIZE,
+from .global_metadata import (RAG_DOC_PATH, RAG_DOC_FILE_NAME, RAG_DOC_FILE_TYPE, RAG_DOC_FILE_SIZE,
                               RAG_DOC_CREATION_DATE, RAG_DOC_LAST_MODIFIED_DATE, RAG_DOC_LAST_ACCESSED_DATE)
 
 def _file_timestamp_format(timestamp: float, include_time: bool = False) -> Optional[str]:
@@ -45,6 +46,7 @@ class _DefaultFileMetadataFunc:
         last_modified_date = _file_timestamp_format(stat_result.get("mtime"))
         last_accessed_date = _file_timestamp_format(stat_result.get("atime"))
         default_meta = {
+            RAG_DOC_PATH: file_path,
             RAG_DOC_FILE_NAME: file_name,
             RAG_DOC_FILE_TYPE: mimetypes.guess_type(file_path)[0],
             RAG_DOC_FILE_SIZE: stat_result.get("size"),
@@ -56,6 +58,31 @@ class _DefaultFileMetadataFunc:
         return {meta_key: meta_value for meta_key, meta_value in default_meta.items() if meta_value is not None}
 
 class SimpleDirectoryReader(ModuleBase):
+    """
+A modular document directory reader that inherits from ModuleBase, supporting reading various document formats from the file system and converting them into standardized DocNode objects.
+Args:
+    input_dir (Optional[str]): Input directory path. Mutually exclusive with input_files.
+    input_files (Optional[List]): Directly specified list of files. Mutually exclusive with input_dir.
+    exclude (Optional[List]): List of file patterns to exclude.
+    exclude_hidden (bool): Whether to exclude hidden files.
+    recursive (bool): Whether to recursively read subdirectories.
+    encoding (str): Encoding format of text files.
+    required_exts (Optional[List[str]]): Whitelist of file extensions to process.
+    file_extractor (Optional[Dict[str, Callable]]): Dictionary of custom file readers.
+    fs (Optional[AbstractFileSystem]): Custom file system.
+    metadata_genf (Optional[Callable[[str], Dict]]): Metadata generation function that takes a file path and returns a metadata dictionary.
+    num_files_limit (Optional[int]): Maximum number of files to read.
+    return_trace (bool): Whether to return processing trace information.
+    metadatas (Optional[Dict]): Predefined global metadata dictionary.
+
+
+Examples:
+    
+    >>> import lazyllm
+    >>> from lazyllm.tools.dataReader import SimpleDirectoryReader
+    >>> reader = SimpleDirectoryReader(input_dir="yourpath/",recursive=True,exclude=["*.tmp"],required_exts=[".pdf", ".docx"])
+    >>> documents = reader.load_data()
+    """
     default_file_readers: Dict[str, Type[ReaderBase]] = {
         "*.pdf": PDFReader,
         "*.docx": DocxReader,
@@ -105,7 +132,9 @@ class SimpleDirectoryReader(ModuleBase):
             self._input_files = []
             for path in input_files:
                 if not self._fs.isfile(path):
-                    raise ValueError(f"File {path} does not exist.")
+                    path = os.path.join(config['data_path'], path)
+                    if not self._fs.isfile(path):
+                        raise ValueError(f"File {path} does not exist.")
                 input_file = self._Path(path)
                 self._input_files.append(input_file)
         elif input_dir:
@@ -117,7 +146,7 @@ class SimpleDirectoryReader(ModuleBase):
         self._file_extractor = file_extractor or {}
 
         self._metadata_genf = metadata_genf or _DefaultFileMetadataFunc(self._fs)
-        self._filename_as_id = filename_as_id
+        if filename_as_id: LOG.warning('Argument `filename_as_id` for DataReader is no longer used')
 
     def _add_files(self, input_dir: Path) -> List[Path]:  # noqa: C901
         all_files = set()
@@ -184,48 +213,61 @@ class SimpleDirectoryReader(ModuleBase):
         for doc in documents:
             doc._excluded_embed_metadata_keys.extend(
                 ["file_name", "file_type", "file_size", "creation_date",
-                 "last_modified_date", "last_accessed_date"])
+                 "last_modified_date", "last_accessed_date", "lazyllm_store_num"])
             doc._excluded_llm_metadata_keys.extend(
                 ["file_name", "file_type", "file_size", "creation_date",
-                 "last_modified_date", "last_accessed_date"])
+                 "last_modified_date", "last_accessed_date", "lazyllm_store_num"])
         return documents
 
     @staticmethod
     def load_file(input_file: Path, metadata_genf: Callable[[str], Dict], file_extractor: Dict[str, Callable],
-                  filename_as_id: bool = False, encoding: str = "utf-8", pathm: PurePath = Path,
-                  fs: Optional[AbstractFileSystem] = None, metadata: Optional[Dict] = None) -> List[DocNode]:
-        metadata: dict = metadata or {}
+                  encoding: str = "utf-8", pathm: PurePath = Path, fs: Optional[AbstractFileSystem] = None,
+                  metadata: Optional[Dict] = None) -> List[DocNode]:
+        # metadata priority: user > reader > metadata_genf
+        user_metadata: Dict = metadata or {}
+        metadata_generated: Dict = metadata_genf(str(input_file)) if metadata_genf else {}
         documents: List[DocNode] = []
 
-        if metadata_genf is not None: metadata.update(metadata_genf(str(input_file)))
-        file_reader_patterns = list(file_extractor.keys())
+        filename_lower = str(input_file).lower()
 
-        for pattern in file_reader_patterns:
-            pt = str(pathm(pattern))
-            match_pattern = pt if pt.startswith("*") else os.path.join(str(pathm.cwd()), pt)
-            if fnmatch.fnmatch(input_file, match_pattern):
-                reader = file_extractor[pattern]
-                reader = reader() if isinstance(reader, type) else reader
-                kwargs = {"extra_info": metadata}
-                if fs and not is_default_fs(fs): kwargs['fs'] = fs
+        for pattern, extractor in file_extractor.items():
+            pt_lower = str(pathm(pattern)).lower()
+            match_pattern = pt_lower if pt_lower.endswith("*") else os.path.join(str(pathm.cwd()).lower(), pt_lower)
+            if pt_lower.startswith("*"):
+                match_pattern = pt_lower
+            else:
+                base = str(pathm.cwd()).lower()
+                match_pattern = os.path.join(base, pt_lower)
+
+            if fnmatch.fnmatch(filename_lower, match_pattern):
+                reader = extractor() if isinstance(extractor, type) else extractor
+                kwargs = {'fs': fs} if fs and not is_default_fs(fs) else {}
                 docs = reader(input_file, **kwargs)
+                if isinstance(docs, DocNode): docs = [docs]
+                for doc in docs:
+                    metadata = metadata_generated.copy()
+                    metadata.update(doc._global_metadata or {})
+                    metadata.update(user_metadata)
+                    doc._global_metadata = metadata
 
-                if filename_as_id:
+                if config['rag_filename_as_id']:
                     for i, doc in enumerate(docs):
                         doc._uid = f"{input_file!s}_index_{i}"
-                        doc.docpath = str(input_file)
                 documents.extend(docs)
                 break
         else:
+            if not config['use_fallback_reader']:
+                LOG.warning(f'no pattern found for {input_file}! '
+                            'If you want fallback to default Reader, set `LAZYLLM_USE_FALLBACK_READER=True`.')
+                return documents
             fs = fs or get_default_fs()
             with fs.open(input_file, encoding=encoding) as f:
-                data = f.read().decode(encoding)
-
-            doc = DocNode(text=data, global_metadata=metadata or {})
-            doc.docpath = str(input_file)
-            if filename_as_id: doc._uid = str(input_file)
-            documents.append(doc)
-
+                try:
+                    data = f.read().decode(encoding)
+                    doc = DocNode(text=data, global_metadata=user_metadata)
+                    documents.append(doc)
+                except Exception:
+                    LOG.error(f'no pattern found for {input_file} and it is not utf-8, skip it!')
         return documents
 
     def _load_data(self, show_progress: bool = False, num_workers: Optional[int] = None,
@@ -245,19 +287,49 @@ class SimpleDirectoryReader(ModuleBase):
             with multiprocessing.get_context("spawn").Pool(num_workers) as p:
                 results = p.starmap(SimpleDirectoryReader.load_file,
                                     zip(process_file, repeat(self._metadata_genf), repeat(file_readers),
-                                        repeat(self._filename_as_id), repeat(self._encoding), repeat(self._Path),
+                                        repeat(self._encoding), repeat(self._Path),
                                         repeat(self._fs), self._metadatas or repeat(None)))
                 documents = reduce(lambda x, y: x + y, results)
         else:
             if show_progress:
                 process_file = tqdm(self._input_files, desc="Loading files", unit="file")
-            for input_file in process_file:
+            for input_file, metadata in zip(process_file, self._metadatas or repeat(None)):
                 documents.extend(
-                    SimpleDirectoryReader.load_file(input_file=input_file, metadata_genf=self._metadata_genf,
-                                                    file_extractor=file_readers, filename_as_id=self._filename_as_id,
-                                                    encoding=self._encoding, pathm=self._Path, fs=self._fs))
+                    SimpleDirectoryReader.load_file(
+                        input_file=input_file, metadata_genf=self._metadata_genf, file_extractor=file_readers,
+                        encoding=self._encoding, pathm=self._Path, fs=self._fs, metadata=metadata))
 
         return self._exclude_metadata(documents)
 
     def forward(self, *args, **kwargs) -> List[DocNode]:
         return self._load_data(*args, **kwargs)
+
+
+config.add('rag_filename_as_id', bool, False, 'RAG_FILENAME_AS_ID')
+config.add('use_fallback_reader', bool, True, 'USE_FALLBACK_READER')
+
+
+class FileReader(object):
+    """
+File content reader whose main function is to convert various input file formats into concatenated plain text content.
+Args:
+    input_files (Optional[List]): Directly specified list of input files.
+
+
+Examples:
+    
+    >>> import lazyllm
+    >>> from lazyllm.tools.dataReader import FileReader
+    >>> reader = FileReader()
+    >>> content = reader("yourpath/") 
+    """
+
+    def __call__(self, input_files):
+        file_list = _lazyllm_get_file_list(input_files)
+        if isinstance(file_list, str) and file_list is not None:
+            file_list = [file_list]
+        if len(file_list) == 0:
+            return []
+        nodes = SimpleDirectoryReader(input_files=file_list)._load_data()
+        txt = [node.get_text() for node in nodes]
+        return "\n".join(txt)
