@@ -1,10 +1,11 @@
 import os
 import json
+import traceback
+
 from typing import List, Optional, Dict, Union
 from pydantic import BaseModel, Field
-
 from starlette.responses import RedirectResponse
-from fastapi import UploadFile, Body
+from fastapi import UploadFile
 
 import lazyllm
 from lazyllm import FastapiApp as app
@@ -28,7 +29,6 @@ Args:
         self._manager.enable_path_monitoring = False
 
     def __reduce__(self):
-        # For unknown reason, when deserializing _manager monitoring is always enabled
         self._manager.enable_path_monitoring = False
         return (__class__, (self._manager,))
 
@@ -140,10 +140,28 @@ Args:
             lazyllm.LOG.error(f'upload_files exception: {e}')
             return BaseResponse(code=500, msg=str(e), data=None)
 
+    class AddFilesRequest(BaseModel):
+        files: List[str]
+        group_name: Optional[str] = None
+        metadatas: Optional[str] = None
+
     @app.post("/add_files")
-    def add_files(self, files: List[str] = Body(...),
-                  group_name: str = Body(None),
-                  metadatas: Optional[str] = Body(None)):
+    def add_files(self, request: AddFilesRequest):
+        """
+Batch add files.
+
+Args:
+    files (List[UploadFile]): List of uploaded files.
+    group_name (str): Target knowledge base group name; if empty, files are not added to any group.
+    metadatas (Optional[str]): Metadata of the files in JSON format.
+
+**Returns:**
+
+- BaseResponse: Returns a list of unique file IDs corresponding to all input files, including newly added and existing ones. In case of exceptions, returns error codes and exception information.
+"""
+        files = request.files
+        group_name = request.group_name
+        metadatas = request.metadatas
         try:
             if metadatas:
                 metadatas: Optional[List[Dict[str, str]]] = json.loads(metadatas)
@@ -206,6 +224,14 @@ Args:
         except Exception as e:
             return BaseResponse(code=500, msg=str(e), data=None)
 
+    @app.get("/reparse_files")
+    def reparse_files(self, file_ids: List[str], group_name: Optional[str] = None):
+        try:
+            self._manager.update_need_reparsing(file_ids, group_name)
+            return BaseResponse()
+        except Exception as e:
+            return BaseResponse(code=500, msg=str(e), data=None)
+
     @app.get("/list_files_in_group")
     def list_files_in_group(self, group_name: Optional[str] = None,
                             limit: Optional[int] = None, alive: Optional[bool] = None):
@@ -226,7 +252,6 @@ Args:
                       DocListManager.Status.failed] if alive else DocListManager.Status.all
             return BaseResponse(data=self._manager.list_kb_group_files(group_name, limit, details=True, status=status))
         except Exception as e:
-            import traceback
             return BaseResponse(code=500, msg=str(e) + '\ntraceback:\n' + str(traceback.format_exc()), data=None)
 
     class FileGroupRequest(BaseModel):
@@ -305,6 +330,16 @@ Args:
 
     @app.post("/delete_files_from_group")
     def delete_files_from_group(self, request: FileGroupRequest):
+        """
+An endpoint to delete specified files in a group.
+
+Args:
+    request (FileGroupRequest): Request containing a list of file IDs and the group name.
+
+**Returns:**
+
+- BaseResponse: Deletion operation result.
+"""
         try:
             self._manager.update_kb_group(cond_file_ids=request.file_ids, cond_group=request.group_name,
                                           new_status=DocListManager.Status.deleting)
@@ -318,6 +353,16 @@ Args:
 
     @app.post("/add_metadata")
     def add_metadata(self, add_metadata_request: AddMetadataRequest):
+        """
+An endpoint to add or update metadata for specified documents.
+
+Args:
+    add_metadata_request (AddMetadataRequest): Request containing list of document IDs and key-value metadata.
+
+**Returns:**
+
+- BaseResponse: Operation result information.
+"""
         doc_ids = add_metadata_request.doc_ids
         kv_pair = add_metadata_request.kv_pair
         try:
@@ -364,6 +409,16 @@ Args:
 
     @app.post("/delete_metadata_item")
     def delete_metadata_item(self, del_metadata_request: DeleteMetadataRequest):
+        """
+An endpoint to delete metadata fields or field values from specified documents.
+
+Args:
+    del_metadata_request (DeleteMetadataRequest): Request containing list of document IDs, field names, and/or deletion rules.
+
+**Returns:**
+
+- BaseResponse: Deletion operation result.
+"""
         doc_ids = del_metadata_request.doc_ids
         kv_pair = del_metadata_request.kv_pair
         keys = del_metadata_request.keys
@@ -397,6 +452,16 @@ Args:
 
     @app.post("/update_or_create_metadata_keys")
     def update_or_create_metadata_keys(self, update_metadata_request: UpdateMetadataRequest):
+        """
+An endpoint to update or create metadata fields for specified documents.
+
+Args:
+    update_metadata_request (UpdateMetadataRequest): Request containing a list of document IDs and metadata key-value pairs to update or create.
+
+**Returns:**
+
+- BaseResponse: Deletion operation result.
+"""
         doc_ids = update_metadata_request.doc_ids
         kv_pair = update_metadata_request.kv_pair
         try:
@@ -420,6 +485,16 @@ Args:
 
     @app.post("/reset_metadata")
     def reset_metadata(self, reset_metadata_request: ResetMetadataRequest):
+        """
+An endpoint to reset all metadata fields of specified documents.
+
+Args:
+    reset_metadata_request (ResetMetadataRequest): Request containing a list of document IDs and the new metadata dictionary to apply.
+
+**Returns:**
+
+- BaseResponse: Deletion operation result.
+"""
         doc_ids = reset_metadata_request.doc_ids
         new_meta = reset_metadata_request.new_meta
         try:
@@ -437,6 +512,16 @@ Args:
 
     @app.post("/query_metadata")
     def query_metadata(self, query_metadata_request: QueryMetadataRequest):
+        """
+An endpoint to query metadata of a specific document.
+
+Args:
+    query_metadata_request (QueryMetadataRequest): Request containing the document ID and an optional metadata field name.
+
+**Returns:**
+
+- BaseResponse: Returns the field value if key is specified and exists; otherwise returns full metadata. If the key does not exist, returns an error.
+"""
         doc_id = query_metadata_request.doc_id
         key = query_metadata_request.key
         try:
