@@ -1,16 +1,20 @@
 import os
 
 from typing import Callable, Optional, Dict, Union, List
+from functools import cached_property
 import lazyllm
-from lazyllm import ModuleBase, ServerModule, DynamicDescriptor, deprecated
+from lazyllm import ModuleBase, ServerModule, DynamicDescriptor, deprecated, OnlineChatModule, TrainableModule
 from lazyllm.launcher import LazyLLMLaunchersBase as Launcher
+from lazyllm.tools.sql.sql_manager import SqlManager, DBStatus
+from lazyllm.common.bind import _MetaBind
 
 from .doc_manager import DocManager
-from .doc_impl import DocImpl, StorePlaceholder, EmbedPlaceholder
+from .doc_impl import DocImpl, StorePlaceholder, EmbedPlaceholder, BuiltinGroups, DocumentProcessor, NodeGroupType
 from .doc_node import DocNode
+from .doc_to_db import DocInfoSchema, DocToDbProcessor, extract_db_schema_from_files
+from .store import LAZY_ROOT_NAME, EMBED_DEFAULT_KEY
 from .index_base import IndexBase
-from .store_base import LAZY_ROOT_NAME, EMBED_DEFAULT_KEY
-from .utils import DocListManager
+from .utils import DocListManager, ensure_call_endpoint
 from .global_metadata import GlobalMetadataDesc as DocField
 from .web import DocWebModule
 import copy
@@ -21,7 +25,14 @@ class CallableDict(dict):
     def __call__(self, cls, *args, **kw):
         return self[cls](*args, **kw)
 
-class Document(ModuleBase):
+
+class _MetaDocument(_MetaBind):
+    def __instancecheck__(self, __instance):
+        if isinstance(__instance, UrlDocument): return True
+        return super().__instancecheck__(__instance)
+
+
+class Document(ModuleBase, BuiltinGroups, metaclass=_MetaDocument):
     """Initialize a document module with an optional user interface.
 
 This constructor initializes a document module that can have an optional user interface. If the user interface is enabled, it also provides a UI to manage the document operation interface and offers a web page for user interface interaction.
@@ -29,10 +40,14 @@ This constructor initializes a document module that can have an optional user in
 Args:
     dataset_path (str): The path to the dataset directory. This directory should contain the documents to be managed by the document module.
     embed (Optional[Union[Callable, Dict[str, Callable]]]): The object used to generate document embeddings. If you need to generate multiple embeddings for the text, you need to specify multiple embedding models in a dictionary format. The key identifies the name corresponding to the embedding, and the value is the corresponding embedding model.
+    create_ui (bool): [Deprecated] Whether to create a user interface. Use 'manager' parameter instead.
     manager (bool, optional): A flag indicating whether to create a user interface for the document module. Defaults to False.
+    server (Union[bool, int]): Server configuration. True for default server, False for no server, or an integer port number for custom server.
+    name (Optional[str]): Name identifier for this document collection. Required for cloud services.
     launcher (optional): An object or function responsible for launching the server module. If not provided, the default asynchronous launcher from `lazyllm.launchers` is used (`sync=False`).
-    store_conf (optional): Configure which storage backend and index backend to use.
     doc_fields (optional): Configure the fields that need to be stored and retrieved along with their corresponding types (currently only used by the Milvus backend).
+    doc_files (Optional[List[str]]): List of temporary document files (alternative to dataset_path).When used, dataset_path must be None and only map store is supported.
+    store_conf (optional): Configure which storage backend, MapStore is the default choice.      
 
 
 Examples:
@@ -44,16 +59,19 @@ Examples:
     >>> document1 = Document(dataset_path='your_doc_path', embed={"online": m, "local": m1}, manager=False)
     
     >>> store_conf = {
-    >>>     'type': 'chroma',
-    >>>     'indices': {
-    >>>         'smart_embedding_index': {
-    >>>             'backend': 'milvus',
-    >>>             'kwargs': {
-    >>>                 'uri': '/tmp/tmp.db',
-    >>>                 'index_kwargs': {
-    >>>                     'index_type': 'HNSW',
-    >>>                     'metric_type': 'COSINE'
-    >>>                  }
+    >>>     "segment_store": {
+    >>>         "type": "map",
+    >>>         "kwargs": {
+    >>>             "uri": "/tmp/tmp_segments.db",
+    >>>         },
+    >>>     },
+    >>>     "vector_store": {
+    >>>         "type": "milvus",
+    >>>         "kwargs": {
+    >>>             "uri": "/tmp/tmp_milvus.db",
+    >>>             "index_kwargs": {
+    >>>                 "index_type": "FLAT",
+    >>>                 "metric_type": "COSINE",
     >>>             },
     >>>         },
     >>>     },
@@ -65,30 +83,39 @@ Examples:
     >>> document2 = Document(dataset_path='your_doc_path', embed={"online": m, "local": m1}, store_conf=store_conf, doc_fields=doc_fields)
     """
     class _Manager(ModuleBase):
-        def __init__(self, dataset_path: str, embed: Optional[Union[Callable, Dict[str, Callable]]] = None,
-                     manager: Union[bool, str] = False, server: bool = False, name: Optional[str] = None,
+        def __init__(self, dataset_path: Optional[str], embed: Optional[Union[Callable, Dict[str, Callable]]] = None,
+                     manager: Union[bool, str] = False, server: Union[bool, int] = False, name: Optional[str] = None,
                      launcher: Optional[Launcher] = None, store_conf: Optional[Dict] = None,
-                     doc_fields: Optional[Dict[str, DocField]] = None):
+                     doc_fields: Optional[Dict[str, DocField]] = None, cloud: bool = False,
+                     doc_files: Optional[List[str]] = None, processor: Optional[DocumentProcessor] = None,
+                     display_name: Optional[str] = "", description: Optional[str] = "algorithm description"):
             super().__init__()
-            self._origin_path = dataset_path
-            if not os.path.exists(dataset_path):
+            self._origin_path, self._doc_files, self._cloud = dataset_path, doc_files, cloud
+
+            if dataset_path and not os.path.exists(dataset_path):
                 defatult_path = os.path.join(lazyllm.config["data_path"], dataset_path)
                 if os.path.exists(defatult_path):
                     dataset_path = defatult_path
-            else:
+            elif dataset_path:
                 dataset_path = os.path.join(os.getcwd(), dataset_path)
+
             self._launcher: Launcher = launcher if launcher else lazyllm.launchers.remote(sync=False)
             self._dataset_path = dataset_path
             self._embed = self._get_embeds(embed)
-            self.name = name
-            self._dlm = DocListManager(dataset_path, name, enable_path_monitoring=False if manager else True)
-            self._kbs = CallableDict({DocListManager.DEFAULT_GROUP_NAME:
-                                      DocImpl(embed=self._embed, dlm=self._dlm,
-                                              global_metadata_desc=doc_fields,
-                                              store_conf=store_conf)})
-            if manager: self._manager = ServerModule(DocManager(self._dlm))
+            self._processor = processor
+            name = name or DocListManager.DEFAULT_GROUP_NAME
+            if not display_name: display_name = name
+
+            self._dlm = None if (self._cloud or self._doc_files is not None) else DocListManager(
+                dataset_path, name, enable_path_monitoring=False if manager else True)
+            self._kbs = CallableDict({name: DocImpl(
+                embed=self._embed, dlm=self._dlm, doc_files=doc_files, global_metadata_desc=doc_fields,
+                store=store_conf, processor=processor, algo_name=name, display_name=display_name,
+                description=description)})
+
+            if manager: self._manager = ServerModule(DocManager(self._dlm), launcher=self._launcher)
             if manager == 'ui': self._docweb = DocWebModule(doc_server=self._manager)
-            if server: self._kbs = ServerModule(self._kbs)
+            if server: self._kbs = ServerModule(self._kbs, port=(None if isinstance(server, bool) else int(server)))
             self._global_metadata_desc = doc_fields
 
         @property
@@ -119,10 +146,10 @@ Examples:
             embed = self._get_embeds(embed) if embed else self._embed
             if isinstance(self._kbs, ServerModule):
                 self._kbs._impl._m[name] = DocImpl(dlm=self._dlm, embed=embed, kb_group_name=name,
-                                                   global_metadata_desc=doc_fields, store_conf=store_conf)
+                                                   global_metadata_desc=doc_fields, store=store_conf)
             else:
                 self._kbs[name] = DocImpl(dlm=self._dlm, embed=self._embed, kb_group_name=name,
-                                          global_metadata_desc=doc_fields, store_conf=store_conf)
+                                          global_metadata_desc=doc_fields, store=store_conf)
             self._dlm.add_kb_group(name=name)
 
         def get_doc_by_kb_group(self, name):
@@ -136,16 +163,40 @@ Examples:
         def __call__(self, *args, **kw):
             return self._kbs(*args, **kw)
 
-    def __init__(self, dataset_path: str, embed: Optional[Union[Callable, Dict[str, Callable]]] = None,
-                 create_ui: bool = False, manager: Union[bool, str] = False, server: bool = False,
-                 name: Optional[str] = None, launcher: Optional[Launcher] = None,
-                 doc_fields: Dict[str, DocField] = None, store_conf: Optional[Dict] = None):
+    def __new__(cls, *args, **kw):
+        if url := kw.pop('url', None):
+            name = kw.pop('name', None)
+            assert not args and not kw, 'Only `name` is supported with `url`'
+            return UrlDocument(url, name)
+        else:
+            return super().__new__(cls)
+
+    def __init__(self, dataset_path: Optional[str] = None, embed: Optional[Union[Callable, Dict[str, Callable]]] = None,
+                 create_ui: bool = False, manager: Union[bool, str, "Document._Manager", DocumentProcessor] = False,
+                 server: Union[bool, int] = False, name: Optional[str] = None, launcher: Optional[Launcher] = None,
+                 doc_files: Optional[List[str]] = None, doc_fields: Dict[str, DocField] = None,
+                 store_conf: Optional[Dict] = None, display_name: Optional[str] = "",
+                 description: Optional[str] = "algorithm description"):
         super().__init__()
         if create_ui:
             lazyllm.LOG.warning('`create_ui` for Document is deprecated, use `manager` instead')
+            manager = create_ui
+        if isinstance(dataset_path, (tuple, list)):
+            doc_fields = dataset_path
+            dataset_path = None
+        if doc_files is not None:
+            assert dataset_path is None and not manager, (
+                'Manager and dataset_path are not supported for Document with temp-files')
+            assert store_conf is None or store_conf['type'] == 'map', (
+                'Only map store is supported for Document with temp-files')
+
+        name = name or DocListManager.DEFAULT_GROUP_NAME
+
         if isinstance(manager, Document._Manager):
             assert not server, 'Server infomation is already set to by manager'
             assert not launcher, 'Launcher infomation is already set to by manager'
+            assert not manager._cloud, 'manager is not allowed to share in cloud mode'
+            assert manager._doc_files is None, 'manager is not allowed to share with temp files'
             if dataset_path != manager._dataset_path and dataset_path != manager._origin_path:
                 raise RuntimeError(f'Document path mismatch, expected `{manager._dataset_path}`'
                                    f'while received `{dataset_path}`')
@@ -153,9 +204,94 @@ Examples:
             self._manager = manager
             self._curr_group = name
         else:
-            self._manager = Document._Manager(dataset_path, embed, create_ui or manager, server, name,
-                                              launcher, store_conf, doc_fields)
-            self._curr_group = DocListManager.DEFAULT_GROUP_NAME
+            if isinstance(manager, DocumentProcessor):
+                processor, cloud = manager, True
+                processor._impl.start()
+                manager = False
+                assert name, '`Name` of Document is necessary when using cloud service'
+                assert store_conf.get('type') != 'map', 'Cloud manager is not supported when using map store'
+                assert not dataset_path, 'Cloud manager is not supported with local dataset path'
+            else:
+                cloud, processor = False, None
+            self._manager = Document._Manager(dataset_path, embed, manager, server, name, launcher, store_conf,
+                                              doc_fields, cloud=cloud, doc_files=doc_files, processor=processor,
+                                              display_name=display_name, description=description)
+            self._curr_group = name
+        self._doc_to_db_processor: DocToDbProcessor = None
+
+    def _list_all_files_in_dataset(self) -> List[str]:
+        files_list = []
+        for root, _, files in os.walk(self._manager._dataset_path):
+            files = [os.path.join(root, file_path) for file_path in files]
+            files_list.extend(files)
+        return files_list
+
+    def connect_sql_manager(
+        self,
+        sql_manager: SqlManager,
+        schma: Optional[DocInfoSchema] = None,
+        force_refresh: bool = True,
+    ):
+        def format_schema_to_dict(schema: DocInfoSchema):
+            if schema is None:
+                return None, None
+            desc_dict = {ele["key"]: ele["desc"] for ele in schema}
+            type_dict = {ele["key"]: ele["type"] for ele in schema}
+            return desc_dict, type_dict
+
+        def compare_schema(old_schema: DocInfoSchema, new_schema: DocInfoSchema):
+            old_desc_dict, old_type_dict = format_schema_to_dict(old_schema)
+            new_desc_dict, new_type_dict = format_schema_to_dict(new_schema)
+            return old_desc_dict == new_desc_dict and old_type_dict == new_type_dict
+
+        # 1. Check valid arguments
+        if sql_manager.check_connection().status != DBStatus.SUCCESS:
+            raise RuntimeError(f'Failed to connect to sql manager: {sql_manager._gen_conn_url()}')
+        pre_doc_table_schema = None
+        if self._doc_to_db_processor:
+            pre_doc_table_schema = self._doc_to_db_processor.doc_info_schema
+        assert pre_doc_table_schema or schma, "doc_table_schma must be given"
+
+        schema_equal = compare_schema(pre_doc_table_schema, schma)
+        assert (
+            schema_equal or force_refresh is True
+        ), "When changing doc_table_schema, force_refresh should be set to True"
+
+        # 2. Init handler if needed
+        need_init_processor = False
+        if self._doc_to_db_processor is None:
+            need_init_processor = True
+        else:
+            # avoid reinit for the same db
+            if sql_manager != self._doc_to_db_processor.sql_manager:
+                need_init_processor = True
+        if need_init_processor:
+            self._doc_to_db_processor = DocToDbProcessor(sql_manager)
+
+        # 3. Reset doc_table_schema if needed
+        if schma and not schema_equal:
+            # This api call will clear existing db table "lazyllm_doc_elements"
+            self._doc_to_db_processor._reset_doc_info_schema(schma)
+
+    def get_sql_manager(self):
+        if self._doc_to_db_processor is None:
+            raise ValueError("Please call connect_sql_manager to init handler first")
+        return self._doc_to_db_processor.sql_manager
+
+    def extract_db_schema(
+        self, llm: Union[OnlineChatModule, TrainableModule], print_schema: bool = False
+    ) -> DocInfoSchema:
+        file_paths = self._list_all_files_in_dataset()
+        schema = extract_db_schema_from_files(file_paths, llm)
+        if print_schema:
+            lazyllm.LOG.info(f"Extracted Schema:\n\t{schema}\n")
+        return schema
+
+    def update_database(self, llm: Union[OnlineChatModule, TrainableModule]):
+        assert self._doc_to_db_processor, "Please call connect_db to init handler first"
+        file_paths = self._list_all_files_in_dataset()
+        info_dicts = self._doc_to_db_processor.extract_info_from_docs(llm, file_paths)
+        self._doc_to_db_processor.export_info_to_db(info_dicts)
 
     @deprecated('Document(dataset_path, manager=doc.manager, name=xx, doc_fields=xx, store_conf=xx)')
     def create_kb_group(self, name: str, doc_fields: Optional[Dict[str, DocField]] = None,
@@ -170,14 +306,25 @@ Examples:
     def _impls(self): return self._manager
 
     @property
-    def _impl(self): return self._manager.get_doc_by_kb_group(self._curr_group)
+    def _impl(self) -> DocImpl: return self._manager.get_doc_by_kb_group(self._curr_group)
 
     @property
-    def manager(self): return self._manager
+    def manager(self): return self._manager._processor or self._manager
+
+    def activate_group(self, group_name: str, embed_keys: Optional[Union[str, List[str]]] = None):
+        if isinstance(embed_keys, str): embed_keys = [embed_keys]
+        elif embed_keys is None: embed_keys = []
+        self._impl.activate_group(group_name, embed_keys)
+
+    def activate_groups(self, groups: Union[str, List[str]]):
+        if isinstance(groups, str): groups = [groups]
+        for group in groups:
+            self.activate_group(group)
 
     @DynamicDescriptor
     def create_node_group(self, name: str = None, *, transform: Callable, parent: str = LAZY_ROOT_NAME,
-                          trans_node: bool = None, num_workers: int = 0, **kwargs) -> None:
+                          trans_node: bool = None, num_workers: int = 0, display_name: str = None,
+                          group_type: NodeGroupType = NodeGroupType.CHUNK, **kwargs) -> None:
         """
 Generate a node group produced by the specified rule.
 
@@ -200,10 +347,12 @@ Examples:
     """
         if isinstance(self, type):
             DocImpl.create_global_node_group(name, transform=transform, parent=parent, trans_node=trans_node,
-                                             num_workers=num_workers, **kwargs)
+                                             num_workers=num_workers, display_name=display_name,
+                                             group_type=group_type, **kwargs)
         else:
             self._impl.create_node_group(name, transform=transform, parent=parent, trans_node=trans_node,
-                                         num_workers=num_workers, **kwargs)
+                                         num_workers=num_workers, display_name=display_name, group_type=group_type,
+                                         **kwargs)
 
     @DynamicDescriptor
     def add_reader(self, pattern: str, func: Optional[Callable] = None):
@@ -220,7 +369,7 @@ Examples:
     >>> from lazyllm.tools.rag import Document, DocNode
     >>> from lazyllm.tools.rag.readers import ReaderBase
     >>> class YmlReader(ReaderBase):
-    ...     def _load_data(self, file, extra_info=None, fs=None):
+    ...     def _load_data(self, file, fs=None):
     ...         try:
     ...             import yaml
     ...         except ImportError:
@@ -228,13 +377,13 @@ Examples:
     ...         with open(file, 'r') as f:
     ...             data = yaml.safe_load(f)
     ...         print("Call the class YmlReader.")
-    ...         return [DocNode(text=data, metadata=extra_info or {})]
+    ...         return [DocNode(text=data)]
     ...
-    >>> def processYml(file, extra_info=None):
+    >>> def processYml(file):
     ...     with open(file, 'r') as f:
     ...         data = f.read()
     ...     print("Call the function processYml.")
-    ...     return [DocNode(text=data, metadata=extra_info or {})]
+    ...     return [DocNode(text=data)]
     ...
     >>> doc1 = Document(dataset_path="your_files_path", create_ui=False)
     >>> doc2 = Document(dataset_path="your_files_path", create_ui=False)
@@ -269,10 +418,10 @@ Examples:
     
     >>> from lazyllm.tools.rag import Document, DocNode
     >>> @Document.register_global_reader("**/*.yml")
-    >>> def processYml(file, extra_info=None):
+    >>> def processYml(file):
     ...     with open(file, 'r') as f:
     ...         data = f.read()
-    ...     return [DocNode(text=data, metadata=extra_info or {})]
+    ...     return [DocNode(text=data)]
     ...
     >>> doc1 = Document(dataset_path="your_files_path", create_ui=False)
     >>> doc2 = Document(dataset_path="your_files_path", create_ui=False)
@@ -301,7 +450,7 @@ Examples:
 Find the parent node of the specified node.
 
 Args:
-    group (str): The name of the node for which to find the parent.
+    group (str): The name of the node group for which to find the parent.
 
 
 Examples:
@@ -314,18 +463,14 @@ Examples:
     >>> documents.create_node_group(name="children", transform=SentenceSplitter, parent="parent", chunk_size=1024, chunk_overlap=100)
     >>> documents.find_parent('children')
     """
-        # TODO: Currently, when a DocNode is returned from the server, it will carry all parent nodes and child nodes.
-        # So the query of parent and child nodes can be performed locally, and there is no need to search the
-        # document service through the server for the time being. When this item is optimized, the code will become:
-        # return functools.partial(self._forward, 'find_parent', group=target)
-        return functools.partial(Document.find_parent, group=target)
+        return functools.partial(self._forward, 'find_parent', group=target)
 
     def find_children(self, target) -> Callable:
         """
 Find the child nodes of the specified node.
 
 Args:
-    group (str): The name of the node for which to find the children.
+    group (str): The name of the node group for which to find the children.
 
 
 Examples:
@@ -338,15 +483,61 @@ Examples:
     >>> documents.create_node_group(name="children", transform=SentenceSplitter, parent="parent", chunk_size=1024, chunk_overlap=100)
     >>> documents.find_children('parent')
     """
-        # TODO: Currently, when a DocNode is returned from the server, it will carry all parent nodes and child nodes.
-        # So the query of parent and child nodes can be performed locally, and there is no need to search the
-        # document service through the server for the time being. When this item is optimized, the code will become:
-        # return functools.partial(self._forward, 'find_children', group=target)
-        return functools.partial(Document.find_children, group=target)
+        return functools.partial(self._forward, 'find_children', group=target)
+
+    def find(self, target) -> Callable:
+        return functools.partial(self._forward, 'find', group=target)
 
     def forward(self, *args, **kw) -> List[DocNode]:
         return self._forward('retrieve', *args, **kw)
 
+    def clear_cache(self, group_names: Optional[List[str]] = None) -> None:
+        return self._forward('clear_cache', group_names)
+
+    def _get_post_process_tasks(self):
+        return lazyllm.pipeline(lambda *a: self._forward('_lazy_init'))
+
     def __repr__(self):
         return lazyllm.make_repr("Module", "Document", manager=hasattr(self._manager, '_manager'),
                                  server=isinstance(self._manager._kbs, ServerModule))
+
+class UrlDocument(ModuleBase):
+    """UrlDocument class inherits from ModuleBase, used to manage remote document resources by specifying a URL and a name.  
+Internally delegates calls to lazyllm's UrlModule, supporting document find, retrieve, and querying active node groups.
+
+Args:
+    url (str): Access URL for the remote document resource.
+    name (str): Current document group name used to identify the document group.
+"""
+    def __init__(self, url: str, name: str = None):
+        super().__init__()
+        self._missing_keys = set(dir(Document)) - set(dir(UrlDocument))
+        self._manager = lazyllm.UrlModule(url=ensure_call_endpoint(url))
+        self._curr_group = name or DocListManager.DEFAULT_GROUP_NAME
+
+    def _forward(self, func_name: str, *args, **kwargs):
+        args = (self._curr_group, func_name, *args)
+        return self._manager._call("__call__", *args, **kwargs)
+
+    def find(self, target) -> Callable:
+        """Creates a partially applied function to find a specified target within the current document group.
+
+Args:
+    target (str): The target identifier to find.
+
+**Returns:**
+
+- Callable: A partially applied function that executes the find operation when called.
+"""
+        return functools.partial(self._forward, 'find', group=target)
+
+    def forward(self, *args, **kw):
+        return self._forward('retrieve', *args, **kw)
+
+    @cached_property
+    def active_node_groups(self):
+        return self._forward('active_node_groups')
+
+    def __getattr__(self, name):
+        if name in self._missing_keys:
+            raise RuntimeError(f'Document generated with url and name has no attribute `{name}`')
