@@ -7,13 +7,19 @@ from .readerBase import LazyLLMReaderBase
 from ..doc_node import DocNode
 
 class IPYNBReader(LazyLLMReaderBase):
+    """Module for reading and parsing Jupyter Notebook (.ipynb) files. Converts the notebook to script text, then splits it by code cells into multiple document nodes or concatenates into a single text node.
+
+Args:
+    parser_config (Optional[Dict]): Reserved parser configuration parameter, currently unused. Defaults to None.
+    concatenate (bool): Whether to concatenate all code cells into one text node. Defaults to False (split into multiple nodes).
+    return_trace (bool): Whether to record processing trace. Default is True.
+"""
     def __init__(self, parser_config: Optional[Dict] = None, concatenate: bool = False, return_trace: bool = True):
         super().__init__(return_trace=return_trace)
         self._parser_config = parser_config
         self._concatenate = concatenate
 
-    def _load_data(self, file: Path, extra_info: Optional[Dict] = None,
-                   fs: Optional[AbstractFileSystem] = None) -> List[DocNode]:
+    def _load_data(self, file: Path, fs: Optional[AbstractFileSystem] = None) -> List[DocNode]:
         if not isinstance(file, Path): file = Path(file)
 
         if file.name.endswith(".ipynb"):
@@ -31,7 +37,7 @@ class IPYNBReader(LazyLLMReaderBase):
         splits = re.split(r"In\[\d+\]:", doc_str)
         splits.pop(0)
 
-        if self._concatenate: docs = [DocNode(text="\n\n".join(splits), metadata=extra_info or {})]
-        else: docs = [DocNode(text=s, global_metadata=extra_info) for s in splits]
+        if self._concatenate: docs = [DocNode(text="\n\n".join(splits))]
+        else: docs = [DocNode(text=s) for s in splits]
 
         return docs
