@@ -2,12 +2,19 @@ import re
 from pathlib import Path
 from fsspec import AbstractFileSystem
 from fsspec.implementations.local import LocalFileSystem
-from typing import Dict, List, Optional, Tuple
+from typing import List, Optional, Tuple
 
 from .readerBase import LazyLLMReaderBase
 from ..doc_node import DocNode
 
 class MarkdownReader(LazyLLMReaderBase):
+    """Module for reading and parsing Markdown files. Supports removing hyperlinks and images, and splits Markdown into text segments by headers, returning document nodes.
+
+Args:
+    remove_hyperlinks (bool): Whether to remove hyperlinks, default is True.
+    remove_images (bool): Whether to remove image tags, default is True.
+    return_trace (bool): Whether to record processing trace, default is True.
+"""
     def __init__(self, remove_hyperlinks: bool = True, remove_images: bool = True, return_trace: bool = True) -> None:
         super().__init__(return_trace=return_trace)
         self._remove_hyperlinks = remove_hyperlinks
@@ -38,10 +45,26 @@ class MarkdownReader(LazyLLMReaderBase):
                 for key, value in markdown_tups]
 
     def remove_images(self, content: str) -> str:
+        """Remove custom image tags of the form ![[...]] from the content.
+
+Args:
+    content (str): Input markdown content.
+
+Returns:
+    str: Content with image tags removed.
+"""
         pattern = r"!{1}\[\[(.*)\]\]"
         return re.sub(pattern, "", content)
 
     def remove_hyperlinks(self, content: str) -> str:
+        """Remove markdown hyperlinks, converting [text](url) to just text.
+
+Args:
+    content (str): Input markdown content.
+
+Returns:
+    str: Content with hyperlinks removed, only link text retained.
+"""
         pattern = r"\[(.*)\]\((.*)\)"
         return re.sub(pattern, r"\1", content)
 
@@ -56,12 +79,10 @@ class MarkdownReader(LazyLLMReaderBase):
         if self._remove_images: content = self.remove_images(content)
         return self._markdown_to_tups(content)
 
-    def _load_data(self, file: Path, extra_info: Optional[Dict] = None,
-                   fs: Optional[AbstractFileSystem] = None) -> List[DocNode]:
+    def _load_data(self, file: Path, fs: Optional[AbstractFileSystem] = None) -> List[DocNode]:
         if not isinstance(file, Path): file = Path(file)
 
         tups = self._parse_tups(file, fs=fs)
         results = [DocNode(
-            content=[value if header is None else f"\n\n{header}\n{value}" for header, value in tups],
-            global_metadata=extra_info)]
+            content=[value if header is None else f"\n\n{header}\n{value}" for header, value in tups])]
         return results
