@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Dict, List, Optional
+from typing import List, Optional
 from fsspec import AbstractFileSystem
 
 from .readerBase import LazyLLMReaderBase
@@ -7,6 +7,13 @@ from ..doc_node import DocNode
 from lazyllm import LOG
 
 class MboxReader(LazyLLMReaderBase):
+    """Module to parse Mbox email archive files. Reads email messages and formats them into text. Supports limiting the maximum number of messages and custom message formatting.
+
+Args:
+    max_count (int): Maximum number of emails to read. Default 0 means read all.
+    message_format (str): Template string for formatting each message, supports placeholders ``{_date}``, ``{_from}``, ``{_to}``, ``{_subject}``, and ``{_content}``.
+    return_trace (bool): Whether to record processing trace. Default is True.
+"""
     DEFAULT_MESSAGE_FORMAT: str = (
         "Date: {_date}\n"
         "From: {_from}\n"
@@ -26,8 +33,7 @@ class MboxReader(LazyLLMReaderBase):
         self._max_count = max_count
         self._message_format = message_format
 
-    def _load_data(self, file: Path, extra_info: Optional[Dict] = None,
-                   fs: Optional[AbstractFileSystem] = None) -> List[DocNode]:
+    def _load_data(self, file: Path, fs: Optional[AbstractFileSystem] = None) -> List[DocNode]:
         import mailbox
         from email.parser import BytesParser
         from email.policy import default
@@ -65,4 +71,4 @@ class MboxReader(LazyLLMReaderBase):
 
             i += 1
             if self._max_count > 0 and i >= self._max_count: break
-        return [DocNode(text=result, global_metadata=extra_info) for result in results]
+        return [DocNode(text=result) for result in results]
