@@ -1,11 +1,17 @@
 from pathlib import Path
-from typing import Dict, List, Optional, cast
+from typing import List, Optional, cast
 from fsspec import AbstractFileSystem
 
 from .readerBase import LazyLLMReaderBase
 from ..doc_node import DocNode
 
 class VideoAudioReader(LazyLLMReaderBase):
+    """Reader for extracting speech content from video or audio files using OpenAI's Whisper model for transcription.
+
+Args:
+    model_version (str): Whisper model version (e.g., "base", "small", "medium", "large"). Default is "base".
+    return_trace (bool): Whether to return the processing trace. Default is True.
+"""
     def __init__(self, model_version: str = "base", return_trace: bool = True) -> None:
         super().__init__(return_trace=return_trace)
         self._model_version = model_version
@@ -14,13 +20,12 @@ class VideoAudioReader(LazyLLMReaderBase):
             import whisper
         except ImportError:
             raise ImportError("Please install OpenAI whisper model "
-                              "`pip install git+https://github.com/openai/whisper.git` to use the model")
+                              "`pip install openai-whisper` to use the model")
 
         model = whisper.load_model(self._model_version)
         self._parser_config = {"model": model}
 
-    def _load_data(self, file: Path, extra_info: Optional[Dict] = None,
-                   fs: Optional[AbstractFileSystem] = None) -> List[DocNode]:
+    def _load_data(self, file: Path, fs: Optional[AbstractFileSystem] = None) -> List[DocNode]:
         import whisper
 
         if not isinstance(file, Path): file = Path(file)
@@ -45,4 +50,4 @@ class VideoAudioReader(LazyLLMReaderBase):
         result = model.transcribe(str(file))
 
         transcript = result['text']
-        return [DocNode(text=transcript, global_metadata=extra_info)]
+        return [DocNode(text=transcript)]
