@@ -2,6 +2,7 @@ from typing import Optional, Callable, Literal, List
 from .component.bm25 import BM25
 from lazyllm.thirdparty import numpy as np
 from .doc_node import DocNode
+import functools
 
 registered_similarities = dict()
 
@@ -11,7 +12,17 @@ def register_similarity(
     descend: bool = True,
     batch: bool = False,
 ) -> Callable:
+    """
+Similarity computation registration decorator, used for unified registration and management of different types of similarity computation methods.
+Args:
+    func (Callable): The name of the similarity computation function.
+    mode (Literal['text', 'embedding']): 'text' indicates direct text matching, while 'embedding' indicates vector-based similarity computation.
+    descend (bool): Controls whether multithreading is enabled (enabled when > 0).
+    kwargs (Dict): Whether the results are sorted in descending order of similarity.
+    batch (bool): Whether to process nodes in batch.
+"""
     def decorator(f):
+        @functools.wraps(f)
         def wrapper(query, nodes, **kwargs):
             if mode != "embedding":
                 if batch:
