@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from copy import copy as lite_copy
 from dataclasses import dataclass, field
 import requests
 import os
@@ -12,17 +13,36 @@ from lazyllm.thirdparty import nltk
 import tiktoken
 
 from .doc_node import DocNode, MetadataMode, QADocNode
-from lazyllm import LOG, TrainableModule, ThreadPoolExecutor
+from lazyllm import LOG, TrainableModule, ThreadPoolExecutor, config
+from lazyllm.components.formatter import encode_query_with_filepaths
 
 
 @dataclass
 class TransformArgs():
-    """TransformArgs(f: Union[str, Callable], trans_node: Optional[bool] = None, num_workers: int = 0, kwargs: Dict = <factory>, pattern: Optional[str] = None)"""
+    """
+A document transformation parameter container for centralized management of processing configurations.
+Args:
+    f (Union[str, Callable]): Transformation function or registered function name.Can be either a callable function or a string identifier for registered functions.
+    trans_node (bool): Whether to transform node types.When True, modifies the document node structure during processing.
+    num_workers (int):Controls parallel processing threads.Values >0.
+    kwargs (Dict):Additional parameters passed to the transformation function.
+    pattern (Union[str, Callable[[str], bool]]):File name/content matching pattern.
+
+
+Examples:
+    
+    >>> from lazyllm.tools import TransformArgs
+    >>> args = TransformArgs(f=lambda text: text.lower(),num_workers=4,pattern=r'.*\.md$')
+    >>>config = {'f': 'parse_pdf','kwargs': {'engine': 'pdfminer'},'trans_node': True}
+    >>>args = TransformArgs.from_dict(config)
+    print(args['f'])
+    print(args.get('unknown'))
+    """
     f: Union[str, Callable]
     trans_node: Optional[bool] = None
     num_workers: int = 0
     kwargs: Dict = field(default_factory=dict)
-    pattern: Optional[str] = None
+    pattern: Optional[Union[str, Callable[[str], bool]]] = None
 
     @staticmethod
     def from_dict(d):
@@ -72,12 +92,34 @@ def split_text_keep_separator(text: str, separator: str) -> List[str]:
 
 
 class NodeTransform(ABC):
+    """
+Processes document nodes in batch, supporting both single-threaded and multi-threaded modes.
+Args:
+    num_workers(int): Controls whether multi-threading is enabled (enabled when >0).
+
+
+Examples:
+    
+    >>> import lazyllm
+    >>> from lazyllm.tools import NodeTransform
+    >>> node_tran = NodeTransform(num_workers=num_workers)
+    >>> doc = lazyllm.Document(dataset_path="/path/to/your/data", embed=m, manager=False)
+    >>> nodes = node_tran.batch_forward(doc, "word_split")
+    """
     def __init__(self, num_workers: int = 0):
         self._number_workers = num_workers
+        self._name = None
 
     def batch_forward(
         self, documents: Union[DocNode, List[DocNode]], node_group: str, **kwargs
     ) -> List[DocNode]:
+        """
+Process documents in batch with node group transformation.
+Args:
+    documents (Union[DocNode, List[DocNode]]): Input node(s) to process.
+    node_group (str): Target transformation group name.
+    **kwargs: Additional transformation parameters.
+"""
         documents: List[DocNode] = documents if isinstance(documents, (tuple, list)) else [documents]
 
         def impl(node: DocNode):
@@ -99,8 +141,26 @@ class NodeTransform(ABC):
 
     @abstractmethod
     def transform(self, document: DocNode, **kwargs) -> List[Union[str, DocNode]]:
+        """
+[Abstract] Core transformation logic to implement.
+Args:
+    document (DocNode): Input document node.
+    **kwargs: Implementation-specific parameters.
+"""
         raise NotImplementedError('Not implemented')
 
+    def with_name(self, name: Optional[str], *, copy: bool = True) -> 'NodeTransform':
+        """
+Set transformer name with optional copying.
+Args:
+    name (Optional[str]): New name for the transformer.
+    copy (bool): Whether to return a copy. Default True.
+"""
+        if name is not None:
+            if copy: return lite_copy(self).with_name(name, copy=False)
+            self._name = name
+        return self
+
     def __call__(self, node: DocNode, **kwargs: Any) -> List[DocNode]:
         # Parent and child should not be set here.
         results = self.transform(node, **kwargs)
@@ -108,29 +168,77 @@ class NodeTransform(ABC):
         return [DocNode(text=chunk) if isinstance(chunk, str) else chunk for chunk in results if chunk]
 
 
-def make_transform(t):
+def make_transform(t: Union[TransformArgs, Dict[str, Any]], group_name: Optional[str] = None) -> NodeTransform:
     if isinstance(t, dict): t = TransformArgs.from_dict(t)
     transform, trans_node, num_workers = t['f'], t['trans_node'], t['num_workers']
     num_workers = dict(num_workers=num_workers) if num_workers > 0 else dict()
-    return (transform(**t['kwargs'], **num_workers)
-            if isinstance(transform, type)
-            else transform if isinstance(transform, NodeTransform)
-            else FuncNodeTransform(transform, trans_node=trans_node, **num_workers))
+    return (transform(**t['kwargs'], **num_workers).with_name(group_name, copy=False) if isinstance(transform, type)
+            else transform.with_name(group_name) if isinstance(transform, NodeTransform)
+            else FuncNodeTransform(transform, trans_node=trans_node, **num_workers).with_name(group_name, copy=False))
 
 
 class AdaptiveTransform(NodeTransform):
-    def __init__(self, transforms: Union[List[TransformArgs], TransformArgs]):
-        super().__init__(num_workers=0)
+    """A flexible document transformation system that applies different transforms based on document patterns.
+
+AdaptiveTransform allows you to define multiple transformation strategies and automatically selects the appropriate one based on the document's file path or custom pattern matching. This is particularly useful when you have different types of documents that require different processing approaches.
+
+Args:
+    transforms (Union[List[Union[TransformArgs, Dict]], Union[TransformArgs, Dict]]): A list of transform configurations or a single transform configuration. 
+    num_workers (int, optional): Number of worker threads for parallel processing. Defaults to 0.
+
+
+Examples:
+    >>> from lazyllm.tools.rag.transform import AdaptiveTransform, DocNode, SentenceSplitter
+    >>> doc1 = DocNode(text="这是第一个文档的内容。它包含多个句子。")
+    >>> doc2 = DocNode(text="这是第二个文档的内容。")
+    >>> transforms = [
+    ...     {
+    ...         'f': SentenceSplitter,
+    ...         'pattern': '*.txt',
+    ...         'kwargs': {'chunk_size': 50, 'chunk_overlap': 10}
+    ...     },
+    ...     {
+    ...         'f': SentenceSplitter,
+    ...         'pattern': '*.pdf',
+    ...         'kwargs': {'chunk_size': 100, 'chunk_overlap': 20}
+    ...     }
+    ... ]
+    >>> adaptive = AdaptiveTransform(transforms)
+    >>> results1 = adaptive.transform(doc1)
+    >>> print(f"文档1转换结果: {len(results1)} 个块")
+    >>> for i, result in enumerate(results1):
+    ...     print(f"  块 {i+1}: {result.text}")
+    >>> results2 = adaptive.transform(doc2)
+    >>> print(f"文档2转换结果: {len(results2)} 个块")
+    >>> for i, result in enumerate(results2):
+    ...     print(f"  块 {i+1}: {result.text}")      
+    """
+    def __init__(self, transforms: Union[List[Union[TransformArgs, Dict]], Union[TransformArgs, Dict]],
+                 num_workers: int = 0):
+        super().__init__(num_workers=num_workers)
         if not isinstance(transforms, (tuple, list)): transforms = [transforms]
         self._transformers = [(t.get('pattern'), make_transform(t)) for t in transforms]
 
     def transform(self, document: DocNode, **kwargs) -> List[Union[str, DocNode]]:
+        """Transform a document using the appropriate transformation strategy based on pattern matching.
+
+This method evaluates each transform configuration in order and applies the first one that matches the document's path pattern. The matching logic supports both glob patterns and custom callable functions.
+
+Args:
+    document (DocNode): The document node to be transformed.
+    **kwargs: Additional keyword arguments passed to the transform function.
+
+**Returns:**
+
+- List[Union[str, DocNode]]: A list of transformed results (strings or DocNode objects).
+"""
+        if not isinstance(document, DocNode): LOG.warning(f'Invalud document type {type(document)} got')
         for pt, transform in self._transformers:
-            if pt and not pt.startswith('*'): pt = os.path.join(str(os.cwd()), pt)
-            if not isinstance(document, DocNode):
-                LOG.warning(f'Invalud document type {type(document)} got')
-            if not pt or fnmatch.fnmatch(document.docpath, pt):
+            if pt and isinstance(pt, str) and not pt.startswith('*'): pt = os.path.join(str(os.cwd()), pt)
+            if not pt or (callable(pt) and pt(document.docpath)) or (
+                    isinstance(pt, str) and fnmatch.fnmatch(document.docpath, pt)):
                 return transform(document, **kwargs)
+        LOG.warning(f'No transform found for document {document.docpath} with group name `{self._name}`')
         return []
 
 
@@ -141,6 +249,7 @@ Split sentences into chunks of a specified size. You can specify the size of the
 Args:
     chunk_size (int): The size of the chunk after splitting.
     chunk_overlap (int): The length of the overlapping content between two adjacent chunks.
+    num_workers (int): Controls the number of threads or processes used for parallel processing.
 
 
 Examples:
@@ -164,7 +273,12 @@ Examples:
         ), 'chunk size should > 0 and chunk_overlap should >= 0'
 
         try:
+            if 'TIKTOKEN_CACHE_DIR' not in os.environ and 'DATA_GYM_CACHE_DIR' not in os.environ:
+                path = os.path.join(config['model_path'], 'tiktoken')
+                os.makedirs(path, exist_ok=True)
+                os.environ['TIKTOKEN_CACHE_DIR'] = path
             self._tiktoken_tokenizer = tiktoken.encoding_for_model('gpt-3.5-turbo')
+            os.environ.pop('TIKTOKEN_CACHE_DIR')
         except requests.exceptions.ConnectionError:
             LOG.error(
                 'Unable to download the vocabulary file for tiktoken `gpt-3.5-turbo`. '
@@ -220,8 +334,7 @@ Examples:
                 f'Metadata length ({metadata_size}) is close to chunk size '
                 f'({self.chunk_size}). Resulting chunks are less than 50 tokens. '
                 'Consider increasing the chunk size or decreasing the size of '
-                'your metadata to avoid this.',
-                flush=True,
+                'your metadata to avoid this.'
             )
 
         splits = self._split(text, effective_chunk_size)
@@ -267,7 +380,7 @@ Examples:
         is_chunk_new = True
 
         def close_chunk() -> None:
-            nonlocal chunks, cur_chunk, cur_chunk_len, is_chunk_new
+            nonlocal cur_chunk, cur_chunk_len, is_chunk_new
 
             chunks.append(''.join([text for text, _ in cur_chunk]))
             last_chunk = cur_chunk
@@ -351,6 +464,18 @@ class FuncNodeTransform(NodeTransform):
         self._func, self._trans_node = func, trans_node
 
     def transform(self, node: DocNode, **kwargs) -> List[Union[str, DocNode]]:
+        """
+Transform a document node using the wrapped user-defined function.
+
+This method applies the user-defined function to either the text content of the node (when trans_node=False) or the node itself (when trans_node=True).
+
+Args:
+    node (DocNode): The document node to be transformed.
+    **kwargs: Additional keyword arguments passed to the transformation function.
+
+Returns:
+    List[Union[str, DocNode]]: The transformed results, which can be either strings or DocNode objects depending on the function implementation.
+"""
         return self._func(node if self._trans_node else node.get_text())
 
 
@@ -418,6 +543,23 @@ Q: What can LazyLLM do?
 A: LazyLLM can assist you in building the most powerful large-scale model applications with minimal cost.
 
 You should not have any unnecessary output. Lets begin:
+""", qa_img="""
+## Role: Q&A Pair Extraction Engine
+You are a Q&A pair extraction engine, responsible for analyzing and extracting Q&A pairs from images.
+
+## Constraints:
+- Only reply with the requested output content: extracted Q&A pairs.
+- Do not add extra fields, explanations, or translations.
+
+## Example:
+Input an image of a pig.
+#output:
+Q: What color is the pig?
+A: The pig is pink.
+Q: What is the pig doing?
+A: The pig is running on the lawn.
+
+You should not output any extra characters. Let's start now.
 """),
     zh=dict(summary="""
 ## 角色：文本摘要
@@ -475,6 +617,23 @@ A: LazyLLM是由商汤科技开发的。
 Q: LazyLLM能做什么？
 A: LazyLLM可以协助用户，用最低的成本，构建最强大的大模型应用
 
+你不应输出任何多余的字符，现在我们开始吧
+""", qa_img="""
+## 角色：问答对提取引擎
+你是一个问答对提取引擎，负责分析从图像中提取其中的问答对。
+
+## 约束条件:
+- 仅回复请求的输出内容：抽取问答对。
+- 不要添加额外字段、解释或翻译。
+
+## 示例:
+输入一张小猪的图片。
+#output:
+Q: 小猪是什么颜色的？
+A: 小猪是粉红色的。
+Q: 小猪在做啥呢？
+A: 小猪在草坪上奔跑。
+
 你不应输出任何多余的字符，现在我们开始吧
 """))
 
@@ -486,6 +645,7 @@ Args:
     llm (TrainableModule): A trainable module.
     language (str): The language type, currently only supports Chinese (zh) and English (en).
     task_type (str): Currently supports two types of tasks: summary and keyword extraction.
+    num_workers (int): Controls the number of threads or processes used for parallel processing.
 
 
 Examples:
@@ -495,13 +655,16 @@ Examples:
     >>> llm = TrainableModule("internlm2-chat-7b")
     >>> summary_parser = LLMParser(llm, language="en", task_type="summary")
     """
-    def __init__(self, llm: TrainableModule, language: str, task_type: str, num_workers: int = 0):
+    def __init__(self, llm: TrainableModule, language: str, task_type: str, num_workers: int = 30):
         super(__class__, self).__init__(num_workers=num_workers)
         assert language in ['en', 'zh'], f'Not supported language {language}'
-        assert task_type in ['summary', 'keywords', 'qa'], f'Not supported task_type {task_type}'
+        assert task_type in ['summary', 'keywords', 'qa', 'qa_img'], f'Not supported task_type {task_type}'
         self._task_type = task_type
-        self._llm = llm.share(prompt=AlpacaPrompter(dict(
-            system=templates[language][task_type], user='#input:\n{input}\n#output:\n'))).formatter(self._format)
+        if self._task_type == 'qa_img':
+            prompt = dict(system=templates[language][task_type], user='{input}')
+        else:
+            prompt = dict(system=templates[language][task_type], user='#input:\n{input}\n#output:\n')
+        self._llm = llm.share(prompt=AlpacaPrompter(prompt), stream=False, format=self._format)
         self._task_type = task_type
 
     def transform(self, node: DocNode, **kwargs) -> List[str]:
@@ -526,13 +689,17 @@ Examples:
     >>> summary_result = summary_parser.transform(doc_nodes[0])
     >>> keywords_result = keywords_parser.transform(doc_nodes[0])
     """
-        result = self._llm(node.get_text())
+        if self._task_type == 'qa_img':
+            inputs = encode_query_with_filepaths('Extract QA pairs from images.', [node.image_path])
+        else:
+            inputs = node.get_text()
+        result = self._llm(inputs)
         return [result] if isinstance(result, str) else result
 
     def _format(self, input):
         if self._task_type == 'keywords':
             return [s.strip() for s in input.split(',')]
-        elif self._task_type == 'qa':
+        elif self._task_type in ('qa', 'qa_img'):
             return [QADocNode(query=q.strip()[3:].strip(), answer=a.strip()[3:].strip()) for q, a in zip(
                 list(filter(None, map(str.strip, input.split("\n"))))[::2],
                 list(filter(None, map(str.strip, input.split("\n"))))[1::2])]
