@@ -17,7 +17,8 @@ Args:
     proxies (Dict[str, str], optional): Specifies the proxies to be used when requesting the URL. Proxy format refer to `https://www.python-httpx.org/advanced/proxies`.
     code_str (str, optional): A string containing a user-defined function. If the parameter url is empty, execute this function directly, forwarding all arguments to it; if url is not empty, the parameters of this function are the results returned from the URL request, and in this case, the function serves as a post-processing function for the URL response.
     vars_for_code (Dict[str, Any]): A dictionary that includes dependencies and variables required for running the code.
-
+    outputs (Optional[List[str]]): Names of expected output fields.
+    extract_from_result (Optional[bool]): Whether to extract fields directly from response dict using `outputs`.
 
 
 Examples:
