@@ -10,11 +10,11 @@ from lazyllm.thirdparty import gradio as gr, PIL
 import time
 import re
 from pathlib import Path
-from typing import List, Union
+from typing import List, Union, Optional, Any, Dict
 
 import lazyllm
 from lazyllm import LOG, globals, FileSystemQueue, OnlineChatModule, TrainableModule
-from lazyllm.components.formatter import decode_query_with_filepaths
+from lazyllm.components.formatter import decode_query_with_filepaths, encode_query_with_filepaths
 from ...module.module import ModuleBase
 
 
@@ -69,9 +69,12 @@ Examples:
         Refresh = 1
         Appendix = 2
 
-    def __init__(self, m, *, components=dict(), title='对话演示终端', port=None,
-                 history=[], text_mode=None, trace_mode=None, audio=False, stream=False,
-                 files_target=None, static_paths: Union[str, Path, List[str | Path]] = None) -> None:
+    def __init__(self, m: Any, *, components: Dict[Any, Any] = dict(), title: str = '对话演示终端',  # noqa B008
+                 port: Optional[Union[int, range, tuple, list]] = None, history: List[Any] = [],  # noqa B006
+                 text_mode: Optional[Mode] = None, trace_mode: Optional[Mode] = None, audio: bool = False,
+                 stream: bool = False, files_target: Optional[Union[Any, List[Any]]] = None,
+                 static_paths: Optional[Union[str, Path, List[Union[str, Path]]]] = None,
+                 encode_files: bool = False, share: bool = False) -> None:
         super().__init__()
         # Set the static directory of gradio so that gradio can access local resources in the directory
         if isinstance(static_paths, (str, Path)):
@@ -99,6 +102,8 @@ Examples:
         self.audio = audio
         self.stream = stream
         self.files_target = files_target if isinstance(files_target, list) or files_target is None else [files_target]
+        self.encode_files = encode_files
+        self.share = share
         self.demo = self.init_web(components)
         self.url = None
         signal.signal(signal.SIGINT, self._signal_handler)
@@ -128,6 +133,14 @@ Examples:
         return cach_path
 
     def init_web(self, component_descs):
+        """Initialize the Web UI page.
+This method uses Gradio to build the interactive chat interface and binds all components to the appropriate logic. It supports session selection, streaming output, context toggling, multimodal input, and control tools. The method returns the constructed Gradio Blocks object.
+Args:
+    component_descs (List[Tuple]): A list of component descriptors. Each element is a 5-tuple 
+        (module, group_name, name, component_type, value), e.g. ('MyModule', 'GroupA', 'use_cache', 'Checkbox', True).
+Returns:
+    gr.Blocks: The constructed Gradio UI object, which can be launched via `.launch()`.
+"""
         gr.set_static_paths(self._static_paths)
         with gr.Blocks(css=css, title=self.title, analytics_enabled=False) as demo:
             sess_data = gr.State(value={
@@ -298,8 +311,10 @@ Examples:
                 string = chat_history[-1][0]
             else:
                 string = ''
-            if self.files_target is None:
+            if self.files_target is None and not self.encode_files:
                 self._get_all_file_submodule()
+            if self.encode_files and files:
+                string = encode_query_with_filepaths(string, files)
             if files and self.files_target:
                 for module in self.files_target:
                     assert isinstance(module, ModuleBase)
@@ -308,6 +323,10 @@ Examples:
                     else:
                         globals['lazyllm_files'][module._module_id] = files
                 string += f' ## Get attachments: {os.path.basename(files[-1])}'
+            elif self.files_target:
+                for module in self.files_target:
+                    assert isinstance(module, ModuleBase)
+                    globals['lazyllm_files'][module._module_id] = []
             input = string
             history = chat_history[:-1] if use_context and len(chat_history) > 1 else list()
 
@@ -382,6 +401,8 @@ Examples:
                         file = gr.Image(file_path)
                     elif suffix in ('.mp3', '.wav'):
                         file = gr.Audio(file_path)
+                    elif suffix in ('.mp4'):
+                        file = gr.Video(file_path)
                     else:
                         LOG.error(f'Not supported typr: {suffix}, for file: {file}')
                     if i == 0:
@@ -392,17 +413,19 @@ Examples:
                     chat_history.append([None, result])
             else:
                 assert isinstance(result, str), f'Result should only be str, but got {type(result)}'
-                if not contains_markdown_image(result):
-                    count = (len(match.group(1)) if (match := re.search(r'(\n+)$', result)) else 0) + len(result) + 1
-                    if result and not (result in chat_history[-1][1][-count:]):
-                        chat_history[-1][1] += "\n\n" + result
-                else:
-                    urls = extract_img_path(result)
+                show_result = result
+                if contains_markdown_image(show_result):
+                    urls = extract_img_path(show_result)
                     for url in urls:
                         suffix = os.path.splitext(url)[-1].lower()
                         if suffix in PIL.Image.registered_extensions().keys() and os.path.exists(url):
-                            result = result.replace(url, "file=" + url)
-                    chat_history[-1][1] += result
+                            show_result = show_result.replace(url, "file=" + url)
+                if result:
+                    count = (len(match.group(1)) if (match := re.search(r'(\n+)$', result)) else 0) + len(result) + 1
+                    if not (result in chat_history[-1][1][-count:]):
+                        chat_history[-1][1] += "\n\n" + show_result
+                    elif show_result != result:
+                        chat_history[-1][1] = chat_history[-1][1].replace(result, show_result)
         except requests.RequestException as e:
             chat_history = None
             log = str(e)
@@ -428,9 +451,9 @@ Examples:
         self.url = f'http://127.0.0.1:{port}'
         self.broadcast_url = f'http://0.0.0.0:{port}'
 
-        self.demo.queue().launch(server_name="0.0.0.0", server_port=port, prevent_thread_lock=True)
+        self.demo.queue().launch(server_name="0.0.0.0", server_port=port, prevent_thread_lock=True, share=self.share)
         LOG.success('LazyLLM webmodule launched successfully: Running on: '
-                    f'{self.broadcast_url}, local URL: {self.url}', flush=True)
+                    f'{self.broadcast_url}, local URL: {self.url}')
 
     def _update(self, *, mode=None, recursive=True):
         super(__class__, self)._update(mode=mode, recursive=recursive)
@@ -438,9 +461,15 @@ Examples:
         return self
 
     def wait(self):
+        """Block the main thread until the web interface is closed.
+This method blocks the current thread until the Gradio demo is closed. Useful in deployment scenarios to prevent premature program exit.
+"""
         self.demo.block_thread()
 
     def stop(self):
+        """Stop the web interface and clean up resources.
+If the web demo has been initialized, this method closes the Gradio demo, frees related resources, and resets `demo` and `url` attributes.
+"""
         if self.demo:
             self.demo.close()
             del self.demo
